@@ -6,6 +6,8 @@
 
 #include "src/catalog/catalog_entry/index_catalog_entry.cpp"
 
+#include "src/catalog/catalog_entry/macro_catalog_entry.cpp"
+
 #include "src/catalog/catalog_entry/pragma_function_catalog_entry.cpp"
 
 #include "src/catalog/catalog_entry/schema_catalog_entry.cpp"
@@ -26,6 +28,8 @@
 
 #include "src/catalog/dependency_manager.cpp"
 
+#include "src/common/assert.cpp"
+
 #include "src/common/checksum.cpp"
 
 #include "src/common/constants.cpp"
@@ -80,6 +84,8 @@
 
 #include "src/common/types.cpp"
 
+#include "src/common/types/blob.cpp"
+
 #include "src/common/types/chunk_collection.cpp"
 
 #include "src/common/types/data_chunk.cpp"
@@ -146,6 +152,8 @@
 
 #include "src/execution/aggregate_hashtable.cpp"
 
+#include "src/execution/base_aggregate_hashtable.cpp"
+
 #include "src/execution/column_binding_resolver.cpp"
 
 #include "src/execution/expression_executor.cpp"
@@ -156,3 +164,11 @@
 
 #include "src/execution/expression_executor/execute_cast.cpp"
 
+#include "src/execution/expression_executor/execute_comparison.cpp"
+
+#include "src/execution/expression_executor/execute_conjunction.cpp"
+
+#include "src/execution/expression_executor/execute_constant.cpp"
+
+#include "src/execution/expression_executor/execute_function.cpp"
+
