@@ -1,25 +1,3 @@
-#include "src/optimizer/pushdown/pushdown_mark_join.cpp"
-
-#include "src/optimizer/pushdown/pushdown_projection.cpp"
-
-#include "src/optimizer/pushdown/pushdown_set_operation.cpp"
-
-#include "src/optimizer/pushdown/pushdown_single_join.cpp"
-
-#include "src/optimizer/regex_range_filter.cpp"
-
-#include "src/optimizer/remove_unused_columns.cpp"
-
-#include "src/optimizer/rule/arithmetic_simplification.cpp"
-
-#include "src/optimizer/rule/case_simplification.cpp"
-
-#include "src/optimizer/rule/comparison_simplification.cpp"
-
-#include "src/optimizer/rule/conjunction_simplification.cpp"
-
-#include "src/optimizer/rule/constant_folding.cpp"
-
 #include "src/optimizer/rule/date_part_simplification.cpp"
 
 #include "src/optimizer/rule/distributivity.cpp"
@@ -30,6 +8,48 @@
 
 #include "src/optimizer/rule/move_constants.cpp"
 
+#include "src/optimizer/statistics/expression/propagate_aggregate.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_between.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_case.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_cast.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_columnref.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_comparison.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_conjunction.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_constant.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_function.cpp"
+
+#include "src/optimizer/statistics/expression/propagate_operator.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_aggregate.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_cross_product.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_filter.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_get.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_join.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_limit.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_order.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_projection.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_set_operation.cpp"
+
+#include "src/optimizer/statistics/operator/propagate_window.cpp"
+
+#include "src/optimizer/statistics_propagator.cpp"
+
 #include "src/optimizer/topn_optimizer.cpp"
 
 #include "src/parallel/executor.cpp"
@@ -142,6 +162,8 @@
 
 #include "src/parser/transform/expression/transform_function.cpp"
 
+#include "src/parser/transform/expression/transform_interval.cpp"
+
 #include "src/parser/transform/expression/transform_is_null.cpp"
 
 #include "src/parser/transform/expression/transform_operator.cpp"
@@ -150,9 +172,3 @@
 
 #include "src/parser/transform/expression/transform_subquery.cpp"
 
-#include "src/parser/transform/helpers/nodetype_to_string.cpp"
-
-#include "src/parser/transform/helpers/transform_alias.cpp"
-
-#include "src/parser/transform/helpers/transform_cte.cpp"
-
