@@ -14,14 +14,23 @@
 #include "duckdb/common/types/data_chunk.hpp"
 #include "resizable_buffer.hpp"
 
+#include "parquet_file_metadata_cache.hpp"
 #include "parquet_types.h"
+#include "parquet_rle_bp_decoder.hpp"
 
 #include <exception>
 
+namespace parquet {
+namespace format {
+class FileMetaData;
+}
+} // namespace parquet
+
 namespace duckdb {
 class ClientContext;
-class RleBpDecoder;
 class ChunkCollection;
+class BaseStatistics;
+struct TableFilterSet;
 
 struct ParquetReaderColumnData {
 	~ParquetReaderColumnData();
@@ -60,11 +69,16 @@ struct ParquetReaderScanState {
 	idx_t group_offset;
 	vector<unique_ptr<ParquetReaderColumnData>> column_data;
 	bool finished;
+	TableFilterSet *filters;
+	SelectionVector sel;
 };
 
+typedef nullmask_t parquet_filter_t;
+
 class ParquetReader {
 public:
-	ParquetReader(ClientContext &context, string file_name, vector<LogicalType> expected_types);
+	ParquetReader(ClientContext &context, string file_name, vector<LogicalType> expected_types,
+	              string initial_filename = string());
 	ParquetReader(ClientContext &context, string file_name) : ParquetReader(context, file_name, vector<LogicalType>()) {
 	}
 	~ParquetReader();
@@ -73,35 +87,38 @@ public:
 	vector<LogicalType> return_types;
 	vector<string> names;
 
+	shared_ptr<ParquetFileMetadataCache> metadata;
+
 public:
-	void Initialize(ParquetReaderScanState &state, vector<column_t> column_ids, vector<idx_t> groups_to_read);
-	void ReadChunk(ParquetReaderScanState &state, DataChunk &output);
+	void Initialize(ParquetReaderScanState &state, vector<column_t> column_ids, vector<idx_t> groups_to_read,
+	                TableFilterSet *table_filters);
+	void Scan(ParquetReaderScanState &state, DataChunk &output);
 
 	idx_t NumRows();
 	idx_t NumRowGroups();
 
+	const parquet::format::FileMetaData *GetFileMetadata();
+
+	static unique_ptr<BaseStatistics> ReadStatistics(LogicalType &type, column_t column_index,
+	                                                 const parquet::format::FileMetaData *file_meta_data);
+
 private:
-	parquet::format::RowGroup &GetGroup(ParquetReaderScanState &state);
-	void PrepareChunkBuffer(ParquetReaderScanState &state, idx_t col_idx);
+	void ScanColumn(ParquetReaderScanState &state, parquet_filter_t &filter_mask, idx_t count, idx_t out_col_idx,
+	                Vector &out);
+	bool ScanInternal(ParquetReaderScanState &state, DataChunk &output);
+
+	const parquet::format::RowGroup &GetGroup(ParquetReaderScanState &state);
+	void PrepareRowGroupBuffer(ParquetReaderScanState &state, idx_t col_idx, LogicalType &type);
 	bool PreparePageBuffers(ParquetReaderScanState &state, idx_t col_idx);
+	void VerifyString(LogicalTypeId id, const char *str_data, idx_t str_len);
 
 	template <typename... Args> std::runtime_error FormatException(const string fmt_str, Args... params) {
 		return std::runtime_error("Failed to read Parquet file \"" + file_name +
 		                          "\": " + StringUtil::Format(fmt_str, params...));
 	}
 
-	template <class T>
-	void fill_from_dict(ParquetReaderColumnData &col_data, idx_t count, Vector &target, idx_t target_offset);
-	template <class T>
-	void fill_from_plain(ParquetReaderColumnData &col_data, idx_t count, Vector &target, idx_t target_offset);
-
 private:
-	static constexpr uint8_t GZIP_HEADER_MINSIZE = 10;
-	static constexpr uint8_t GZIP_COMPRESSION_DEFLATE = 0x08;
-	static constexpr unsigned char GZIP_FLAG_UNSUPPORTED = 0x1 | 0x2 | 0x4 | 0x10 | 0x20;
-
 	ClientContext &context;
-	parquet::format::FileMetaData file_meta_data;
 };
 
 } // namespace duckdb
