@@ -7,7 +7,7 @@ using namespace std;
 TableFunctionCatalogEntry::TableFunctionCatalogEntry(Catalog *catalog, SchemaCatalogEntry *schema,
                                                      CreateTableFunctionInfo *info)
     : StandardEntry(CatalogType::TABLE_FUNCTION_ENTRY, schema, catalog, info->name), functions(move(info->functions)) {
-	assert(this->functions.size() > 0);
+	D_ASSERT(this->functions.size() > 0);
 }
 
 } // namespace duckdb
