@@ -24,7 +24,7 @@ void BufferedFileWriter::WriteData(const_data_ptr_t buffer, uint64_t write_size)
 	const_data_ptr_t end_ptr = buffer + write_size;
 	while (buffer < end_ptr) {
 		idx_t to_write = min((idx_t)(end_ptr - buffer), FILE_BUFFER_SIZE - offset);
-		assert(to_write > 0);
+		D_ASSERT(to_write > 0);
 		memcpy(data.get() + offset, buffer, to_write);
 		offset += to_write;
 		buffer += to_write;
