@@ -24,10 +24,36 @@ void ChunkCollection::Verify() {
 
 void ChunkCollection::Append(ChunkCollection &other) {
 	for (auto &chunk : other.chunks) {
-		Append(*chunk.get());
+		Append(*chunk);
 	}
 }
 
+void ChunkCollection::Merge(ChunkCollection &other) {
+	if (other.count == 0) {
+		return;
+	}
+	if (count == 0) {
+		chunks = move(other.chunks);
+		types = move(other.types);
+		count = other.count;
+		return;
+	}
+	unique_ptr<DataChunk> old_back;
+	if (!chunks.empty() && chunks.back()->size() != STANDARD_VECTOR_SIZE) {
+		old_back = move(chunks.back());
+		chunks.pop_back();
+		count -= old_back->size();
+	}
+	for (auto &chunk : other.chunks) {
+		chunks.push_back(move(chunk));
+	}
+	count += other.count;
+	if (old_back) {
+		Append(*old_back);
+	}
+	Verify();
+}
+
 void ChunkCollection::Append(DataChunk &new_chunk) {
 	if (new_chunk.size() == 0) {
 		return;
@@ -46,7 +72,7 @@ void ChunkCollection::Append(DataChunk &new_chunk) {
 		types = new_chunk.GetTypes();
 	} else {
 		// the types of the new chunk should match the types of the previous one
-		assert(types.size() == new_chunk.column_count());
+		D_ASSERT(types.size() == new_chunk.ColumnCount());
 		auto new_types = new_chunk.GetTypes();
 		for (idx_t i = 0; i < types.size(); i++) {
 			if (new_types[i] != types[i]) {
@@ -60,8 +86,8 @@ void ChunkCollection::Append(DataChunk &new_chunk) {
 					if (ListVector::HasEntry(chunk_vec) && ListVector::HasEntry(new_vec)) {
 						auto &chunk_types = ListVector::GetEntry(chunk_vec).types;
 						auto &new_types = ListVector::GetEntry(new_vec).types;
-						assert(new_types.size() <= 1);
-						assert(chunk_types.size() <= 1);
+						D_ASSERT(new_types.size() <= 1);
+						D_ASSERT(chunk_types.size() <= 1);
 						if (chunk_types.size() > 0 && new_types.size() > 0 && chunk_types != new_types) {
 							throw TypeMismatchException(chunk_types[0], new_types[0],
 							                            "Type mismatch when combining lists");
@@ -107,7 +133,7 @@ void ChunkCollection::Append(DataChunk &new_chunk) {
 
 template <class TYPE>
 static int8_t templated_compare_value(Vector &left_vec, Vector &right_vec, idx_t left_idx, idx_t right_idx) {
-	assert(left_vec.type == right_vec.type);
+	D_ASSERT(left_vec.type == right_vec.type);
 	auto left_val = FlatVector::GetData<TYPE>(left_vec)[left_idx];
 	auto right_val = FlatVector::GetData<TYPE>(right_vec)[right_idx];
 	if (Equals::Operation<TYPE>(left_val, right_val)) {
@@ -161,25 +187,25 @@ static int32_t compare_value(Vector &left_vec, Vector &right_vec, idx_t vector_i
 
 static int compare_tuple(ChunkCollection *sort_by, vector<OrderType> &desc, vector<OrderByNullType> &null_order,
                          idx_t left, idx_t right) {
-	assert(sort_by);
+	D_ASSERT(sort_by);
 
 	idx_t chunk_idx_left = left / STANDARD_VECTOR_SIZE;
 	idx_t chunk_idx_right = right / STANDARD_VECTOR_SIZE;
 	idx_t vector_idx_left = left % STANDARD_VECTOR_SIZE;
 	idx_t vector_idx_right = right % STANDARD_VECTOR_SIZE;
 
-	auto &left_chunk = sort_by->chunks[chunk_idx_left];
-	auto &right_chunk = sort_by->chunks[chunk_idx_right];
+	auto &left_chunk = sort_by->GetChunk(chunk_idx_left);
+	auto &right_chunk = sort_by->GetChunk(chunk_idx_right);
 
 	for (idx_t col_idx = 0; col_idx < desc.size(); col_idx++) {
 		auto order_type = desc[col_idx];
 
-		Vector &left_vec = left_chunk->data[col_idx];
-		Vector &right_vec = right_chunk->data[col_idx];
+		auto &left_vec = left_chunk.data[col_idx];
+		auto &right_vec = right_chunk.data[col_idx];
 
-		assert(left_vec.vector_type == VectorType::FLAT_VECTOR);
-		assert(right_vec.vector_type == VectorType::FLAT_VECTOR);
-		assert(left_vec.type == right_vec.type);
+		D_ASSERT(left_vec.vector_type == VectorType::FLAT_VECTOR);
+		D_ASSERT(right_vec.vector_type == VectorType::FLAT_VECTOR);
+		D_ASSERT(left_vec.type == right_vec.type);
 
 		auto comp_res = compare_value(left_vec, right_vec, vector_idx_left, vector_idx_right, null_order[col_idx]);
 
@@ -196,16 +222,16 @@ static int64_t _quicksort_initial(ChunkCollection *sort_by, vector<OrderType> &d
                                   vector<OrderByNullType> &null_order, idx_t *result) {
 	// select pivot
 	int64_t pivot = 0;
-	int64_t low = 0, high = sort_by->count - 1;
+	int64_t low = 0, high = sort_by->Count() - 1;
 	// now insert elements
-	for (idx_t i = 1; i < sort_by->count; i++) {
+	for (idx_t i = 1; i < sort_by->Count(); i++) {
 		if (compare_tuple(sort_by, desc, null_order, i, pivot) <= 0) {
 			result[low++] = i;
 		} else {
 			result[high--] = i;
 		}
 	}
-	assert(low == high);
+	D_ASSERT(low == high);
 	result[low] = pivot;
 	return low;
 }
@@ -244,7 +270,7 @@ static void _quicksort_inplace(ChunkCollection *sort_by, vector<OrderType> &desc
 	auto left = info.left;
 	auto right = info.right;
 
-	assert(left < right);
+	D_ASSERT(left < right);
 
 	int64_t middle = left + (right - left) / 2;
 	int64_t pivot = result[middle];
@@ -287,7 +313,7 @@ static void _quicksort_inplace(ChunkCollection *sort_by, vector<OrderType> &desc
 }
 
 void ChunkCollection::Sort(vector<OrderType> &desc, vector<OrderByNullType> &null_order, idx_t result[]) {
-	assert(result);
+	D_ASSERT(result);
 	if (count == 0) {
 		return;
 	}
@@ -314,11 +340,11 @@ void ChunkCollection::Reorder(idx_t order_org[]) {
 	// adapted from https://stackoverflow.com/a/7366196/2652376
 
 	auto val_buf = vector<Value>();
-	val_buf.resize(column_count());
+	val_buf.resize(ColumnCount());
 
 	idx_t j, k;
 	for (idx_t i = 0; i < count; i++) {
-		for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+		for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 			val_buf[col_idx] = GetValue(col_idx, i);
 		}
 		j = i;
@@ -328,12 +354,12 @@ void ChunkCollection::Reorder(idx_t order_org[]) {
 			if (k == i) {
 				break;
 			}
-			for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+			for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 				SetValue(col_idx, j, GetValue(col_idx, k));
 			}
 			j = k;
 		}
-		for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+		for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 			SetValue(col_idx, j, val_buf[col_idx]);
 		}
 	}
@@ -342,14 +368,14 @@ void ChunkCollection::Reorder(idx_t order_org[]) {
 template <class TYPE>
 static void templated_set_values(ChunkCollection *src_coll, Vector &tgt_vec, idx_t order[], idx_t col_idx,
                                  idx_t start_offset, idx_t remaining_data) {
-	assert(src_coll);
+	D_ASSERT(src_coll);
 
 	for (idx_t row_idx = 0; row_idx < remaining_data; row_idx++) {
 		idx_t chunk_idx_src = order[start_offset + row_idx] / STANDARD_VECTOR_SIZE;
 		idx_t vector_idx_src = order[start_offset + row_idx] % STANDARD_VECTOR_SIZE;
 
-		auto &src_chunk = src_coll->chunks[chunk_idx_src];
-		Vector &src_vec = src_chunk->data[col_idx];
+		auto &src_chunk = src_coll->GetChunk(chunk_idx_src);
+		Vector &src_vec = src_chunk.data[col_idx];
 		auto source_data = FlatVector::GetData<TYPE>(src_vec);
 		auto target_data = FlatVector::GetData<TYPE>(tgt_vec);
 
@@ -364,10 +390,10 @@ static void templated_set_values(ChunkCollection *src_coll, Vector &tgt_vec, idx
 // TODO: reorder functionality is similar, perhaps merge
 void ChunkCollection::MaterializeSortedChunk(DataChunk &target, idx_t order[], idx_t start_offset) {
 	idx_t remaining_data = min((idx_t)STANDARD_VECTOR_SIZE, count - start_offset);
-	assert(target.GetTypes() == types);
+	D_ASSERT(target.GetTypes() == types);
 
 	target.SetCardinality(remaining_data);
-	for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 		switch (types[col_idx].InternalType()) {
 		case PhysicalType::BOOL:
 		case PhysicalType::INT8:
@@ -427,9 +453,9 @@ Value ChunkCollection::GetValue(idx_t column, idx_t index) {
 
 vector<Value> ChunkCollection::GetRow(idx_t index) {
 	vector<Value> values;
-	values.resize(column_count());
+	values.resize(ColumnCount());
 
-	for (idx_t p_idx = 0; p_idx < column_count(); p_idx++) {
+	for (idx_t p_idx = 0; p_idx < ColumnCount(); p_idx++) {
 		values[p_idx] = GetValue(p_idx, index);
 	}
 	return values;
@@ -447,7 +473,7 @@ bool ChunkCollection::Equals(ChunkCollection &other) {
 	if (count != other.count) {
 		return false;
 	}
-	if (column_count() != other.column_count()) {
+	if (ColumnCount() != other.ColumnCount()) {
 		return false;
 	}
 	if (types != other.types) {
@@ -455,7 +481,7 @@ bool ChunkCollection::Equals(ChunkCollection &other) {
 	}
 	// if count is equal amount of chunks should be equal
 	for (idx_t row_idx = 0; row_idx < count; row_idx++) {
-		for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+		for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 			auto lvalue = GetValue(col_idx, row_idx);
 			auto rvalue = other.GetValue(col_idx, row_idx);
 			if (!Value::ValuesAreEqual(lvalue, rvalue)) {
@@ -504,7 +530,7 @@ static void _heap_create(ChunkCollection *input, vector<OrderType> &desc, vector
 	}
 
 	// Run through all the rows.
-	for (idx_t i = heap_size; i < input->count; i++) {
+	for (idx_t i = heap_size; i < input->Count(); i++) {
 		if (compare_tuple(input, desc, null_order, i, heap[0]) <= 0) {
 			heap[0] = i;
 			_heapify(input, desc, null_order, heap, heap_size, 0);
@@ -514,7 +540,7 @@ static void _heap_create(ChunkCollection *input, vector<OrderType> &desc, vector
 
 void ChunkCollection::Heap(vector<OrderType> &desc, vector<OrderByNullType> &null_order, idx_t heap[],
                            idx_t heap_size) {
-	assert(heap);
+	D_ASSERT(heap);
 	if (count == 0)
 		return;
 
@@ -529,10 +555,10 @@ void ChunkCollection::Heap(vector<OrderType> &desc, vector<OrderByNullType> &nul
 
 idx_t ChunkCollection::MaterializeHeapChunk(DataChunk &target, idx_t order[], idx_t start_offset, idx_t heap_size) {
 	idx_t remaining_data = min((idx_t)STANDARD_VECTOR_SIZE, heap_size - start_offset);
-	assert(target.GetTypes() == types);
+	D_ASSERT(target.GetTypes() == types);
 
 	target.SetCardinality(remaining_data);
-	for (idx_t col_idx = 0; col_idx < column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < ColumnCount(); col_idx++) {
 		switch (types[col_idx].InternalType()) {
 		case PhysicalType::BOOL:
 		case PhysicalType::INT8:
