@@ -15,7 +15,7 @@ using namespace std;
 // AND/OR
 //===--------------------------------------------------------------------===//
 template <class OP> static void templated_boolean_nullmask(Vector &left, Vector &right, Vector &result, idx_t count) {
-	assert(left.type.id() == LogicalTypeId::BOOLEAN && right.type.id() == LogicalTypeId::BOOLEAN &&
+	D_ASSERT(left.type.id() == LogicalTypeId::BOOLEAN && right.type.id() == LogicalTypeId::BOOLEAN &&
 	       result.type.id() == LogicalTypeId::BOOLEAN);
 
 	if (left.vector_type == VectorType::CONSTANT_VECTOR && right.vector_type == VectorType::CONSTANT_VECTOR) {
@@ -168,7 +168,7 @@ struct NotOperator {
 };
 
 void VectorOperations::Not(Vector &input, Vector &result, idx_t count) {
-	assert(input.type == LogicalType::BOOLEAN && result.type == LogicalType::BOOLEAN);
+	D_ASSERT(input.type == LogicalType::BOOLEAN && result.type == LogicalType::BOOLEAN);
 	UnaryExecutor::Execute<bool, bool, NotOperator>(input, result, count);
 }
 
