@@ -13,7 +13,7 @@ namespace duckdb {
 using namespace std;
 
 template <class SRC, class OP> static void string_cast(Vector &source, Vector &result, idx_t count) {
-	assert(result.type.InternalType() == PhysicalType::VARCHAR);
+	D_ASSERT(result.type.InternalType() == PhysicalType::VARCHAR);
 	UnaryExecutor::Execute<SRC, string_t, true>(source, result, count,
 	                                            [&](SRC input) { return OP::template Operation<SRC>(input, result); });
 }
@@ -93,7 +93,7 @@ template <class T> static void from_decimal_cast(Vector &source, Vector &result,
 
 template <class SOURCE, class DEST, class POWERS_SOURCE, class POWERS_DEST>
 void decimal_scale_up_loop(Vector &source, Vector &result, idx_t count) {
-	assert(result.type.scale() >= source.type.scale());
+	D_ASSERT(result.type.scale() >= source.type.scale());
 	idx_t scale_difference = result.type.scale() - source.type.scale();
 	auto multiply_factor = POWERS_DEST::PowersOfTen[scale_difference];
 	idx_t target_width = result.type.width() - scale_difference;
@@ -107,7 +107,8 @@ void decimal_scale_up_loop(Vector &source, Vector &result, idx_t count) {
 		auto limit = POWERS_SOURCE::PowersOfTen[target_width];
 		UnaryExecutor::Execute<SOURCE, DEST, true>(source, result, count, [&](SOURCE input) {
 			if (input >= limit || input <= -limit) {
-				throw OutOfRangeException("Casting to %s failed", result.type.ToString());
+				throw OutOfRangeException("Casting value \"%s\" to type %s failed: value is out of range!",
+				                          Decimal::ToString(input, source.type.scale()), result.type.ToString());
 			}
 			return Cast::Operation<SOURCE, DEST>(input) * multiply_factor;
 		});
@@ -116,7 +117,7 @@ void decimal_scale_up_loop(Vector &source, Vector &result, idx_t count) {
 
 template <class SOURCE, class DEST, class POWERS_SOURCE>
 void decimal_scale_down_loop(Vector &source, Vector &result, idx_t count) {
-	assert(result.type.scale() < source.type.scale());
+	D_ASSERT(result.type.scale() < source.type.scale());
 	idx_t scale_difference = source.type.scale() - result.type.scale();
 	idx_t target_width = result.type.width() + scale_difference;
 	auto divide_factor = POWERS_SOURCE::PowersOfTen[scale_difference];
@@ -129,7 +130,8 @@ void decimal_scale_down_loop(Vector &source, Vector &result, idx_t count) {
 		auto limit = POWERS_SOURCE::PowersOfTen[target_width];
 		UnaryExecutor::Execute<SOURCE, DEST, true>(source, result, count, [&](SOURCE input) {
 			if (input >= limit || input <= -limit) {
-				throw OutOfRangeException("Casting to %s failed", result.type.ToString());
+				throw OutOfRangeException("Casting value \"%s\" to type %s failed: value is out of range!",
+				                          Decimal::ToString(input, source.type.scale()), result.type.ToString());
 			}
 			return Cast::Operation<SOURCE, DEST>(input / divide_factor);
 		});
@@ -473,7 +475,6 @@ static void value_string_cast_switch(Vector &source, Vector &result, idx_t count
 			auto src_val = source.GetValue(i);
 			auto str_val = src_val.ToString();
 			result.SetValue(i, Value(str_val));
-			break;
 		}
 		break;
 	default:
@@ -483,7 +484,7 @@ static void value_string_cast_switch(Vector &source, Vector &result, idx_t count
 }
 
 void VectorOperations::Cast(Vector &source, Vector &result, idx_t count, bool strict) {
-	assert(source.type != result.type);
+	D_ASSERT(source.type != result.type);
 	// first switch on source type
 	switch (source.type.id()) {
 	case LogicalTypeId::BOOLEAN:
