@@ -12,7 +12,7 @@ unique_ptr<ExpressionState> ExpressionExecutor::InitializeState(BoundConstantExp
 
 void ExpressionExecutor::Execute(BoundConstantExpression &expr, ExpressionState *state, const SelectionVector *sel,
                                  idx_t count, Vector &result) {
-	assert(expr.value.type() == expr.return_type);
+	D_ASSERT(expr.value.type() == expr.return_type);
 	result.Reference(expr.value);
 }
 
