@@ -6,7 +6,14 @@ namespace duckdb {
 using namespace std;
 
 void ExpressionState::AddChild(Expression *expr) {
+	types.push_back(expr->return_type);
 	child_states.push_back(ExpressionExecutor::InitializeState(*expr, root));
 }
 
+void ExpressionState::Finalize() {
+	if (types.size() > 0) {
+		intermediate_chunk.Initialize(types);
+	}
+}
+
 } // namespace duckdb
