@@ -19,27 +19,27 @@ JoinHashTable::JoinHashTable(BufferManager &buffer_manager, vector<JoinCondition
     : buffer_manager(buffer_manager), build_types(move(btypes)), equality_size(0), condition_size(0), build_size(0),
       entry_size(0), tuple_size(0), join_type(type), finalized(false), has_null(false), count(0) {
 	for (auto &condition : conditions) {
-		assert(condition.left->return_type == condition.right->return_type);
+		D_ASSERT(condition.left->return_type == condition.right->return_type);
 		auto type = condition.left->return_type;
 		auto type_size = GetTypeIdSize(type.InternalType());
 		if (condition.comparison == ExpressionType::COMPARE_EQUAL) {
 			// all equality conditions should be at the front
 			// all other conditions at the back
 			// this assert checks that
-			assert(equality_types.size() == condition_types.size());
+			D_ASSERT(equality_types.size() == condition_types.size());
 			equality_types.push_back(type);
 			equality_size += type_size;
 		}
 		predicates.push_back(condition.comparison);
 		null_values_are_equal.push_back(condition.null_values_are_equal);
-		assert(!condition.null_values_are_equal ||
-		       (condition.null_values_are_equal && condition.comparison == ExpressionType::COMPARE_EQUAL));
+		D_ASSERT(!condition.null_values_are_equal ||
+		         (condition.null_values_are_equal && condition.comparison == ExpressionType::COMPARE_EQUAL));
 
 		condition_types.push_back(type);
 		condition_size += type_size;
 	}
 	// at least one equality is necessary
-	assert(equality_types.size() > 0);
+	D_ASSERT(equality_types.size() > 0);
 
 	for (idx_t i = 0; i < build_types.size(); i++) {
 		build_size += GetTypeIdSize(build_types[i].InternalType());
@@ -48,8 +48,8 @@ JoinHashTable::JoinHashTable(BufferManager &buffer_manager, vector<JoinCondition
 	pointer_offset = tuple_size;
 	// entry size is the tuple size and the size of the hash/next pointer
 	entry_size = tuple_size + MaxValue(sizeof(hash_t), sizeof(uintptr_t));
-	if (join_type == JoinType::OUTER) {
-		// outer joins need an extra bool to keep track of whether or not a tuple has found a matching entry
+	if (IsRightOuterJoin(join_type)) {
+		// full/right outer joins need an extra bool to keep track of whether or not a tuple has found a matching entry
 		// we place the bool before the NEXT pointer
 		entry_size += sizeof(bool);
 		pointer_offset += sizeof(bool);
@@ -72,7 +72,7 @@ JoinHashTable::~JoinHashTable() {
 
 void JoinHashTable::ApplyBitmask(Vector &hashes, idx_t count) {
 	if (hashes.vector_type == VectorType::CONSTANT_VECTOR) {
-		assert(!ConstantVector::IsNull(hashes));
+		D_ASSERT(!ConstantVector::IsNull(hashes));
 		auto indices = ConstantVector::GetData<hash_t>(hashes);
 		*indices = *indices & bitmask;
 	} else {
@@ -192,7 +192,7 @@ void JoinHashTable::SerializeVectorData(VectorData &vdata, PhysicalType type, co
 			} else if (source[source_idx].IsInlined()) {
 				new_val = source[source_idx];
 			} else {
-				new_val = local_heap.AddString(source[source_idx]);
+				new_val = local_heap.AddBlob(source[source_idx].GetDataUnsafe(), source[source_idx].GetSize());
 			}
 			Store<string_t>(new_val, key_locations[i]);
 			key_locations[i] += sizeof(string_t);
@@ -237,13 +237,17 @@ static idx_t FilterNullValues(VectorData &vdata, const SelectionVector &sel, idx
 }
 
 idx_t JoinHashTable::PrepareKeys(DataChunk &keys, unique_ptr<VectorData[]> &key_data,
-                                 const SelectionVector *&current_sel, SelectionVector &sel) {
+                                 const SelectionVector *&current_sel, SelectionVector &sel, bool build_side) {
 	key_data = keys.Orrify();
 
 	// figure out which keys are NULL, and create a selection vector out of them
 	current_sel = &FlatVector::IncrementalSelectionVector;
 	idx_t added_count = keys.size();
-	for (idx_t i = 0; i < keys.column_count(); i++) {
+	if (build_side && IsRightOuterJoin(join_type)) {
+		// in case of a right or full outer join, we cannot remove NULL keys from the build side
+		return added_count;
+	}
+	for (idx_t i = 0; i < keys.ColumnCount(); i++) {
 		if (!null_values_are_equal[i]) {
 			if (!key_data[i].nullmask->any()) {
 				continue;
@@ -257,8 +261,8 @@ idx_t JoinHashTable::PrepareKeys(DataChunk &keys, unique_ptr<VectorData[]> &key_
 }
 
 void JoinHashTable::Build(DataChunk &keys, DataChunk &payload) {
-	assert(!finalized);
-	assert(keys.size() == payload.size());
+	D_ASSERT(!finalized);
+	D_ASSERT(keys.size() == payload.size());
 	if (keys.size() == 0) {
 		return;
 	}
@@ -269,15 +273,13 @@ void JoinHashTable::Build(DataChunk &keys, DataChunk &payload) {
 		// Correlated MARK join
 		// for the correlated mark join we need to keep track of COUNT(*) and COUNT(COLUMN) for each of the correlated
 		// columns push into the aggregate hash table
-		assert(info.correlated_counts);
+		D_ASSERT(info.correlated_counts);
 		info.group_chunk.SetCardinality(keys);
 		for (idx_t i = 0; i < info.correlated_types.size(); i++) {
 			info.group_chunk.data[i].Reference(keys.data[i]);
 		}
 		info.payload_chunk.SetCardinality(keys);
-		for (idx_t i = 0; i < 2; i++) {
-			info.payload_chunk.data[i].Reference(keys.data[info.correlated_types.size()]);
-		}
+		info.payload_chunk.data[0].Reference(keys.data[info.correlated_types.size()]);
 		info.correlated_counts->AddChunk(info.group_chunk, info.payload_chunk);
 	}
 
@@ -285,7 +287,7 @@ void JoinHashTable::Build(DataChunk &keys, DataChunk &payload) {
 	unique_ptr<VectorData[]> key_data;
 	const SelectionVector *current_sel;
 	SelectionVector sel(STANDARD_VECTOR_SIZE);
-	idx_t added_count = PrepareKeys(keys, key_data, current_sel, sel);
+	idx_t added_count = PrepareKeys(keys, key_data, current_sel, sel, true);
 	if (added_count < keys.size()) {
 		has_null = true;
 	}
@@ -344,31 +346,31 @@ void JoinHashTable::Build(DataChunk &keys, DataChunk &payload) {
 	Hash(keys, *current_sel, added_count, hash_values);
 
 	// serialize the keys to the key locations
-	for (idx_t i = 0; i < keys.column_count(); i++) {
+	for (idx_t i = 0; i < keys.ColumnCount(); i++) {
 		SerializeVectorData(key_data[i], keys.data[i].type.InternalType(), *current_sel, added_count, key_locations);
 	}
 	// now serialize the payload
 	if (build_types.size() > 0) {
-		for (idx_t i = 0; i < payload.column_count(); i++) {
+		for (idx_t i = 0; i < payload.ColumnCount(); i++) {
 			SerializeVector(payload.data[i], payload.size(), *current_sel, added_count, key_locations);
 		}
 	}
-	if (join_type == JoinType::OUTER) {
-		// for OUTER joins initialize the "found" boolean to false
+	if (IsRightOuterJoin(join_type)) {
+		// for FULL/RIGHT OUTER joins initialize the "found" boolean to false
 		initialize_outer_join(added_count, key_locations);
 	}
 	SerializeVector(hash_values, payload.size(), *current_sel, added_count, key_locations);
 }
 
 void JoinHashTable::InsertHashes(Vector &hashes, idx_t count, data_ptr_t key_locations[]) {
-	assert(hashes.type.id() == LogicalTypeId::HASH);
+	D_ASSERT(hashes.type.id() == LogicalTypeId::HASH);
 
 	// use bitmask to get position in array
 	ApplyBitmask(hashes, count);
 
 	hashes.Normalify(count);
 
-	assert(hashes.vector_type == VectorType::FLAT_VECTOR);
+	D_ASSERT(hashes.vector_type == VectorType::FLAT_VECTOR);
 	auto pointers = (data_ptr_t *)hash_map->node->buffer;
 	auto indices = FlatVector::GetData<hash_t>(hashes);
 	for (idx_t i = 0; i < count; i++) {
@@ -388,7 +390,7 @@ void JoinHashTable::Finalize() {
 	// select a HT that has at least 50% empty space
 	idx_t capacity = NextPowerOfTwo(MaxValue<idx_t>(count * 2, (Storage::BLOCK_ALLOC_SIZE / sizeof(data_ptr_t)) + 1));
 	// size needs to be a power of 2
-	assert((capacity & (capacity - 1)) == 0);
+	D_ASSERT((capacity & (capacity - 1)) == 0);
 	bitmask = capacity - 1;
 
 	// allocate the HT and initialize it with all-zero entries
@@ -426,8 +428,8 @@ void JoinHashTable::Finalize() {
 }
 
 unique_ptr<ScanStructure> JoinHashTable::Probe(DataChunk &keys) {
-	assert(count > 0); // should be handled before
-	assert(finalized);
+	D_ASSERT(count > 0); // should be handled before
+	D_ASSERT(finalized);
 
 	// set up the scan structure
 	auto ss = make_unique<ScanStructure>(*this);
@@ -439,7 +441,7 @@ unique_ptr<ScanStructure> JoinHashTable::Probe(DataChunk &keys) {
 
 	// first prepare the keys for probing
 	const SelectionVector *current_sel;
-	ss->count = PrepareKeys(keys, ss->key_data, current_sel, ss->sel_vector);
+	ss->count = PrepareKeys(keys, ss->key_data, current_sel, ss->sel_vector, false);
 	if (ss->count == 0) {
 		return ss;
 	}
@@ -477,6 +479,7 @@ void ScanStructure::Next(DataChunk &keys, DataChunk &left, DataChunk &result) {
 
 	switch (ht.join_type) {
 	case JoinType::INNER:
+	case JoinType::RIGHT:
 		NextInnerJoin(keys, left, result);
 		break;
 	case JoinType::SEMI:
@@ -738,7 +741,7 @@ void ScanStructure::GatherResult(Vector &result, const SelectionVector &sel_vect
 }
 
 void ScanStructure::NextInnerJoin(DataChunk &keys, DataChunk &left, DataChunk &result) {
-	assert(result.column_count() == left.column_count() + ht.build_types.size());
+	D_ASSERT(result.ColumnCount() == left.ColumnCount() + ht.build_types.size());
 	if (this->count == 0) {
 		// no pointers left to chase
 		return;
@@ -748,8 +751,8 @@ void ScanStructure::NextInnerJoin(DataChunk &keys, DataChunk &left, DataChunk &r
 
 	idx_t result_count = ScanInnerJoin(keys, result_vector);
 	if (result_count > 0) {
-		if (ht.join_type == JoinType::OUTER) {
-			// outer join: mark join matches as FOUND in the HT
+		if (IsRightOuterJoin(ht.join_type)) {
+			// full/right outer join: mark join matches as FOUND in the HT
 			auto ptrs = FlatVector::GetData<uintptr_t>(pointers);
 			for (idx_t i = 0; i < result_count; i++) {
 				auto idx = result_vector.get_index(i);
@@ -766,8 +769,8 @@ void ScanStructure::NextInnerJoin(DataChunk &keys, DataChunk &left, DataChunk &r
 		// on the RHS, we need to fetch the data from the hash table
 		idx_t offset = ht.condition_size;
 		for (idx_t i = 0; i < ht.build_types.size(); i++) {
-			auto &vector = result.data[left.column_count() + i];
-			assert(vector.type == ht.build_types[i]);
+			auto &vector = result.data[left.ColumnCount() + i];
+			D_ASSERT(vector.type == ht.build_types[i]);
 			GatherResult(vector, result_vector, result_count, offset);
 		}
 		AdvancePointers();
@@ -796,8 +799,8 @@ void ScanStructure::ScanKeyMatches(DataChunk &keys) {
 }
 
 template <bool MATCH> void ScanStructure::NextSemiOrAntiJoin(DataChunk &keys, DataChunk &left, DataChunk &result) {
-	assert(left.column_count() == result.column_count());
-	assert(keys.size() == left.size());
+	D_ASSERT(left.ColumnCount() == result.ColumnCount());
+	D_ASSERT(keys.size() == left.size());
 	// create the selection vector from the matches that were found
 	SelectionVector sel(STANDARD_VECTOR_SIZE);
 	idx_t result_count = 0;
@@ -813,7 +816,7 @@ template <bool MATCH> void ScanStructure::NextSemiOrAntiJoin(DataChunk &keys, Da
 		// reference the columns of the left side from the result
 		result.Slice(left, sel, result_count);
 	} else {
-		assert(result.size() == 0);
+		D_ASSERT(result.size() == 0);
 	}
 }
 
@@ -838,7 +841,7 @@ void ScanStructure::NextAntiJoin(DataChunk &keys, DataChunk &left, DataChunk &re
 void ScanStructure::ConstructMarkJoinResult(DataChunk &join_keys, DataChunk &child, DataChunk &result) {
 	// for the initial set of columns we just reference the left side
 	result.SetCardinality(child);
-	for (idx_t i = 0; i < child.column_count(); i++) {
+	for (idx_t i = 0; i < child.ColumnCount(); i++) {
 		result.data[i].Reference(child.data[i]);
 	}
 	auto &mark_vector = result.data.back();
@@ -847,7 +850,7 @@ void ScanStructure::ConstructMarkJoinResult(DataChunk &join_keys, DataChunk &chi
 	// if there is any NULL in the keys, the result is NULL
 	auto bool_result = FlatVector::GetData<bool>(mark_vector);
 	auto &nullmask = FlatVector::Nullmask(mark_vector);
-	for (idx_t col_idx = 0; col_idx < join_keys.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < join_keys.ColumnCount(); col_idx++) {
 		if (ht.null_values_are_equal[col_idx]) {
 			continue;
 		}
@@ -879,10 +882,10 @@ void ScanStructure::ConstructMarkJoinResult(DataChunk &join_keys, DataChunk &chi
 }
 
 void ScanStructure::NextMarkJoin(DataChunk &keys, DataChunk &input, DataChunk &result) {
-	assert(result.column_count() == input.column_count() + 1);
-	assert(result.data.back().type == LogicalType::BOOLEAN);
+	D_ASSERT(result.ColumnCount() == input.ColumnCount() + 1);
+	D_ASSERT(result.data.back().type == LogicalType::BOOLEAN);
 	// this method should only be called for a non-empty HT
-	assert(ht.count > 0);
+	D_ASSERT(ht.count > 0);
 
 	ScanKeyMatches(keys);
 	if (ht.correlated_mark_join_info.correlated_types.size() == 0) {
@@ -891,16 +894,16 @@ void ScanStructure::NextMarkJoin(DataChunk &keys, DataChunk &input, DataChunk &r
 		auto &info = ht.correlated_mark_join_info;
 		// there are correlated columns
 		// first we fetch the counts from the aggregate hashtable corresponding to these entries
-		assert(keys.column_count() == info.group_chunk.column_count() + 1);
+		D_ASSERT(keys.ColumnCount() == info.group_chunk.ColumnCount() + 1);
 		info.group_chunk.SetCardinality(keys);
-		for (idx_t i = 0; i < info.group_chunk.column_count(); i++) {
+		for (idx_t i = 0; i < info.group_chunk.ColumnCount(); i++) {
 			info.group_chunk.data[i].Reference(keys.data[i]);
 		}
 		info.correlated_counts->FetchAggregates(info.group_chunk, info.result_chunk);
 
 		// for the initial set of columns we just reference the left side
 		result.SetCardinality(input);
-		for (idx_t i = 0; i < input.column_count(); i++) {
+		for (idx_t i = 0; i < input.ColumnCount(); i++) {
 			result.data[i].Reference(input.data[i]);
 		}
 		// create the result matching vector
@@ -934,7 +937,7 @@ void ScanStructure::NextMarkJoin(DataChunk &keys, DataChunk &input, DataChunk &r
 		auto count = FlatVector::GetData<int64_t>(info.result_chunk.data[1]);
 		// set the entries to either true or false based on whether a match was found
 		for (idx_t i = 0; i < input.size(); i++) {
-			assert(count_star[i] >= count[i]);
+			D_ASSERT(count_star[i] >= count[i]);
 			bool_result[i] = found_match ? found_match[i] : false;
 			if (!bool_result[i] && count_star[i] > count[i]) {
 				// RHS has NULL value and result is false: set to null
@@ -971,7 +974,7 @@ void ScanStructure::NextLeftJoin(DataChunk &keys, DataChunk &left, DataChunk &re
 			result.Slice(left, sel, remaining_count);
 
 			// now set the right side to NULL
-			for (idx_t i = left.column_count(); i < result.column_count(); i++) {
+			for (idx_t i = left.ColumnCount(); i < result.ColumnCount(); i++) {
 				result.data[i].vector_type = VectorType::CONSTANT_VECTOR;
 				ConstantVector::SetNull(result.data[i], true);
 			}
@@ -1004,14 +1007,14 @@ void ScanStructure::NextSingleJoin(DataChunk &keys, DataChunk &input, DataChunk
 		AdvancePointers(no_match_sel, no_match_count);
 	}
 	// reference the columns of the left side from the result
-	assert(input.column_count() > 0);
-	for (idx_t i = 0; i < input.column_count(); i++) {
+	D_ASSERT(input.ColumnCount() > 0);
+	for (idx_t i = 0; i < input.ColumnCount(); i++) {
 		result.data[i].Reference(input.data[i]);
 	}
 	// now fetch the data from the RHS
 	idx_t offset = ht.condition_size;
 	for (idx_t i = 0; i < ht.build_types.size(); i++) {
-		auto &vector = result.data[input.column_count() + i];
+		auto &vector = result.data[input.ColumnCount() + i];
 		// set NULL entries for every entry that was not found
 		auto &nullmask = FlatVector::Nullmask(vector);
 		nullmask.set();
@@ -1031,7 +1034,7 @@ void JoinHashTable::ScanFullOuter(DataChunk &result, JoinHTScanState &state) {
 	// scan the HT starting from the current position and check which rows from the build side did not find a match
 	data_ptr_t key_locations[STANDARD_VECTOR_SIZE];
 	idx_t found_entries = 0;
-	for (; state.block_position < blocks.size(); state.block_position++) {
+	for (; state.block_position < blocks.size(); state.block_position++, state.position = 0) {
 		auto &block = blocks[state.block_position];
 		auto &handle = pinned_handles[state.block_position];
 		auto baseptr = handle->node->buffer;
@@ -1052,7 +1055,7 @@ void JoinHashTable::ScanFullOuter(DataChunk &result, JoinHTScanState &state) {
 	}
 	result.SetCardinality(found_entries);
 	if (found_entries > 0) {
-		idx_t left_column_count = result.column_count() - build_types.size();
+		idx_t left_column_count = result.ColumnCount() - build_types.size();
 		// set the left side as a constant NULL
 		for (idx_t i = 0; i < left_column_count; i++) {
 			result.data[i].vector_type = VectorType::CONSTANT_VECTOR;
@@ -1062,7 +1065,7 @@ void JoinHashTable::ScanFullOuter(DataChunk &result, JoinHTScanState &state) {
 		idx_t offset = condition_size;
 		for (idx_t i = 0; i < build_types.size(); i++) {
 			auto &vector = result.data[left_column_count + i];
-			assert(vector.type == build_types[i]);
+			D_ASSERT(vector.type == build_types[i]);
 			GatherResultVector(vector, FlatVector::IncrementalSelectionVector, (uintptr_t *)key_locations,
 			                   FlatVector::IncrementalSelectionVector, found_entries, offset);
 		}
