@@ -21,7 +21,7 @@ PhysicalSimpleAggregate::PhysicalSimpleAggregate(vector<LogicalType> types, vect
 struct AggregateState {
 	AggregateState(vector<unique_ptr<Expression>> &aggregate_expressions) {
 		for (auto &aggregate : aggregate_expressions) {
-			assert(aggregate->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
+			D_ASSERT(aggregate->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
 			auto &aggr = (BoundAggregateExpression &)*aggregate;
 			auto state = unique_ptr<data_t[]>(new data_t[aggr.function.state_size()]);
 			aggr.function.initialize(state.get());
@@ -30,7 +30,7 @@ struct AggregateState {
 		}
 	}
 	~AggregateState() {
-		assert(destructors.size() == aggregates.size());
+		D_ASSERT(destructors.size() == aggregates.size());
 		for (idx_t i = 0; i < destructors.size(); i++) {
 			if (!destructors[i]) {
 				continue;
@@ -46,10 +46,6 @@ struct AggregateState {
 		other.aggregates = move(aggregates);
 		other.destructors = move(destructors);
 	}
-	void Clear() {
-		aggregates.clear();
-		destructors.clear();
-	}
 
 	//! The aggregate values
 	vector<unique_ptr<data_t[]>> aggregates;
@@ -73,7 +69,7 @@ public:
 	SimpleAggregateLocalState(vector<unique_ptr<Expression>> &aggregates) : state(aggregates) {
 		vector<LogicalType> payload_types;
 		for (auto &aggregate : aggregates) {
-			assert(aggregate->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
+			D_ASSERT(aggregate->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
 			auto &aggr = (BoundAggregateExpression &)*aggregate;
 			// initialize the payload chunk
 			if (aggr.children.size()) {
@@ -81,12 +77,11 @@ public:
 					payload_types.push_back(aggr.children[i]->return_type);
 					child_executor.AddExpression(*aggr.children[i]);
 				}
-			} else {
-				// COUNT(*)
-				payload_types.push_back(LogicalType::BIGINT);
 			}
 		}
-		payload_chunk.Initialize(payload_types);
+		if (!payload_types.empty()) { // for select count(*) from t; there is no payload at all
+			payload_chunk.Initialize(payload_types);
+		}
 	}
 
 	//! The local aggregate state
@@ -124,11 +119,10 @@ void PhysicalSimpleAggregate::Sink(ExecutionContext &context, GlobalOperatorStat
 				payload_expr_idx++;
 				payload_cnt++;
 			}
-		} else {
-			payload_cnt++;
 		}
+
 		// perform the actual aggregation
-		aggregate.function.simple_update(&payload_chunk.data[payload_idx], payload_cnt,
+		aggregate.function.simple_update(payload_cnt == 0 ? nullptr : &payload_chunk.data[payload_idx], payload_cnt,
 		                                 sink.state.aggregates[aggr_idx].get(), payload_chunk.size());
 		payload_idx += payload_cnt;
 	}
@@ -153,7 +147,6 @@ void PhysicalSimpleAggregate::Combine(ExecutionContext &context, GlobalOperatorS
 
 			aggregate.function.combine(source_state, dest_state, 1);
 		}
-		source.state.Clear();
 	} else {
 		// complex aggregates: this is necessarily a non-parallel aggregate
 		// simply move over the source state into the global state
@@ -176,9 +169,20 @@ void PhysicalSimpleAggregate::GetChunkInternal(ExecutionContext &context, DataCh
 		auto &aggregate = (BoundAggregateExpression &)*aggregates[aggr_idx];
 
 		Vector state_vector(Value::POINTER((uintptr_t)gstate.state.aggregates[aggr_idx].get()));
-		aggregate.function.finalize(state_vector, chunk.data[aggr_idx], 1);
+		aggregate.function.finalize(state_vector, aggregate.bind_info.get(), chunk.data[aggr_idx], 1);
 	}
 	state->finished = true;
 }
 
+string PhysicalSimpleAggregate::ParamsToString() const {
+	string result;
+	for (idx_t i = 0; i < aggregates.size(); i++) {
+		if (i > 0) {
+			result += "\n";
+		}
+		result += aggregates[i]->GetName();
+	}
+	return result;
+}
+
 } // namespace duckdb
