@@ -13,6 +13,26 @@ using namespace std;
 
 namespace duckdb {
 
+class WindowGlobalState : public GlobalOperatorState {
+public:
+	WindowGlobalState(PhysicalWindow &_op, ClientContext &context) : op(_op) {
+	}
+
+	PhysicalWindow &op;
+	std::mutex lock;
+	ChunkCollection chunks;
+	ChunkCollection window_results;
+};
+
+class WindowLocalState : public LocalSinkState {
+public:
+	WindowLocalState(PhysicalWindow &_op) : op(_op) {
+	}
+
+	PhysicalWindow &op;
+	ChunkCollection chunks;
+};
+
 //! The operator state of the window
 class PhysicalWindowOperatorState : public PhysicalOperatorState {
 public:
@@ -21,18 +41,16 @@ public:
 	}
 
 	idx_t position;
-	ChunkCollection tuples;
-	ChunkCollection window_results;
 };
 
 // this implements a sorted window functions variant
 PhysicalWindow::PhysicalWindow(vector<LogicalType> types, vector<unique_ptr<Expression>> select_list,
                                PhysicalOperatorType type)
-    : PhysicalOperator(type, move(types)), select_list(move(select_list)) {
+    : PhysicalSink(type, move(types)), select_list(move(select_list)) {
 }
 
 static bool EqualsSubset(vector<Value> &a, vector<Value> &b, idx_t start, idx_t end) {
-	assert(start <= end);
+	D_ASSERT(start <= end);
 	for (idx_t i = start; i < end; i++) {
 		if (a[i] != b[i]) {
 			return false;
@@ -76,11 +94,11 @@ static void MaterializeExpressions(Expression **exprs, idx_t expr_count, ChunkCo
 		executor.AddExpression(*exprs[expr_idx]);
 	}
 
-	for (idx_t i = 0; i < input.chunks.size(); i++) {
+	for (idx_t i = 0; i < input.ChunkCount(); i++) {
 		DataChunk chunk;
 		chunk.Initialize(types);
 
-		executor.Execute(*input.chunks[i], chunk);
+		executor.Execute(input.GetChunk(i), chunk);
 
 		chunk.Verify();
 		output.Append(chunk);
@@ -120,22 +138,22 @@ static void SortCollectionForWindow(BoundWindowExpression *wexpr, ChunkCollectio
 		executor.AddExpression(*oexpr);
 	}
 
-	assert(sort_types.size() > 0);
+	D_ASSERT(sort_types.size() > 0);
 
 	// create a chunkcollection for the results of the expressions in the window definitions
-	for (idx_t i = 0; i < input.chunks.size(); i++) {
+	for (idx_t i = 0; i < input.ChunkCount(); i++) {
 		DataChunk sort_chunk;
 		sort_chunk.Initialize(sort_types);
 
-		executor.Execute(*input.chunks[i], sort_chunk);
+		executor.Execute(input.GetChunk(i), sort_chunk);
 
 		sort_chunk.Verify();
 		sort_collection.Append(sort_chunk);
 	}
 
-	assert(input.count == sort_collection.count);
+	D_ASSERT(input.Count() == sort_collection.Count());
 
-	auto sorted_vector = unique_ptr<idx_t[]>(new idx_t[input.count]);
+	auto sorted_vector = unique_ptr<idx_t[]>(new idx_t[input.Count()]);
 	sort_collection.Sort(orders, null_order_types, sorted_vector.get());
 
 	input.Reorder(sorted_vector.get());
@@ -164,7 +182,7 @@ static void UpdateWindowBoundaries(BoundWindowExpression *wexpr, ChunkCollection
                                    idx_t row_idx, ChunkCollection &boundary_start_collection,
                                    ChunkCollection &boundary_end_collection, WindowBoundariesState &bounds) {
 
-	if (input.column_count() > 0) {
+	if (input.ColumnCount() > 0) {
 		vector<Value> row_cur = input.GetRow(row_idx);
 		idx_t sort_col_count = wexpr->partitions.size() + wexpr->orders.size();
 
@@ -181,7 +199,7 @@ static void UpdateWindowBoundaries(BoundWindowExpression *wexpr, ChunkCollection
 
 			// find end of partition
 			bounds.partition_end =
-			    BinarySearchRightmost(input, row_cur, bounds.partition_start, input.count, wexpr->partitions.size()) +
+			    BinarySearchRightmost(input, row_cur, bounds.partition_start, input.Count(), wexpr->partitions.size()) +
 			    1;
 
 		} else if (!bounds.is_peer) {
@@ -213,17 +231,17 @@ static void UpdateWindowBoundaries(BoundWindowExpression *wexpr, ChunkCollection
 		bounds.window_start = bounds.peer_start;
 		break;
 	case WindowBoundary::UNBOUNDED_FOLLOWING:
-		assert(0); // disallowed
+		D_ASSERT(0); // disallowed
 		break;
 	case WindowBoundary::EXPR_PRECEDING: {
-		assert(boundary_start_collection.column_count() > 0);
+		D_ASSERT(boundary_start_collection.ColumnCount() > 0);
 		bounds.window_start =
 		    (int64_t)row_idx -
 		    boundary_start_collection.GetValue(0, wexpr->start_expr->IsScalar() ? 0 : row_idx).GetValue<int64_t>();
 		break;
 	}
 	case WindowBoundary::EXPR_FOLLOWING: {
-		assert(boundary_start_collection.column_count() > 0);
+		D_ASSERT(boundary_start_collection.ColumnCount() > 0);
 		bounds.window_start =
 		    row_idx +
 		    boundary_start_collection.GetValue(0, wexpr->start_expr->IsScalar() ? 0 : row_idx).GetValue<int64_t>();
@@ -236,7 +254,7 @@ static void UpdateWindowBoundaries(BoundWindowExpression *wexpr, ChunkCollection
 
 	switch (wexpr->end) {
 	case WindowBoundary::UNBOUNDED_PRECEDING:
-		assert(0); // disallowed
+		D_ASSERT(0); // disallowed
 		break;
 	case WindowBoundary::CURRENT_ROW_ROWS:
 		bounds.window_end = row_idx + 1;
@@ -248,13 +266,13 @@ static void UpdateWindowBoundaries(BoundWindowExpression *wexpr, ChunkCollection
 		bounds.window_end = bounds.partition_end;
 		break;
 	case WindowBoundary::EXPR_PRECEDING:
-		assert(boundary_end_collection.column_count() > 0);
+		D_ASSERT(boundary_end_collection.ColumnCount() > 0);
 		bounds.window_end =
 		    (int64_t)row_idx -
 		    boundary_end_collection.GetValue(0, wexpr->end_expr->IsScalar() ? 0 : row_idx).GetValue<int64_t>() + 1;
 		break;
 	case WindowBoundary::EXPR_FOLLOWING:
-		assert(boundary_end_collection.column_count() > 0);
+		D_ASSERT(boundary_end_collection.ColumnCount() > 0);
 		bounds.window_end =
 		    row_idx +
 		    boundary_end_collection.GetValue(0, wexpr->end_expr->IsScalar() ? 0 : row_idx).GetValue<int64_t>() + 1;
@@ -286,6 +304,8 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 		SortCollectionForWindow(wexpr, input, output, sort_collection);
 	}
 
+	// TODO we could evaluate those expressions in parallel
+
 	// evaluate inner expressions of window functions, could be more complex
 	ChunkCollection payload_collection;
 	vector<Expression *> exprs;
@@ -325,7 +345,8 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 	unique_ptr<WindowSegmentTree> segment_tree = nullptr;
 
 	if (wexpr->aggregate) {
-		segment_tree = make_unique<WindowSegmentTree>(*(wexpr->aggregate), wexpr->return_type, &payload_collection);
+		segment_tree = make_unique<WindowSegmentTree>(*(wexpr->aggregate), wexpr->bind_info.get(), wexpr->return_type,
+		                                              &payload_collection);
 	}
 
 	WindowBoundariesState bounds;
@@ -336,9 +357,9 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 	}
 
 	// this is the main loop, go through all sorted rows and compute window function result
-	for (idx_t row_idx = 0; row_idx < input.count; row_idx++) {
+	for (idx_t row_idx = 0; row_idx < input.Count(); row_idx++) {
 		// special case, OVER (), aggregate over everything
-		UpdateWindowBoundaries(wexpr, sort_collection, input.count, row_idx, boundary_start_collection,
+		UpdateWindowBoundaries(wexpr, sort_collection, input.Count(), row_idx, boundary_start_collection,
 		                       boundary_end_collection, bounds);
 		if (WindowNeedsRank(wexpr)) {
 			if (!bounds.is_same_partition || row_idx == 0) { // special case for first row, need to init
@@ -391,7 +412,7 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 			break;
 		}
 		case ExpressionType::WINDOW_NTILE: {
-			if (payload_collection.column_count() != 1) {
+			if (payload_collection.ColumnCount() != 1) {
 				throw Exception("NTILE needs a parameter");
 			}
 			auto n_param = payload_collection.GetValue(0, row_idx).GetValue<int64_t>();
@@ -404,14 +425,14 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 			}
 			int64_t n_size = (n_total / n_param);
 			// find the row idx within the group
-			assert(row_idx >= bounds.partition_start);
+			D_ASSERT(row_idx >= bounds.partition_start);
 			int64_t adjusted_row_idx = row_idx - bounds.partition_start;
 			// now compute the ntile
 			int64_t n_large = n_total - n_param * n_size;
 			int64_t i_small = n_large * (n_size + 1);
 			int64_t result_ntile;
 
-			assert((n_large * (n_size + 1) + (n_param - n_large) * n_size) == n_total);
+			D_ASSERT((n_large * (n_size + 1) + (n_param - n_large) * n_size) == n_total);
 
 			if (adjusted_row_idx < i_small) {
 				result_ntile = 1 + adjusted_row_idx / (n_size + 1);
@@ -419,7 +440,7 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 				result_ntile = 1 + n_large + (adjusted_row_idx - i_small) / n_size;
 			}
 			// result has to be between [1, NTILE]
-			assert(result_ntile >= 1 && result_ntile <= n_param);
+			D_ASSERT(result_ntile >= 1 && result_ntile <= n_param);
 			res = Value::Numeric(wexpr->return_type, result_ntile);
 			break;
 		}
@@ -470,64 +491,31 @@ static void ComputeWindowExpression(BoundWindowExpression *wexpr, ChunkCollectio
 
 void PhysicalWindow::GetChunkInternal(ExecutionContext &context, DataChunk &chunk, PhysicalOperatorState *state_) {
 	auto state = reinterpret_cast<PhysicalWindowOperatorState *>(state_);
-	ChunkCollection &big_data = state->tuples;
-	ChunkCollection &window_results = state->window_results;
 
-	// this is a blocking operator, so compute complete result on first invocation
-	if (state->position == 0) {
-		do {
-			children[0]->GetChunk(context, state->child_chunk, state->child_state.get());
-			big_data.Append(state->child_chunk);
-		} while (state->child_chunk.size() != 0);
+	auto &gstate = (WindowGlobalState &)*sink_state;
 
-		if (big_data.count == 0) {
-			return;
-		}
+	ChunkCollection &big_data = gstate.chunks;
+	ChunkCollection &window_results = gstate.window_results;
 
-		vector<LogicalType> window_types;
-		for (idx_t expr_idx = 0; expr_idx < select_list.size(); expr_idx++) {
-			window_types.push_back(select_list[expr_idx]->return_type);
-		}
-
-		for (idx_t i = 0; i < big_data.chunks.size(); i++) {
-			DataChunk window_chunk;
-			window_chunk.Initialize(window_types);
-			window_chunk.SetCardinality(big_data.chunks[i]->size());
-			for (idx_t col_idx = 0; col_idx < window_chunk.column_count(); col_idx++) {
-				window_chunk.data[col_idx].vector_type = VectorType::CONSTANT_VECTOR;
-				ConstantVector::SetNull(window_chunk.data[col_idx], true);
-			}
-
-			window_chunk.Verify();
-			window_results.Append(window_chunk);
-		}
-
-		assert(window_results.column_count() == select_list.size());
-		idx_t window_output_idx = 0;
-		// we can have multiple window functions
-		for (idx_t expr_idx = 0; expr_idx < select_list.size(); expr_idx++) {
-			assert(select_list[expr_idx]->GetExpressionClass() == ExpressionClass::BOUND_WINDOW);
-			// sort by partition and order clause in window def
-			auto wexpr = reinterpret_cast<BoundWindowExpression *>(select_list[expr_idx].get());
-			ComputeWindowExpression(wexpr, big_data, window_results, window_output_idx++);
-		}
+	if (big_data.Count() == 0) {
+		return;
 	}
 
-	if (state->position >= big_data.count) {
+	if (state->position >= big_data.Count()) {
 		return;
 	}
 
 	// just return what was computed before, appending the result cols of the window expressions at the end
-	auto &proj_ch = big_data.GetChunk(state->position);
-	auto &wind_ch = window_results.GetChunk(state->position);
+	auto &proj_ch = big_data.GetChunkForRow(state->position);
+	auto &wind_ch = window_results.GetChunkForRow(state->position);
 
 	idx_t out_idx = 0;
-	assert(proj_ch.size() == wind_ch.size());
+	D_ASSERT(proj_ch.size() == wind_ch.size());
 	chunk.SetCardinality(proj_ch);
-	for (idx_t col_idx = 0; col_idx < proj_ch.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < proj_ch.ColumnCount(); col_idx++) {
 		chunk.data[out_idx++].Reference(proj_ch.data[col_idx]);
 	}
-	for (idx_t col_idx = 0; col_idx < wind_ch.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < wind_ch.ColumnCount(); col_idx++) {
 		chunk.data[out_idx++].Reference(wind_ch.data[col_idx]);
 	}
 	state->position += STANDARD_VECTOR_SIZE;
@@ -537,4 +525,76 @@ unique_ptr<PhysicalOperatorState> PhysicalWindow::GetOperatorState() {
 	return make_unique<PhysicalWindowOperatorState>(*this, children[0].get());
 }
 
+void PhysicalWindow::Sink(ExecutionContext &context, GlobalOperatorState &state, LocalSinkState &lstate_,
+                          DataChunk &input) {
+	auto &lstate = (WindowLocalState &)lstate_;
+	lstate.chunks.Append(input);
+}
+
+void PhysicalWindow::Combine(ExecutionContext &context, GlobalOperatorState &gstate_, LocalSinkState &lstate_) {
+	auto &gstate = (WindowGlobalState &)gstate_;
+	auto &lstate = (WindowLocalState &)lstate_;
+	lock_guard<mutex> glock(gstate.lock);
+	gstate.chunks.Merge(lstate.chunks);
+}
+
+void PhysicalWindow::Finalize(Pipeline &pipeline, ClientContext &context, unique_ptr<GlobalOperatorState> gstate_) {
+	this->sink_state = move(gstate_);
+	auto &gstate = (WindowGlobalState &)*this->sink_state;
+
+	ChunkCollection &big_data = gstate.chunks;
+	ChunkCollection &window_results = gstate.window_results;
+
+	if (big_data.Count() == 0) {
+		return;
+	}
+
+	vector<LogicalType> window_types;
+	for (idx_t expr_idx = 0; expr_idx < select_list.size(); expr_idx++) {
+		window_types.push_back(select_list[expr_idx]->return_type);
+	}
+
+	for (idx_t i = 0; i < big_data.ChunkCount(); i++) {
+		DataChunk window_chunk;
+		window_chunk.Initialize(window_types);
+		window_chunk.SetCardinality(big_data.GetChunk(i).size());
+		for (idx_t col_idx = 0; col_idx < window_chunk.ColumnCount(); col_idx++) {
+			window_chunk.data[col_idx].vector_type = VectorType::CONSTANT_VECTOR;
+			ConstantVector::SetNull(window_chunk.data[col_idx], true);
+		}
+
+		window_chunk.Verify();
+		window_results.Append(window_chunk);
+	}
+
+	D_ASSERT(window_results.ColumnCount() == select_list.size());
+	idx_t window_output_idx = 0;
+	// we can have multiple window functions
+	for (idx_t expr_idx = 0; expr_idx < select_list.size(); expr_idx++) {
+		D_ASSERT(select_list[expr_idx]->GetExpressionClass() == ExpressionClass::BOUND_WINDOW);
+		// sort by partition and order clause in window def
+		auto wexpr = reinterpret_cast<BoundWindowExpression *>(select_list[expr_idx].get());
+		ComputeWindowExpression(wexpr, big_data, window_results, window_output_idx++);
+	}
+}
+
+unique_ptr<LocalSinkState> PhysicalWindow::GetLocalSinkState(ExecutionContext &context) {
+	return make_unique<WindowLocalState>(*this);
+}
+
+unique_ptr<GlobalOperatorState> PhysicalWindow::GetGlobalState(ClientContext &context) {
+	return make_unique<WindowGlobalState>(*this, context);
+}
+
+string PhysicalWindow::ParamsToString() const {
+	string result;
+	for (idx_t i = 0; i < select_list.size(); i++) {
+		if (i > 0) {
+			result += "\n";
+		}
+		result += select_list[i]->GetName();
+	}
+	return result;
+}
+
 } // namespace duckdb
