@@ -17,7 +17,7 @@ public:
 
 PhysicalFilter::PhysicalFilter(vector<LogicalType> types, vector<unique_ptr<Expression>> select_list)
     : PhysicalOperator(PhysicalOperatorType::FILTER, move(types)) {
-	assert(select_list.size() > 0);
+	D_ASSERT(select_list.size() > 0);
 	if (select_list.size() > 1) {
 		// create a big AND out of the expressions
 		auto conjunction = make_unique<BoundConjunctionExpression>(ExpressionType::CONJUNCTION_AND);
