@@ -6,7 +6,8 @@ namespace duckdb {
 
 void PhysicalPragma::GetChunkInternal(ExecutionContext &context, DataChunk &chunk, PhysicalOperatorState *state) {
 	auto &client = context.client;
-	function.function(client, info.parameters);
+	FunctionParameters parameters{info.parameters, info.named_parameters};
+	function.function(client, parameters);
 }
 
 } // namespace duckdb
