@@ -38,17 +38,17 @@ void PhysicalComparisonJoin::ConstructEmptyJoinResult(JoinType join_type, bool h
 	if (join_type == JoinType::ANTI) {
 		// anti join with empty hash table, NOP join
 		// return the input
-		assert(input.column_count() == result.column_count());
+		D_ASSERT(input.ColumnCount() == result.ColumnCount());
 		result.Reference(input);
 	} else if (join_type == JoinType::MARK) {
 		// MARK join with empty hash table
-		assert(join_type == JoinType::MARK);
-		assert(result.column_count() == input.column_count() + 1);
+		D_ASSERT(join_type == JoinType::MARK);
+		D_ASSERT(result.ColumnCount() == input.ColumnCount() + 1);
 		auto &result_vector = result.data.back();
-		assert(result_vector.type == LogicalType::BOOLEAN);
+		D_ASSERT(result_vector.type == LogicalType::BOOLEAN);
 		// for every data vector, we just reference the child chunk
 		result.SetCardinality(input);
-		for (idx_t i = 0; i < input.column_count(); i++) {
+		for (idx_t i = 0; i < input.ColumnCount(); i++) {
 			result.data[i].Reference(input.data[i]);
 		}
 		// for the MARK vector:
@@ -67,11 +67,11 @@ void PhysicalComparisonJoin::ConstructEmptyJoinResult(JoinType join_type, bool h
 		// LEFT/FULL OUTER/SINGLE join and build side is empty
 		// for the LHS we reference the data
 		result.SetCardinality(input.size());
-		for (idx_t i = 0; i < input.column_count(); i++) {
+		for (idx_t i = 0; i < input.ColumnCount(); i++) {
 			result.data[i].Reference(input.data[i]);
 		}
 		// for the RHS
-		for (idx_t k = input.column_count(); k < result.column_count(); k++) {
+		for (idx_t k = input.ColumnCount(); k < result.ColumnCount(); k++) {
 			result.data[k].vector_type = VectorType::CONSTANT_VECTOR;
 			ConstantVector::SetNull(result.data[k], true);
 		}
@@ -82,8 +82,8 @@ void PhysicalComparisonJoin::ConstructFullOuterJoinResult(bool *found_match, Chu
                                                           idx_t &scan_position) {
 	// fill in NULL values for the LHS
 	SelectionVector rsel(STANDARD_VECTOR_SIZE);
-	while (scan_position < input.count) {
-		auto &rhs_chunk = *input.chunks[scan_position / STANDARD_VECTOR_SIZE];
+	while (scan_position < input.Count()) {
+		auto &rhs_chunk = input.GetChunk(scan_position / STANDARD_VECTOR_SIZE);
 		idx_t result_count = 0;
 		// figure out which tuples didn't find a match in the RHS
 		for (idx_t i = 0; i < rhs_chunk.size(); i++) {
@@ -94,12 +94,12 @@ void PhysicalComparisonJoin::ConstructFullOuterJoinResult(bool *found_match, Chu
 		scan_position += STANDARD_VECTOR_SIZE;
 		if (result_count > 0) {
 			// if there were any tuples that didn't find a match, output them
-			idx_t left_column_count = result.column_count() - input.column_count();
+			idx_t left_column_count = result.ColumnCount() - input.ColumnCount();
 			for (idx_t i = 0; i < left_column_count; i++) {
 				result.data[i].vector_type = VectorType::CONSTANT_VECTOR;
 				ConstantVector::SetNull(result.data[i], true);
 			}
-			for (idx_t col_idx = 0; col_idx < rhs_chunk.column_count(); col_idx++) {
+			for (idx_t col_idx = 0; col_idx < rhs_chunk.ColumnCount(); col_idx++) {
 				result.data[left_column_count + col_idx].Slice(rhs_chunk.data[col_idx], rsel, result_count);
 			}
 			result.SetCardinality(result_count);
