@@ -9,7 +9,7 @@ class PhysicalCrossProductOperatorState : public PhysicalOperatorState {
 public:
 	PhysicalCrossProductOperatorState(PhysicalOperator &op, PhysicalOperator *left, PhysicalOperator *right)
 	    : PhysicalOperatorState(op, left), left_position(0) {
-		assert(left && right);
+		D_ASSERT(left && right);
 	}
 
 	idx_t left_position;
@@ -28,7 +28,7 @@ void PhysicalCrossProduct::GetChunkInternal(ExecutionContext &context, DataChunk
                                             PhysicalOperatorState *state_) {
 	auto state = reinterpret_cast<PhysicalCrossProductOperatorState *>(state_);
 	// first we fully materialize the right child, if we haven't done that yet
-	if (state->right_data.column_count() == 0) {
+	if (state->right_data.ColumnCount() == 0) {
 		auto right_state = children[1]->GetOperatorState();
 		auto types = children[1]->GetTypes();
 
@@ -42,7 +42,7 @@ void PhysicalCrossProduct::GetChunkInternal(ExecutionContext &context, DataChunk
 			state->right_data.Append(new_chunk);
 		} while (new_chunk.size() > 0);
 
-		if (state->right_data.count == 0) {
+		if (state->right_data.Count() == 0) {
 			return;
 		}
 		state->left_position = 0;
@@ -56,18 +56,18 @@ void PhysicalCrossProduct::GetChunkInternal(ExecutionContext &context, DataChunk
 	}
 
 	auto &left_chunk = state->child_chunk;
-	auto &right_chunk = *state->right_data.chunks[state->right_position];
+	auto &right_chunk = state->right_data.GetChunk(state->right_position);
 	// now match the current row of the left relation with the current chunk
 	// from the right relation
 	chunk.SetCardinality(right_chunk.size());
-	for (idx_t i = 0; i < left_chunk.column_count(); i++) {
+	for (idx_t i = 0; i < left_chunk.ColumnCount(); i++) {
 		// first duplicate the values of the left side
 		auto lvalue = left_chunk.GetValue(i, state->left_position);
 		chunk.data[i].Reference(lvalue);
 	}
-	for (idx_t i = 0; i < right_chunk.column_count(); i++) {
+	for (idx_t i = 0; i < right_chunk.ColumnCount(); i++) {
 		// now create a reference to the vectors of the right chunk
-		chunk.data[left_chunk.column_count() + i].Reference(right_chunk.data[i]);
+		chunk.data[left_chunk.ColumnCount() + i].Reference(right_chunk.data[i]);
 	}
 
 	// for the next iteration, move to the next position on the left side
@@ -77,7 +77,7 @@ void PhysicalCrossProduct::GetChunkInternal(ExecutionContext &context, DataChunk
 		// move to the next chunk on the right side
 		state->left_position = 0;
 		state->right_position++;
-		if (state->right_position >= state->right_data.chunks.size()) {
+		if (state->right_position >= state->right_data.ChunkCount()) {
 			state->right_position = 0;
 			// move to the next chunk on the left side
 			children[0]->GetChunk(context, state->child_chunk, state->child_state.get());
