@@ -7,8 +7,8 @@ using namespace std;
 namespace duckdb {
 
 void PhysicalAlter::GetChunkInternal(ExecutionContext &context, DataChunk &chunk, PhysicalOperatorState *state) {
-	auto table_info = (AlterTableInfo *)info.get();
-	Catalog::GetCatalog(context.client).AlterTable(context.client, table_info);
+	auto &catalog = Catalog::GetCatalog(context.client);
+	catalog.Alter(context.client, info.get());
 	state->finished = true;
 }
 
