@@ -7,12 +7,12 @@ namespace duckdb {
 using namespace std;
 
 unique_ptr<PhysicalOperator> PhysicalPlanGenerator::CreatePlan(LogicalProjection &op) {
-	assert(op.children.size() == 1);
+	D_ASSERT(op.children.size() == 1);
 	auto plan = CreatePlan(*op.children[0]);
 
 #ifdef DEBUG
 	for (auto &expr : op.expressions) {
-		assert(!expr->IsWindow() && !expr->IsAggregate());
+		D_ASSERT(!expr->IsWindow() && !expr->IsAggregate());
 	}
 #endif
 	if (plan->types.size() == op.types.size()) {
