@@ -15,13 +15,13 @@ using namespace std;
 
 unique_ptr<PhysicalOperator> PhysicalPlanGenerator::CreatePlan(LogicalSimple &op) {
 	switch (op.type) {
-	case LogicalOperatorType::ALTER:
+	case LogicalOperatorType::LOGICAL_ALTER:
 		return make_unique<PhysicalAlter>(unique_ptr_cast<ParseInfo, AlterInfo>(move(op.info)));
-	case LogicalOperatorType::DROP:
+	case LogicalOperatorType::LOGICAL_DROP:
 		return make_unique<PhysicalDrop>(unique_ptr_cast<ParseInfo, DropInfo>(move(op.info)));
-	case LogicalOperatorType::TRANSACTION:
+	case LogicalOperatorType::LOGICAL_TRANSACTION:
 		return make_unique<PhysicalTransaction>(unique_ptr_cast<ParseInfo, TransactionInfo>(move(op.info)));
-	case LogicalOperatorType::VACUUM:
+	case LogicalOperatorType::LOGICAL_VACUUM:
 		return make_unique<PhysicalVacuum>(unique_ptr_cast<ParseInfo, VacuumInfo>(move(op.info)));
 	default:
 		throw NotImplementedException("Unimplemented type for logical simple operator");
