@@ -51,82 +51,83 @@ unique_ptr<PhysicalOperator> PhysicalPlanGenerator::CreatePlan(unique_ptr<Logica
 
 unique_ptr<PhysicalOperator> PhysicalPlanGenerator::CreatePlan(LogicalOperator &op) {
 	switch (op.type) {
-	case LogicalOperatorType::GET:
+	case LogicalOperatorType::LOGICAL_GET:
 		return CreatePlan((LogicalGet &)op);
-	case LogicalOperatorType::PROJECTION:
+	case LogicalOperatorType::LOGICAL_PROJECTION:
 		return CreatePlan((LogicalProjection &)op);
-	case LogicalOperatorType::EMPTY_RESULT:
+	case LogicalOperatorType::LOGICAL_EMPTY_RESULT:
 		return CreatePlan((LogicalEmptyResult &)op);
-	case LogicalOperatorType::FILTER:
+	case LogicalOperatorType::LOGICAL_FILTER:
 		return CreatePlan((LogicalFilter &)op);
-	case LogicalOperatorType::AGGREGATE_AND_GROUP_BY:
+	case LogicalOperatorType::LOGICAL_AGGREGATE_AND_GROUP_BY:
 		return CreatePlan((LogicalAggregate &)op);
-	case LogicalOperatorType::WINDOW:
+	case LogicalOperatorType::LOGICAL_WINDOW:
 		return CreatePlan((LogicalWindow &)op);
-	case LogicalOperatorType::UNNEST:
+	case LogicalOperatorType::LOGICAL_UNNEST:
 		return CreatePlan((LogicalUnnest &)op);
-	case LogicalOperatorType::LIMIT:
+	case LogicalOperatorType::LOGICAL_LIMIT:
 		return CreatePlan((LogicalLimit &)op);
-	case LogicalOperatorType::ORDER_BY:
+	case LogicalOperatorType::LOGICAL_ORDER_BY:
 		return CreatePlan((LogicalOrder &)op);
-	case LogicalOperatorType::TOP_N:
+	case LogicalOperatorType::LOGICAL_TOP_N:
 		return CreatePlan((LogicalTopN &)op);
-	case LogicalOperatorType::COPY_TO_FILE:
+	case LogicalOperatorType::LOGICAL_COPY_TO_FILE:
 		return CreatePlan((LogicalCopyToFile &)op);
-	case LogicalOperatorType::DUMMY_SCAN:
+	case LogicalOperatorType::LOGICAL_DUMMY_SCAN:
 		return CreatePlan((LogicalDummyScan &)op);
-	case LogicalOperatorType::ANY_JOIN:
+	case LogicalOperatorType::LOGICAL_ANY_JOIN:
 		return CreatePlan((LogicalAnyJoin &)op);
-	case LogicalOperatorType::DELIM_JOIN:
+	case LogicalOperatorType::LOGICAL_DELIM_JOIN:
 		return CreatePlan((LogicalDelimJoin &)op);
-	case LogicalOperatorType::COMPARISON_JOIN:
+	case LogicalOperatorType::LOGICAL_COMPARISON_JOIN:
 		return CreatePlan((LogicalComparisonJoin &)op);
-	case LogicalOperatorType::CROSS_PRODUCT:
+	case LogicalOperatorType::LOGICAL_CROSS_PRODUCT:
 		return CreatePlan((LogicalCrossProduct &)op);
-	case LogicalOperatorType::UNION:
-	case LogicalOperatorType::EXCEPT:
-	case LogicalOperatorType::INTERSECT:
+	case LogicalOperatorType::LOGICAL_UNION:
+	case LogicalOperatorType::LOGICAL_EXCEPT:
+	case LogicalOperatorType::LOGICAL_INTERSECT:
 		return CreatePlan((LogicalSetOperation &)op);
-	case LogicalOperatorType::INSERT:
+	case LogicalOperatorType::LOGICAL_INSERT:
 		return CreatePlan((LogicalInsert &)op);
-	case LogicalOperatorType::DELETE:
+	case LogicalOperatorType::LOGICAL_DELETE:
 		return CreatePlan((LogicalDelete &)op);
-	case LogicalOperatorType::CHUNK_GET:
+	case LogicalOperatorType::LOGICAL_CHUNK_GET:
 		return CreatePlan((LogicalChunkGet &)op);
-	case LogicalOperatorType::DELIM_GET:
+	case LogicalOperatorType::LOGICAL_DELIM_GET:
 		return CreatePlan((LogicalDelimGet &)op);
-	case LogicalOperatorType::EXPRESSION_GET:
+	case LogicalOperatorType::LOGICAL_EXPRESSION_GET:
 		return CreatePlan((LogicalExpressionGet &)op);
-	case LogicalOperatorType::UPDATE:
+	case LogicalOperatorType::LOGICAL_UPDATE:
 		return CreatePlan((LogicalUpdate &)op);
-	case LogicalOperatorType::CREATE_TABLE:
+	case LogicalOperatorType::LOGICAL_CREATE_TABLE:
 		return CreatePlan((LogicalCreateTable &)op);
-	case LogicalOperatorType::CREATE_INDEX:
+	case LogicalOperatorType::LOGICAL_CREATE_INDEX:
 		return CreatePlan((LogicalCreateIndex &)op);
-	case LogicalOperatorType::EXPLAIN:
+	case LogicalOperatorType::LOGICAL_EXPLAIN:
 		return CreatePlan((LogicalExplain &)op);
-	case LogicalOperatorType::DISTINCT:
+	case LogicalOperatorType::LOGICAL_DISTINCT:
 		return CreatePlan((LogicalDistinct &)op);
-	case LogicalOperatorType::PREPARE:
+	case LogicalOperatorType::LOGICAL_PREPARE:
 		return CreatePlan((LogicalPrepare &)op);
-	case LogicalOperatorType::EXECUTE:
+	case LogicalOperatorType::LOGICAL_EXECUTE:
 		return CreatePlan((LogicalExecute &)op);
-	case LogicalOperatorType::CREATE_VIEW:
-	case LogicalOperatorType::CREATE_SEQUENCE:
-	case LogicalOperatorType::CREATE_SCHEMA:
+	case LogicalOperatorType::LOGICAL_CREATE_VIEW:
+	case LogicalOperatorType::LOGICAL_CREATE_SEQUENCE:
+	case LogicalOperatorType::LOGICAL_CREATE_SCHEMA:
+	case LogicalOperatorType::LOGICAL_CREATE_MACRO:
 		return CreatePlan((LogicalCreate &)op);
-	case LogicalOperatorType::PRAGMA:
+	case LogicalOperatorType::LOGICAL_PRAGMA:
 		return CreatePlan((LogicalPragma &)op);
-	case LogicalOperatorType::TRANSACTION:
-	case LogicalOperatorType::ALTER:
-	case LogicalOperatorType::DROP:
-	case LogicalOperatorType::VACUUM:
+	case LogicalOperatorType::LOGICAL_TRANSACTION:
+	case LogicalOperatorType::LOGICAL_ALTER:
+	case LogicalOperatorType::LOGICAL_DROP:
+	case LogicalOperatorType::LOGICAL_VACUUM:
 		return CreatePlan((LogicalSimple &)op);
-	case LogicalOperatorType::RECURSIVE_CTE:
+	case LogicalOperatorType::LOGICAL_RECURSIVE_CTE:
 		return CreatePlan((LogicalRecursiveCTE &)op);
-	case LogicalOperatorType::CTE_REF:
+	case LogicalOperatorType::LOGICAL_CTE_REF:
 		return CreatePlan((LogicalCTERef &)op);
-	case LogicalOperatorType::EXPORT:
+	case LogicalOperatorType::LOGICAL_EXPORT:
 		return CreatePlan((LogicalExport &)op);
 	default:
 		throw NotImplementedException("Unimplemented logical operator type!");
