@@ -8,25 +8,46 @@
 namespace duckdb {
 using namespace std;
 
-WindowSegmentTree::WindowSegmentTree(AggregateFunction &aggregate, LogicalType result_type, ChunkCollection *input)
-    : aggregate(aggregate), state(aggregate.state_size()), statep(LogicalTypeId::POINTER), result_type(result_type),
-      input_ref(input) {
+WindowSegmentTree::WindowSegmentTree(AggregateFunction &aggregate, FunctionData *bind_info, LogicalType result_type,
+                                     ChunkCollection *input)
+    : aggregate(aggregate), bind_info(bind_info), result_type(result_type), state(aggregate.state_size()),
+      internal_nodes(0), input_ref(input) {
 #if STANDARD_VECTOR_SIZE < 512
 	throw NotImplementedException("Window functions are not supported for vector sizes < 512");
 #endif
-
 	Value ptr_val = Value::POINTER((idx_t)state.data());
 	statep.Reference(ptr_val);
 	statep.Normalify(STANDARD_VECTOR_SIZE);
 
-	if (input_ref && input_ref->column_count() > 0) {
-		inputs.Initialize(input_ref->types);
+	if (input_ref && input_ref->ColumnCount() > 0) {
+		inputs.Initialize(input_ref->Types());
 		if (aggregate.combine) {
 			ConstructTree();
 		}
 	}
 }
 
+WindowSegmentTree::~WindowSegmentTree() {
+	if (!aggregate.destructor) {
+		// nothing to destroy
+		return;
+	}
+	// call the destructor for all the intermediate states
+	uint64_t address_data[STANDARD_VECTOR_SIZE];
+	Vector addresses(LogicalType::POINTER, (data_ptr_t)address_data);
+	idx_t count = 0;
+	for (idx_t i = 0; i < internal_nodes; i++) {
+		address_data[count++] = uint64_t(levels_flat_native.get() + i * state.size());
+		if (count == STANDARD_VECTOR_SIZE) {
+			aggregate.destructor(addresses, count);
+			count = 0;
+		}
+	}
+	if (count > 0) {
+		aggregate.destructor(addresses, count);
+	}
+}
+
 void WindowSegmentTree::AggregateInit() {
 	aggregate.initialize(state.data());
 }
@@ -36,26 +57,29 @@ Value WindowSegmentTree::AggegateFinal() {
 	Vector result(result_type);
 	result.vector_type = VectorType::CONSTANT_VECTOR;
 	ConstantVector::SetNull(result, false);
-	aggregate.finalize(statev, result, 1);
+	aggregate.finalize(statev, bind_info, result, 1);
 
+	if (aggregate.destructor) {
+		aggregate.destructor(statev, 1);
+	}
 	return result.GetValue(0);
 }
 
 void WindowSegmentTree::WindowSegmentValue(idx_t l_idx, idx_t begin, idx_t end) {
-	assert(begin <= end);
+	D_ASSERT(begin <= end);
 	if (begin == end) {
 		return;
 	}
 	inputs.Reset();
 	inputs.SetCardinality(end - begin);
 
-	idx_t start_in_vector = begin % STANDARD_VECTOR_SIZE;
 	Vector s;
 	s.Slice(statep, 0);
+	idx_t start_in_vector = begin % STANDARD_VECTOR_SIZE;
 	if (l_idx == 0) {
-		const auto input_count = input_ref->column_count();
+		const auto input_count = input_ref->ColumnCount();
 		if (start_in_vector + inputs.size() < STANDARD_VECTOR_SIZE) {
-			auto &chunk = input_ref->GetChunk(begin);
+			auto &chunk = input_ref->GetChunkForRow(begin);
 			for (idx_t i = 0; i < input_count; ++i) {
 				auto &v = inputs.data[i];
 				auto &vec = chunk.data[i];
@@ -64,8 +88,8 @@ void WindowSegmentTree::WindowSegmentValue(idx_t l_idx, idx_t begin, idx_t end)
 			}
 		} else {
 			// we cannot just slice the individual vector!
-			auto &chunk_a = input_ref->GetChunk(begin);
-			auto &chunk_b = input_ref->GetChunk(end);
+			auto &chunk_a = input_ref->GetChunkForRow(begin);
+			auto &chunk_b = input_ref->GetChunkForRow(end);
 			idx_t chunk_a_count = chunk_a.size() - start_in_vector;
 			idx_t chunk_b_count = inputs.size() - chunk_a_count;
 			for (idx_t i = 0; i < input_count; ++i) {
@@ -76,7 +100,7 @@ void WindowSegmentTree::WindowSegmentValue(idx_t l_idx, idx_t begin, idx_t end)
 		}
 		aggregate.update(&inputs.data[0], input_count, s, inputs.size());
 	} else {
-		assert(end - begin <= STANDARD_VECTOR_SIZE);
+		D_ASSERT(end - begin <= STANDARD_VECTOR_SIZE);
 		// find out where the states begin
 		data_ptr_t begin_ptr = levels_flat_native.get() + state.size() * (begin + levels_flat_start[l_idx - 1]);
 		// set up a vector of pointers that point towards the set of states
@@ -91,14 +115,14 @@ void WindowSegmentTree::WindowSegmentValue(idx_t l_idx, idx_t begin, idx_t end)
 }
 
 void WindowSegmentTree::ConstructTree() {
-	assert(input_ref);
-	assert(inputs.column_count() > 0);
+	D_ASSERT(input_ref);
+	D_ASSERT(inputs.ColumnCount() > 0);
 
 	// compute space required to store internal nodes of segment tree
-	idx_t internal_nodes = 0;
-	idx_t level_nodes = input_ref->count;
+	internal_nodes = 0;
+	idx_t level_nodes = input_ref->Count();
 	do {
-		level_nodes = (idx_t)ceil((double)level_nodes / TREE_FANOUT);
+		level_nodes = (level_nodes + (TREE_FANOUT - 1)) / TREE_FANOUT;
 		internal_nodes += level_nodes;
 	} while (level_nodes > 1);
 	levels_flat_native = unique_ptr<data_t[]>(new data_t[internal_nodes * state.size()]);
@@ -108,9 +132,11 @@ void WindowSegmentTree::ConstructTree() {
 	idx_t level_current = 0;
 	// level 0 is data itself
 	idx_t level_size;
-	while ((level_size = (level_current == 0 ? input_ref->count
+	// iterate over the levels of the segment tree
+	while ((level_size = (level_current == 0 ? input_ref->Count()
 	                                         : levels_flat_offset - levels_flat_start[level_current - 1])) > 1) {
 		for (idx_t pos = 0; pos < level_size; pos += TREE_FANOUT) {
+			// compute the aggregate for this entry in the segment tree
 			AggregateInit();
 			WindowSegmentValue(level_current, pos, min(level_size, pos + TREE_FANOUT));
 
@@ -125,10 +151,10 @@ void WindowSegmentTree::ConstructTree() {
 }
 
 Value WindowSegmentTree::Compute(idx_t begin, idx_t end) {
-	assert(input_ref);
+	D_ASSERT(input_ref);
 
 	// No arguments, so just count
-	if (inputs.column_count() == 0) {
+	if (inputs.ColumnCount() == 0) {
 		return Value::Numeric(result_type, end - begin);
 	}
 
@@ -137,6 +163,10 @@ Value WindowSegmentTree::Compute(idx_t begin, idx_t end) {
 	// Aggregate everything at once if we can't combine states
 	if (!aggregate.combine) {
 		WindowSegmentValue(0, begin, end);
+		if (end - begin >= STANDARD_VECTOR_SIZE) {
+			throw InternalException(
+			    "Cannot compute window aggregation: bounds are too large for non-combinable aggregate");
+		}
 		return AggegateFinal();
 	}
 
