@@ -4,8 +4,11 @@ namespace duckdb {
 using namespace std;
 
 void BuiltinFunctions::RegisterGenericFunctions() {
+	Register<AliasFun>();
 	Register<LeastFun>();
 	Register<GreatestFun>();
+	Register<StatsFun>();
+	Register<TypeOfFun>();
 }
 
 } // namespace duckdb
