@@ -16,9 +16,9 @@ static void concat_function(DataChunk &args, ExpressionState &state, Vector &res
 	// iterate over the vectors to count how large the final string will be
 	idx_t constant_lengths = 0;
 	vector<idx_t> result_lengths(args.size(), 0);
-	for (idx_t col_idx = 0; col_idx < args.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < args.ColumnCount(); col_idx++) {
 		auto &input = args.data[col_idx];
-		assert(input.type.id() == LogicalTypeId::VARCHAR);
+		D_ASSERT(input.type.id() == LogicalTypeId::VARCHAR);
 		if (input.vector_type == VectorType::CONSTANT_VECTOR) {
 			if (ConstantVector::IsNull(input)) {
 				// constant null, skip
@@ -56,7 +56,7 @@ static void concat_function(DataChunk &args, ExpressionState &state, Vector &res
 	}
 
 	// now that the empty space for the strings has been allocated, perform the concatenation
-	for (idx_t col_idx = 0; col_idx < args.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < args.ColumnCount(); col_idx++) {
 		auto &input = args.data[col_idx];
 
 		// loop over the vector and concat to all results
@@ -68,10 +68,10 @@ static void concat_function(DataChunk &args, ExpressionState &state, Vector &res
 			}
 			// append the constant vector to each of the strings
 			auto input_data = ConstantVector::GetData<string_t>(input);
-			auto input_ptr = input_data->GetData();
+			auto input_ptr = input_data->GetDataUnsafe();
 			auto input_len = input_data->GetSize();
 			for (idx_t i = 0; i < args.size(); i++) {
-				memcpy(result_data[i].GetData() + result_lengths[i], input_ptr, input_len);
+				memcpy(result_data[i].GetDataWriteable() + result_lengths[i], input_ptr, input_len);
 				result_lengths[i] += input_len;
 			}
 		} else {
@@ -85,9 +85,9 @@ static void concat_function(DataChunk &args, ExpressionState &state, Vector &res
 				if ((*idata.nullmask)[idx]) {
 					continue;
 				}
-				auto input_ptr = input_data[idx].GetData();
+				auto input_ptr = input_data[idx].GetDataUnsafe();
 				auto input_len = input_data[idx].GetSize();
-				memcpy(result_data[i].GetData() + result_lengths[i], input_ptr, input_len);
+				memcpy(result_data[i].GetDataWriteable() + result_lengths[i], input_ptr, input_len);
 				result_lengths[i] += input_len;
 			}
 		}
@@ -100,14 +100,14 @@ static void concat_function(DataChunk &args, ExpressionState &state, Vector &res
 static void concat_operator(DataChunk &args, ExpressionState &state, Vector &result) {
 	BinaryExecutor::Execute<string_t, string_t, string_t, true>(
 	    args.data[0], args.data[1], result, args.size(), [&](string_t a, string_t b) {
-		    auto a_data = a.GetData();
-		    auto b_data = b.GetData();
+		    auto a_data = a.GetDataUnsafe();
+		    auto b_data = b.GetDataUnsafe();
 		    auto a_length = a.GetSize();
 		    auto b_length = b.GetSize();
 
 		    auto target_length = a_length + b_length;
 		    auto target = StringVector::EmptyString(result, target_length);
-		    auto target_data = target.GetData();
+		    auto target_data = target.GetDataWriteable();
 
 		    memcpy(target_data, a_data, a_length);
 		    memcpy(target_data + a_length, b_data, b_length);
@@ -120,13 +120,13 @@ static void templated_concat_ws(DataChunk &args, string_t *sep_data, const Selec
                                 const SelectionVector &rsel, idx_t count, Vector &result) {
 	vector<idx_t> result_lengths(args.size(), 0);
 	vector<bool> has_results(args.size(), false);
-	auto orrified_data = unique_ptr<VectorData[]>(new VectorData[args.column_count() - 1]);
-	for (idx_t col_idx = 1; col_idx < args.column_count(); col_idx++) {
+	auto orrified_data = unique_ptr<VectorData[]>(new VectorData[args.ColumnCount() - 1]);
+	for (idx_t col_idx = 1; col_idx < args.ColumnCount(); col_idx++) {
 		args.data[col_idx].Orrify(args.size(), orrified_data[col_idx - 1]);
 	}
 
 	// first figure out the lengths
-	for (idx_t col_idx = 1; col_idx < args.column_count(); col_idx++) {
+	for (idx_t col_idx = 1; col_idx < args.ColumnCount(); col_idx++) {
 		auto &idata = orrified_data[col_idx - 1];
 
 		auto input_data = (string_t *)idata.data;
@@ -157,7 +157,7 @@ static void templated_concat_ws(DataChunk &args, string_t *sep_data, const Selec
 	}
 
 	// now that the empty space for the strings has been allocated, perform the concatenation
-	for (idx_t col_idx = 1; col_idx < args.column_count(); col_idx++) {
+	for (idx_t col_idx = 1; col_idx < args.ColumnCount(); col_idx++) {
 		auto &idata = orrified_data[col_idx - 1];
 		auto input_data = (string_t *)idata.data;
 		for (idx_t i = 0; i < count; i++) {
@@ -169,13 +169,13 @@ static void templated_concat_ws(DataChunk &args, string_t *sep_data, const Selec
 			}
 			if (has_results[ridx]) {
 				auto sep_size = sep_data[sep_idx].GetSize();
-				auto sep_ptr = sep_data[sep_idx].GetData();
-				memcpy(result_data[ridx].GetData() + result_lengths[ridx], sep_ptr, sep_size);
+				auto sep_ptr = sep_data[sep_idx].GetDataUnsafe();
+				memcpy(result_data[ridx].GetDataWriteable() + result_lengths[ridx], sep_ptr, sep_size);
 				result_lengths[ridx] += sep_size;
 			}
-			auto input_ptr = input_data[idx].GetData();
+			auto input_ptr = input_data[idx].GetDataUnsafe();
 			auto input_len = input_data[idx].GetSize();
-			memcpy(result_data[ridx].GetData() + result_lengths[ridx], input_ptr, input_len);
+			memcpy(result_data[ridx].GetDataWriteable() + result_lengths[ridx], input_ptr, input_len);
 			result_lengths[ridx] += input_len;
 			has_results[ridx] = true;
 		}
@@ -192,7 +192,7 @@ static void concat_ws_function(DataChunk &args, ExpressionState &state, Vector &
 	separator.Orrify(args.size(), vdata);
 
 	result.vector_type = VectorType::CONSTANT_VECTOR;
-	for (idx_t col_idx = 0; col_idx < args.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < args.ColumnCount(); col_idx++) {
 		if (args.data[col_idx].vector_type != VectorType::CONSTANT_VECTOR) {
 			result.vector_type = VectorType::FLAT_VECTOR;
 			break;
