@@ -17,16 +17,15 @@ bool StripAccentsFun::IsAscii(const char *input, idx_t n) {
 }
 
 static void strip_accents_function(DataChunk &args, ExpressionState &state, Vector &result) {
-	assert(args.column_count() == 1);
+	D_ASSERT(args.ColumnCount() == 1);
 
 	UnaryExecutor::Execute<string_t, string_t, true>(args.data[0], result, args.size(), [&](string_t input) {
-		auto input_data = input.GetData();
-		auto input_length = input.GetSize();
-		if (StripAccentsFun::IsAscii(input_data, input_length)) {
+		if (StripAccentsFun::IsAscii(input.GetDataUnsafe(), input.GetSize())) {
 			return input;
 		}
+
 		// non-ascii, perform collation
-		auto stripped = utf8proc_remove_accents((const utf8proc_uint8_t *)input_data);
+		auto stripped = utf8proc_remove_accents((const utf8proc_uint8_t *)input.GetDataUnsafe(), input.GetSize());
 		auto result_str = StringVector::AddString(result, (const char *)stripped);
 		free(stripped);
 		return result_str;
