@@ -22,8 +22,8 @@ static bool suffix(const string_t &str, const string_t &suffix) {
 		return false;
 	}
 
-	auto suffix_data = suffix.GetData();
-	auto str_data = str.GetData();
+	auto suffix_data = suffix.GetDataUnsafe();
+	auto str_data = str.GetDataUnsafe();
 	int32_t suf_idx = suffix_size - 1;
 	idx_t str_idx = str_size - 1;
 	for (; suf_idx >= 0; --suf_idx, --str_idx) {
