@@ -126,8 +126,7 @@ static unique_ptr<FunctionData> arrow_scan_bind(ClientContext &context, vector<V
 }
 
 static unique_ptr<FunctionOperatorData> arrow_scan_init(ClientContext &context, const FunctionData *bind_data,
-                                                        vector<column_t> &column_ids,
-                                                        unordered_map<idx_t, vector<TableFilter>> &table_filters) {
+                                                        vector<column_t> &column_ids, TableFilterSet *table_filters) {
 	auto &data = (ArrowScanFunctionData &)*bind_data;
 	if (data.is_consumed) {
 		throw NotImplementedException("FIXME: Arrow streams can only be read once");
@@ -160,14 +159,14 @@ static void arrow_scan_function(ClientContext &context, const FunctionData *bind
 		return;
 	}
 
-	if ((idx_t)data.current_chunk_root.n_children != output.column_count()) {
+	if ((idx_t)data.current_chunk_root.n_children != output.ColumnCount()) {
 		throw InvalidInputException("arrow_scan: array column count mismatch");
 	}
 
 	output.SetCardinality(
 	    std::min((int64_t)STANDARD_VECTOR_SIZE, (int64_t)(data.current_chunk_root.length - data.chunk_offset)));
 
-	for (idx_t col_idx = 0; col_idx < output.column_count(); col_idx++) {
+	for (idx_t col_idx = 0; col_idx < output.ColumnCount(); col_idx++) {
 		auto &array = *data.current_chunk_root.children[col_idx];
 		if (!array.release) {
 			throw InvalidInputException("arrow_scan: released array passed");
