@@ -7,15 +7,18 @@
 #include "duckdb/common/file_system.hpp"
 #include "duckdb/common/types/string_type.hpp"
 #include "duckdb/common/vector_operations/vector_operations.hpp"
+#include <limits>
 
 using namespace std;
 
 namespace duckdb {
 
 void SubstringDetection(string &str_1, string &str_2, string name_str_1, string name_str_2) {
+	if (str_1.size() == 0 || str_2.size() == 0) {
+		return;
+	}
 	if (str_1.find(str_2) != string::npos || str_2.find(str_1) != std::string::npos) {
-		throw BinderException("COPY " + name_str_1 + " must not appear in the " + name_str_2 +
-		                      " specification and vice versa");
+		throw BinderException(name_str_1 + " must not appear in the " + name_str_2 + " specification and vice versa");
 	}
 }
 
@@ -45,15 +48,11 @@ static string ParseString(vector<Value> &set) {
 	return set[0].GetValue<string>();
 }
 
-static idx_t ParseInteger(vector<Value> &set) {
+static int64_t ParseInteger(vector<Value> &set) {
 	if (set.size() != 1) {
 		// no option specified or multiple options specified
 		throw BinderException("Expected a single argument as a integer value");
 	}
-	if (set[0].type().id() == LogicalTypeId::FLOAT || set[0].type().id() == LogicalTypeId::DOUBLE ||
-	    set[0].type().id() == LogicalTypeId::DECIMAL) {
-		throw BinderException("Expected a integer argument!");
-	}
 	return set[0].GetValue<int64_t>();
 }
 
@@ -70,15 +69,9 @@ static bool ParseBaseOption(BufferedCSVReaderOptions &options, string &loption,
 	} else if (loption == "quote") {
 		options.quote = ParseString(set);
 		options.has_quote = true;
-		if (options.quote.length() == 0) {
-			throw BinderException("QUOTE must not be empty");
-		}
 	} else if (loption == "escape") {
 		options.escape = ParseString(set);
 		options.has_escape = true;
-		if (options.escape.length() == 0) {
-			throw BinderException("ESCAPE must not be empty");
-		}
 	} else if (loption == "header") {
 		options.header = ParseBoolean(set);
 		options.has_header = true;
@@ -212,18 +205,33 @@ static unique_ptr<FunctionData> read_csv_bind(ClientContext &context, CopyInfo &
 			// parsed option in base CSV options: continue
 			continue;
 		} else if (loption == "sample_size") {
-			options.sample_size = ParseInteger(set);
-			if (options.sample_size > STANDARD_VECTOR_SIZE) {
-				throw BinderException(
-				    "Unsupported parameter for SAMPLE_SIZE: cannot be bigger than STANDARD_VECTOR_SIZE %d",
-				    STANDARD_VECTOR_SIZE);
-			} else if (options.sample_size < 1) {
+			int64_t sample_size = ParseInteger(set);
+			if (sample_size < 1 && sample_size != -1) {
 				throw BinderException("Unsupported parameter for SAMPLE_SIZE: cannot be smaller than 1");
 			}
-		} else if (loption == "num_samples") {
-			options.num_samples = ParseInteger(set);
-			if (options.num_samples < 1) {
-				throw BinderException("Unsupported parameter for NUM_SAMPLES: cannot be smaller than 1");
+			if (sample_size == -1) {
+				options.sample_chunks = std::numeric_limits<uint64_t>::max();
+				options.sample_chunk_size = STANDARD_VECTOR_SIZE;
+			} else if (sample_size <= STANDARD_VECTOR_SIZE) {
+				options.sample_chunk_size = sample_size;
+				options.sample_chunks = 1;
+			} else {
+				options.sample_chunk_size = STANDARD_VECTOR_SIZE;
+				options.sample_chunks = sample_size / STANDARD_VECTOR_SIZE;
+			}
+		} else if (loption == "sample_chunk_size") {
+			options.sample_chunk_size = ParseInteger(set);
+			if (options.sample_chunk_size > STANDARD_VECTOR_SIZE) {
+				throw BinderException(
+				    "Unsupported parameter for SAMPLE_CHUNK_SIZE: cannot be bigger than STANDARD_VECTOR_SIZE %d",
+				    STANDARD_VECTOR_SIZE);
+			} else if (options.sample_chunk_size < 1) {
+				throw BinderException("Unsupported parameter for SAMPLE_CHUNK_SIZE: cannot be smaller than 1");
+			}
+		} else if (loption == "sample_chunks") {
+			options.sample_chunks = ParseInteger(set);
+			if (options.sample_chunks < 1) {
+				throw BinderException("Unsupported parameter for SAMPLE_CHUNKS: cannot be smaller than 1");
 			}
 		} else if (loption == "force_not_null") {
 			options.force_not_null = ParseColumnList(set, expected_names);
@@ -445,9 +453,8 @@ static void write_csv_sink(ClientContext &context, FunctionData &bind_data, Glob
 	// first cast the columns of the chunk to varchar
 	auto &cast_chunk = local_data.cast_chunk;
 	cast_chunk.SetCardinality(input);
-	for (idx_t col_idx = 0; col_idx < input.column_count(); col_idx++) {
-		if (csv_data.sql_types[col_idx].id() == LogicalTypeId::VARCHAR ||
-		    csv_data.sql_types[col_idx].id() == LogicalTypeId::BLOB) {
+	for (idx_t col_idx = 0; col_idx < input.ColumnCount(); col_idx++) {
+		if (csv_data.sql_types[col_idx].id() == LogicalTypeId::VARCHAR) {
 			// VARCHAR, just create a reference
 			cast_chunk.data[col_idx].Reference(input.data[col_idx]);
 		} else {
@@ -461,7 +468,7 @@ static void write_csv_sink(ClientContext &context, FunctionData &bind_data, Glob
 	// now loop over the vectors and output the values
 	for (idx_t row_idx = 0; row_idx < cast_chunk.size(); row_idx++) {
 		// write values
-		for (idx_t col_idx = 0; col_idx < cast_chunk.column_count(); col_idx++) {
+		for (idx_t col_idx = 0; col_idx < cast_chunk.ColumnCount(); col_idx++) {
 			if (col_idx != 0) {
 				writer.WriteBufferData(options.delimiter);
 			}
@@ -477,7 +484,7 @@ static void write_csv_sink(ClientContext &context, FunctionData &bind_data, Glob
 			// FIXME: we could gain some performance here by checking for certain types if they ever require quotes
 			// (e.g. integers only require quotes if the delimiter is a number, decimals only require quotes if the
 			// delimiter is a number or "." character)
-			WriteQuotedString(writer, csv_data, str_value.GetData(), str_value.GetSize(),
+			WriteQuotedString(writer, csv_data, str_value.GetDataUnsafe(), str_value.GetSize(),
 			                  csv_data.force_quote[col_idx]);
 		}
 		writer.WriteBufferData(csv_data.newline);
