@@ -61,9 +61,9 @@ static unique_ptr<FunctionData> information_schema_tables_bind(ClientContext &co
 	return nullptr;
 }
 
-unique_ptr<FunctionOperatorData>
-information_schema_tables_init(ClientContext &context, const FunctionData *bind_data, vector<column_t> &column_ids,
-                               unordered_map<idx_t, vector<TableFilter>> &table_filters) {
+unique_ptr<FunctionOperatorData> information_schema_tables_init(ClientContext &context, const FunctionData *bind_data,
+                                                                vector<column_t> &column_ids,
+                                                                TableFilterSet *table_filters) {
 	auto result = make_unique<InformationSchemaTablesData>();
 
 	// scan all the schemas for tables and views and collect them
