@@ -29,8 +29,7 @@ static unique_ptr<FunctionData> repeat_bind(ClientContext &context, vector<Value
 }
 
 static unique_ptr<FunctionOperatorData> repeat_init(ClientContext &context, const FunctionData *bind_data,
-                                                    vector<column_t> &column_ids,
-                                                    unordered_map<idx_t, vector<TableFilter>> &table_filters) {
+                                                    vector<column_t> &column_ids, TableFilterSet *table_filters) {
 	return make_unique<RepeatOperatorData>();
 }
 
@@ -45,14 +44,14 @@ static void repeat_function(ClientContext &context, const FunctionData *bind_dat
 	state.current_count += remaining;
 }
 
-static idx_t repeat_cardinality(const FunctionData *bind_data_) {
+static unique_ptr<NodeStatistics> repeat_cardinality(ClientContext &context, const FunctionData *bind_data_) {
 	auto &bind_data = (RepeatFunctionData &)*bind_data_;
-	return bind_data.target_count;
+	return make_unique<NodeStatistics>(bind_data.target_count, bind_data.target_count);
 }
 
 void RepeatTableFunction::RegisterFunction(BuiltinFunctions &set) {
 	TableFunction repeat("repeat", {LogicalType::ANY, LogicalType::BIGINT}, repeat_function, repeat_bind, repeat_init,
-	                     nullptr, nullptr, repeat_cardinality);
+	                     nullptr, nullptr, nullptr, repeat_cardinality);
 	set.AddFunction(repeat);
 }
 
