@@ -12,6 +12,7 @@
 #include "duckdb/common/types.hpp"
 #include "duckdb/common/types/hugeint.hpp"
 #include "duckdb/common/types/interval.hpp"
+#include "duckdb/common/helper.hpp"
 
 #include <cstring>
 
@@ -90,17 +91,29 @@ template <> inline bool Equals::Operation(string_t left, string_t right) {
 template <> inline bool NotEquals::Operation(string_t left, string_t right) {
 	return StringComparisonOperators::EqualsOrNot<true>(left, right);
 }
+
+// compare up to shared length. if still the same, compare lengths
+template <class OP> static bool templated_string_compare_op(string_t left, string_t right) {
+	auto memcmp_res =
+	    memcmp(left.GetDataUnsafe(), right.GetDataUnsafe(), MinValue<idx_t>(left.GetSize(), right.GetSize()));
+	auto final_res = memcmp_res == 0 ? OP::Operation(left.GetSize(), right.GetSize()) : OP::Operation(memcmp_res, 0);
+	return final_res;
+}
+
 template <> inline bool GreaterThan::Operation(string_t left, string_t right) {
-	return strcmp(left.GetData(), right.GetData()) > 0;
+	return templated_string_compare_op<GreaterThan>(left, right);
 }
+
 template <> inline bool GreaterThanEquals::Operation(string_t left, string_t right) {
-	return strcmp(left.GetData(), right.GetData()) >= 0;
+	return templated_string_compare_op<GreaterThanEquals>(left, right);
 }
+
 template <> inline bool LessThan::Operation(string_t left, string_t right) {
-	return strcmp(left.GetData(), right.GetData()) < 0;
+	return templated_string_compare_op<LessThan>(left, right);
 }
+
 template <> inline bool LessThanEquals::Operation(string_t left, string_t right) {
-	return strcmp(left.GetData(), right.GetData()) <= 0;
+	return templated_string_compare_op<LessThanEquals>(left, right);
 }
 //===--------------------------------------------------------------------===//
 // Specialized Interval Comparison Operators
