@@ -17,11 +17,6 @@ namespace duckdb {
 class Serializer;
 class Deserializer;
 
-struct blob_t {
-	data_ptr_t data;
-	idx_t size;
-};
-
 struct interval_t {
 	int32_t months;
 	int32_t days;
@@ -216,7 +211,6 @@ enum class PhysicalType : uint8_t {
 
 	// DuckDB Extensions
 	VARCHAR = 200, // our own string representation, different from STRING and LARGE_STRING above
-	VARBINARY = 201,
 	POINTER = 202,
 	HASH = 203,
 	INT128 = 204, // 128-bit integers
@@ -246,7 +240,6 @@ enum class LogicalTypeId : uint8_t {
 	DOUBLE = 20,
 	CHAR = 21,
 	VARCHAR = 22,
-	VARBINARY = 23,
 	BLOB = 24,
 	INTERVAL = 25,
 
@@ -307,7 +300,7 @@ struct LogicalType {
 	static LogicalType MaxLogicalType(LogicalType left, LogicalType right);
 
 	//! Gets the decimal properties of a numeric type. Fails if the type is not numeric.
-	bool GetDecimalProperties(int &width, int &scale) const;
+	bool GetDecimalProperties(uint8_t &width, uint8_t &scale) const;
 
 	void Verify() const;
 
@@ -337,7 +330,6 @@ public:
 	static const LogicalType TIMESTAMP;
 	static const LogicalType TIME;
 	static const LogicalType VARCHAR;
-	static const LogicalType VARBINARY;
 	static const LogicalType STRUCT;
 	static const LogicalType LIST;
 	static const LogicalType ANY;
