@@ -10,17 +10,22 @@
 
 #include "duckdb/execution/physical_operator.hpp"
 #include "duckdb/parser/parsed_data/pragma_info.hpp"
+#include "duckdb/function/pragma_function.hpp"
 
 namespace duckdb {
 
 //! PhysicalPragma represents the PRAGMA operator
 class PhysicalPragma : public PhysicalOperator {
 public:
-	PhysicalPragma(unique_ptr<PragmaInfo> info)
-	    : PhysicalOperator(PhysicalOperatorType::PRAGMA, {LogicalType::BOOLEAN}), info(move(info)) {
+	PhysicalPragma(PragmaFunction function_, PragmaInfo info_)
+	    : PhysicalOperator(PhysicalOperatorType::PRAGMA, {LogicalType::BOOLEAN}), function(move(function_)),
+	      info(move(info_)) {
 	}
 
-	unique_ptr<PragmaInfo> info;
+	//! The pragma function to call
+	PragmaFunction function;
+	//! The context of the call
+	PragmaInfo info;
 
 public:
 	void GetChunkInternal(ExecutionContext &context, DataChunk &chunk, PhysicalOperatorState *state) override;
