@@ -24,7 +24,7 @@ public:
 	void GetChunkInternal(ExecutionContext &context, DataChunk &chunk, PhysicalOperatorState *state) override;
 
 	unique_ptr<PhysicalOperatorState> GetOperatorState() override;
-	string ExtraRenderInformation() const override;
+	string ParamsToString() const override;
 };
 
 } // namespace duckdb
