@@ -11,6 +11,7 @@
 #include "duckdb/execution/physical_operator.hpp"
 #include "duckdb/storage/data_table.hpp"
 #include "duckdb/function/table_function.hpp"
+#include "duckdb/planner/table_filter.hpp"
 
 namespace duckdb {
 
@@ -18,8 +19,7 @@ namespace duckdb {
 class PhysicalTableScan : public PhysicalOperator {
 public:
 	PhysicalTableScan(vector<LogicalType> types, TableFunction function, unique_ptr<FunctionData> bind_data,
-	                  vector<column_t> column_ids, vector<string> names,
-	                  unordered_map<idx_t, vector<TableFilter>> table_filters);
+	                  vector<column_t> column_ids, vector<string> names, unique_ptr<TableFilterSet> table_filters);
 
 	//! The table function
 	TableFunction function;
@@ -30,7 +30,7 @@ public:
 	//! The names of the columns
 	vector<string> names;
 	//! The table filters
-	unordered_map<idx_t, vector<TableFilter>> table_filters;
+	unique_ptr<TableFilterSet> table_filters;
 
 public:
 	string GetName() const override;
