@@ -10,6 +10,8 @@
 
 #include "duckdb/function/function.hpp"
 #include "duckdb/common/vector_operations/aggregate_executor.hpp"
+#include "duckdb/storage/statistics/base_statistics.hpp"
+#include "duckdb/storage/statistics/node_statistics.hpp"
 
 namespace duckdb {
 
@@ -24,7 +26,12 @@ typedef void (*aggregate_update_t)(Vector inputs[], idx_t input_count, Vector &s
 //! The type used for combining hashed aggregate states (optional)
 typedef void (*aggregate_combine_t)(Vector &state, Vector &combined, idx_t count);
 //! The type used for finalizing hashed aggregate function payloads
-typedef void (*aggregate_finalize_t)(Vector &state, Vector &result, idx_t count);
+typedef void (*aggregate_finalize_t)(Vector &state, FunctionData *bind_data, Vector &result, idx_t count);
+//! The type used for propagating statistics in aggregate functions (optional)
+typedef unique_ptr<BaseStatistics> (*aggregate_statistics_t)(ClientContext &context, BoundAggregateExpression &expr,
+                                                             FunctionData *bind_data,
+                                                             vector<unique_ptr<BaseStatistics>> &child_stats,
+                                                             NodeStatistics *node_stats);
 //! Binds the scalar function and creates the function data
 typedef unique_ptr<FunctionData> (*bind_aggregate_function_t)(ClientContext &context, AggregateFunction &function,
                                                               vector<unique_ptr<Expression>> &arguments);
@@ -39,18 +46,20 @@ public:
 	AggregateFunction(string name, vector<LogicalType> arguments, LogicalType return_type, aggregate_size_t state_size,
 	                  aggregate_initialize_t initialize, aggregate_update_t update, aggregate_combine_t combine,
 	                  aggregate_finalize_t finalize, aggregate_simple_update_t simple_update = nullptr,
-	                  bind_aggregate_function_t bind = nullptr, aggregate_destructor_t destructor = nullptr)
+	                  bind_aggregate_function_t bind = nullptr, aggregate_destructor_t destructor = nullptr,
+	                  aggregate_statistics_t statistics = nullptr)
 	    : BaseScalarFunction(name, arguments, return_type, false), state_size(state_size), initialize(initialize),
 	      update(update), combine(combine), finalize(finalize), simple_update(simple_update), bind(bind),
-	      destructor(destructor) {
+	      destructor(destructor), statistics(statistics) {
 	}
 
 	AggregateFunction(vector<LogicalType> arguments, LogicalType return_type, aggregate_size_t state_size,
 	                  aggregate_initialize_t initialize, aggregate_update_t update, aggregate_combine_t combine,
 	                  aggregate_finalize_t finalize, aggregate_simple_update_t simple_update = nullptr,
-	                  bind_aggregate_function_t bind = nullptr, aggregate_destructor_t destructor = nullptr)
+	                  bind_aggregate_function_t bind = nullptr, aggregate_destructor_t destructor = nullptr,
+	                  aggregate_statistics_t statistics = nullptr)
 	    : AggregateFunction(string(), arguments, return_type, state_size, initialize, update, combine, finalize,
-	                        simple_update, bind, destructor) {
+	                        simple_update, bind, destructor, statistics) {
 	}
 
 	//! The hashed aggregate state sizing function
@@ -71,6 +80,9 @@ public:
 	//! The destructor method (may be null)
 	aggregate_destructor_t destructor;
 
+	//! The statistics propagation function (may be null)
+	aggregate_statistics_t statistics;
+
 	bool operator==(const AggregateFunction &rhs) const {
 		return state_size == rhs.state_size && initialize == rhs.initialize && update == rhs.update &&
 		       combine == rhs.combine && finalize == rhs.finalize;
@@ -85,6 +97,14 @@ public:
 	                                                                  bool is_distinct = false);
 
 public:
+	template <class STATE, class RESULT_TYPE, class OP>
+	static AggregateFunction NullaryAggregate(LogicalType return_type) {
+		return AggregateFunction(
+		    {}, return_type, AggregateFunction::StateSize<STATE>, AggregateFunction::StateInitialize<STATE, OP>,
+		    AggregateFunction::NullaryScatterUpdate<STATE, OP>, AggregateFunction::StateCombine<STATE, OP>,
+		    AggregateFunction::StateFinalize<STATE, RESULT_TYPE, OP>, AggregateFunction::NullaryUpdate<STATE, OP>);
+	}
+
 	template <class STATE, class INPUT_TYPE, class RESULT_TYPE, class OP>
 	static AggregateFunction UnaryAggregate(LogicalType input_type, LogicalType return_type) {
 		return AggregateFunction(
@@ -120,27 +140,39 @@ public:
 		OP::Initialize((STATE *)state);
 	}
 
+	template <class STATE, class OP>
+	static void NullaryScatterUpdate(Vector inputs[], idx_t input_count, Vector &states, idx_t count) {
+		D_ASSERT(input_count == 0);
+		AggregateExecutor::NullaryScatter<STATE, OP>(states, count);
+	}
+
+	template <class STATE, class OP>
+	static void NullaryUpdate(Vector inputs[], idx_t input_count, data_ptr_t state, idx_t count) {
+		D_ASSERT(input_count == 0);
+		AggregateExecutor::NullaryUpdate<STATE, OP>(state, count);
+	}
+
 	template <class STATE, class T, class OP>
 	static void UnaryScatterUpdate(Vector inputs[], idx_t input_count, Vector &states, idx_t count) {
-		assert(input_count == 1);
+		D_ASSERT(input_count == 1);
 		AggregateExecutor::UnaryScatter<STATE, T, OP>(inputs[0], states, count);
 	}
 
 	template <class STATE, class INPUT_TYPE, class OP>
 	static void UnaryUpdate(Vector inputs[], idx_t input_count, data_ptr_t state, idx_t count) {
-		assert(input_count == 1);
+		D_ASSERT(input_count == 1);
 		AggregateExecutor::UnaryUpdate<STATE, INPUT_TYPE, OP>(inputs[0], state, count);
 	}
 
 	template <class STATE, class A_TYPE, class B_TYPE, class OP>
 	static void BinaryScatterUpdate(Vector inputs[], idx_t input_count, Vector &states, idx_t count) {
-		assert(input_count == 2);
+		D_ASSERT(input_count == 2);
 		AggregateExecutor::BinaryScatter<STATE, A_TYPE, B_TYPE, OP>(inputs[0], inputs[1], states, count);
 	}
 
 	template <class STATE, class A_TYPE, class B_TYPE, class OP>
 	static void BinaryUpdate(Vector inputs[], idx_t input_count, data_ptr_t state, idx_t count) {
-		assert(input_count == 2);
+		D_ASSERT(input_count == 2);
 		AggregateExecutor::BinaryUpdate<STATE, A_TYPE, B_TYPE, OP>(inputs[0], inputs[1], state, count);
 	}
 
@@ -149,8 +181,8 @@ public:
 	}
 
 	template <class STATE, class RESULT_TYPE, class OP>
-	static void StateFinalize(Vector &states, Vector &result, idx_t count) {
-		AggregateExecutor::Finalize<STATE, RESULT_TYPE, OP>(states, result, count);
+	static void StateFinalize(Vector &states, FunctionData *bind_data, Vector &result, idx_t count) {
+		AggregateExecutor::Finalize<STATE, RESULT_TYPE, OP>(states, bind_data, result, count);
 	}
 
 	template <class STATE, class OP> static void StateDestroy(Vector &states, idx_t count) {
