@@ -14,6 +14,7 @@
 #include "duckdb/common/vector_operations/vector_operations.hpp"
 #include "duckdb/execution/expression_executor_state.hpp"
 #include "duckdb/function/function.hpp"
+#include "duckdb/storage/statistics/base_statistics.hpp"
 
 namespace duckdb {
 class BoundFunctionExpression;
@@ -24,6 +25,9 @@ typedef std::function<void(DataChunk &, ExpressionState &, Vector &)> scalar_fun
 //! Binds the scalar function and creates the function data
 typedef unique_ptr<FunctionData> (*bind_scalar_function_t)(ClientContext &context, ScalarFunction &bound_function,
                                                            vector<unique_ptr<Expression>> &arguments);
+typedef unique_ptr<BaseStatistics> (*function_statistics_t)(ClientContext &context, BoundFunctionExpression &expr,
+                                                            FunctionData *bind_data,
+                                                            vector<unique_ptr<BaseStatistics>> &child_stats);
 //! Adds the dependencies of this BoundFunctionExpression to the set of dependencies
 typedef void (*dependency_function_t)(BoundFunctionExpression &expr, unordered_set<CatalogEntry *> &dependencies);
 
@@ -31,15 +35,18 @@ class ScalarFunction : public BaseScalarFunction {
 public:
 	ScalarFunction(string name, vector<LogicalType> arguments, LogicalType return_type, scalar_function_t function,
 	               bool has_side_effects = false, bind_scalar_function_t bind = nullptr,
-	               dependency_function_t dependency = nullptr, LogicalType varargs = LogicalType::INVALID)
+	               dependency_function_t dependency = nullptr, function_statistics_t statistics = nullptr,
+	               LogicalType varargs = LogicalType::INVALID)
 	    : BaseScalarFunction(name, arguments, return_type, has_side_effects, varargs), function(function), bind(bind),
-	      dependency(dependency) {
+	      dependency(dependency), statistics(statistics) {
 	}
 
 	ScalarFunction(vector<LogicalType> arguments, LogicalType return_type, scalar_function_t function,
 	               bool has_side_effects = false, bind_scalar_function_t bind = nullptr,
-	               dependency_function_t dependency = nullptr, LogicalType varargs = LogicalType::INVALID)
-	    : ScalarFunction(string(), arguments, return_type, function, has_side_effects, bind, dependency, varargs) {
+	               dependency_function_t dependency = nullptr, function_statistics_t statistics = nullptr,
+	               LogicalType varargs = LogicalType::INVALID)
+	    : ScalarFunction(string(), arguments, return_type, function, has_side_effects, bind, dependency, statistics,
+	                     varargs) {
 	}
 
 	//! The main scalar function to execute
@@ -48,23 +55,24 @@ public:
 	bind_scalar_function_t bind;
 	// The dependency function (if any)
 	dependency_function_t dependency;
+	//! The statistics propagation function (if any)
+	function_statistics_t statistics;
 
 	static unique_ptr<BoundFunctionExpression> BindScalarFunction(ClientContext &context, string schema, string name,
 	                                                              vector<unique_ptr<Expression>> children,
-																  string &error,
-	                                                              bool is_operator = false);
+	                                                              string &error, bool is_operator = false);
 	static unique_ptr<BoundFunctionExpression> BindScalarFunction(ClientContext &context,
 	                                                              ScalarFunctionCatalogEntry &function,
 	                                                              vector<unique_ptr<Expression>> children,
-																  string &error,
-	                                                              bool is_operator = false);
+	                                                              string &error, bool is_operator = false);
 
 	static unique_ptr<BoundFunctionExpression> BindScalarFunction(ClientContext &context, ScalarFunction bound_function,
 	                                                              vector<unique_ptr<Expression>> children,
 	                                                              bool is_operator = false);
 
 	bool operator==(const ScalarFunction &rhs) const {
-		return CompareScalarFunctionT(rhs.function) && bind == rhs.bind && dependency == rhs.dependency;
+		return CompareScalarFunctionT(rhs.function) && bind == rhs.bind && dependency == rhs.dependency &&
+		       statistics == rhs.statistics;
 	}
 	bool operator!=(const ScalarFunction &rhs) const {
 		return !(*this == rhs);
@@ -87,19 +95,19 @@ private:
 
 public:
 	static void NopFunction(DataChunk &input, ExpressionState &state, Vector &result) {
-		assert(input.column_count() >= 1);
+		D_ASSERT(input.ColumnCount() >= 1);
 		result.Reference(input.data[0]);
 	}
 
 	template <class TA, class TR, class OP, bool SKIP_NULLS = false>
 	static void UnaryFunction(DataChunk &input, ExpressionState &state, Vector &result) {
-		assert(input.column_count() >= 1);
+		D_ASSERT(input.ColumnCount() >= 1);
 		UnaryExecutor::Execute<TA, TR, OP, SKIP_NULLS>(input.data[0], result, input.size());
 	}
 
 	template <class TA, class TB, class TR, class OP, bool IGNORE_NULL = false>
 	static void BinaryFunction(DataChunk &input, ExpressionState &state, Vector &result) {
-		assert(input.column_count() == 2);
+		D_ASSERT(input.ColumnCount() == 2);
 		BinaryExecutor::ExecuteStandard<TA, TB, TR, OP, IGNORE_NULL>(input.data[0], input.data[1], result,
 		                                                             input.size());
 	}
