@@ -18,6 +18,7 @@ class TransactionManager;
 class ConnectionManager;
 class FileSystem;
 class TaskScheduler;
+class ObjectCache;
 
 //! The database object. This object holds the catalog and all the
 //! database-specific meta information.
@@ -36,6 +37,7 @@ public:
 	unique_ptr<TransactionManager> transaction_manager;
 	unique_ptr<TaskScheduler> scheduler;
 	unique_ptr<ConnectionManager> connection_manager;
+	unique_ptr<ObjectCache> object_cache;
 
 public:
 	template <class T> void LoadExtension() {
