@@ -10,23 +10,33 @@
 
 #include "duckdb/parser/parsed_data/parse_info.hpp"
 #include "duckdb/parser/column_definition.hpp"
+#include "duckdb/common/enums/catalog_type.hpp"
 
 namespace duckdb {
 
-enum class AlterType : uint8_t { INVALID = 0, ALTER_TABLE = 1 };
+enum class AlterType : uint8_t { INVALID = 0, ALTER_TABLE = 1, ALTER_VIEW = 2 };
 
 struct AlterInfo : public ParseInfo {
-	AlterInfo(AlterType type) : type(type) {
+	AlterInfo(AlterType type, string schema, string name) : type(type), schema(schema), name(name) {
 	}
 	virtual ~AlterInfo() {
 	}
 
 	AlterType type;
+	//! Schema name to alter
+	string schema;
+	//! Entry name to alter
+	string name;
 
+public:
+	virtual CatalogType GetCatalogType() = 0;
 	virtual void Serialize(Serializer &serializer);
 	static unique_ptr<AlterInfo> Deserialize(Deserializer &source);
 };
 
+//===--------------------------------------------------------------------===//
+// Alter Table
+//===--------------------------------------------------------------------===//
 enum class AlterTableType : uint8_t {
 	INVALID = 0,
 	RENAME_COLUMN = 1,
@@ -34,25 +44,23 @@ enum class AlterTableType : uint8_t {
 	ADD_COLUMN = 3,
 	REMOVE_COLUMN = 4,
 	ALTER_COLUMN_TYPE = 5,
-	SET_DEFAULT = 6,
-	RENAME_VIEW = 7
+	SET_DEFAULT = 6
 };
 
 struct AlterTableInfo : public AlterInfo {
 	AlterTableInfo(AlterTableType type, string schema, string table)
-	    : AlterInfo(AlterType::ALTER_TABLE), alter_table_type(type), schema(schema), table(table) {
+	    : AlterInfo(AlterType::ALTER_TABLE, schema, table), alter_table_type(type) {
 	}
-	virtual ~AlterTableInfo() override {
+	~AlterTableInfo() override {
 	}
 
 	AlterTableType alter_table_type;
-	//! Schema name to alter to
-	string schema;
-	//! Table name to alter to
-	string table;
 
 public:
-	virtual void Serialize(Serializer &serializer) override;
+	CatalogType GetCatalogType() override {
+		return CatalogType::TABLE_ENTRY;
+	}
+	void Serialize(Serializer &serializer) override;
 	static unique_ptr<AlterInfo> Deserialize(Deserializer &source);
 };
 
@@ -80,9 +88,8 @@ public:
 // RenameTableInfo
 //===--------------------------------------------------------------------===//
 struct RenameTableInfo : public AlterTableInfo {
-	RenameTableInfo(string schema, string table, string new_name, bool is_view)
-	    : AlterTableInfo(is_view ? AlterTableType::RENAME_VIEW : AlterTableType::RENAME_TABLE, schema, table),
-	      new_table_name(new_name) {
+	RenameTableInfo(string schema, string table, string new_name)
+	    : AlterTableInfo(AlterTableType::RENAME_TABLE, schema, table), new_table_name(new_name) {
 	}
 	~RenameTableInfo() override {
 	}
@@ -92,7 +99,7 @@ struct RenameTableInfo : public AlterTableInfo {
 
 public:
 	void Serialize(Serializer &serializer) override;
-	static unique_ptr<AlterInfo> Deserialize(Deserializer &source, string schema, string table, bool is_view);
+	static unique_ptr<AlterInfo> Deserialize(Deserializer &source, string schema, string table);
 };
 
 //===--------------------------------------------------------------------===//
@@ -179,4 +186,44 @@ public:
 	static unique_ptr<AlterInfo> Deserialize(Deserializer &source, string schema, string table);
 };
 
+//===--------------------------------------------------------------------===//
+// Alter View
+//===--------------------------------------------------------------------===//
+enum class AlterViewType : uint8_t { INVALID = 0, RENAME_VIEW = 1 };
+
+struct AlterViewInfo : public AlterInfo {
+	AlterViewInfo(AlterViewType type, string schema, string view)
+	    : AlterInfo(AlterType::ALTER_VIEW, schema, view), alter_view_type(type) {
+	}
+	~AlterViewInfo() override {
+	}
+
+	AlterViewType alter_view_type;
+
+public:
+	CatalogType GetCatalogType() override {
+		return CatalogType::VIEW_ENTRY;
+	}
+	void Serialize(Serializer &serializer) override;
+	static unique_ptr<AlterInfo> Deserialize(Deserializer &source);
+};
+
+//===--------------------------------------------------------------------===//
+// RenameViewInfo
+//===--------------------------------------------------------------------===//
+struct RenameViewInfo : public AlterViewInfo {
+	RenameViewInfo(string schema, string view, string new_name)
+	    : AlterViewInfo(AlterViewType::RENAME_VIEW, schema, view), new_view_name(new_name) {
+	}
+	~RenameViewInfo() override {
+	}
+
+	//! Relation new name
+	string new_view_name;
+
+public:
+	void Serialize(Serializer &serializer) override;
+	static unique_ptr<AlterInfo> Deserialize(Deserializer &source, string schema, string table);
+};
+
 } // namespace duckdb
