@@ -14,7 +14,7 @@
 namespace duckdb {
 
 struct CreateCopyFunctionInfo : public CreateInfo {
-	CreateCopyFunctionInfo(CopyFunction function) : CreateInfo(CatalogType::COPY_FUNCTION), function(function) {
+	CreateCopyFunctionInfo(CopyFunction function) : CreateInfo(CatalogType::COPY_FUNCTION_ENTRY), function(function) {
 		this->name = function.name;
 	}
 
