@@ -21,9 +21,15 @@ public:
 	virtual ~SQLStatement() {
 	}
 
+	//! The statement type
 	StatementType type;
+	//! The statement location within the query string
 	idx_t stmt_location;
+	//! The statement length within the query string
 	idx_t stmt_length;
+	//! The number of prepared statement parameters (if any)
+	idx_t n_param;
+	//! The query text that corresponds to this SQL statement
 	string query;
 };
 } // namespace duckdb
