@@ -10,6 +10,7 @@
 
 #include "duckdb/planner/logical_operator.hpp"
 #include "duckdb/planner/column_binding.hpp"
+#include "duckdb/storage/statistics/base_statistics.hpp"
 
 namespace duckdb {
 
@@ -25,6 +26,8 @@ public:
 	idx_t aggregate_index;
 	//! The set of groups (optional).
 	vector<unique_ptr<Expression>> groups;
+	//! Group statistics (optional)
+	vector<unique_ptr<BaseStatistics>> group_stats;
 
 public:
 	string ParamsToString() const override;
