@@ -16,8 +16,8 @@ namespace duckdb {
 class LogicalDelimGet : public LogicalOperator {
 public:
 	LogicalDelimGet(idx_t table_index, vector<LogicalType> types)
-	    : LogicalOperator(LogicalOperatorType::DELIM_GET), table_index(table_index) {
-		assert(types.size() > 0);
+	    : LogicalOperator(LogicalOperatorType::LOGICAL_DELIM_GET), table_index(table_index) {
+		D_ASSERT(types.size() > 0);
 		chunk_types = types;
 	}
 
