@@ -16,8 +16,8 @@ namespace duckdb {
 class LogicalExecute : public LogicalOperator {
 public:
 	LogicalExecute(PreparedStatementData *prepared)
-	    : LogicalOperator(LogicalOperatorType::EXECUTE), prepared(prepared) {
-		assert(prepared);
+	    : LogicalOperator(LogicalOperatorType::LOGICAL_EXECUTE), prepared(prepared) {
+		D_ASSERT(prepared);
 		types = prepared->types;
 	}
 
@@ -27,5 +27,12 @@ protected:
 	void ResolveTypes() override {
 		// already resolved
 	}
+	vector<ColumnBinding> GetColumnBindings() override {
+		vector<ColumnBinding> bindings;
+		for (idx_t i = 0; i < types.size(); i++) {
+			bindings.push_back(ColumnBinding(0, i));
+		}
+		return bindings;
+	}
 };
 } // namespace duckdb
