@@ -15,7 +15,7 @@ namespace duckdb {
 //! LogicalInsert represents an insertion of data into a base table
 class LogicalInsert : public LogicalOperator {
 public:
-	LogicalInsert(TableCatalogEntry *table) : LogicalOperator(LogicalOperatorType::INSERT), table(table) {
+	LogicalInsert(TableCatalogEntry *table) : LogicalOperator(LogicalOperatorType::LOGICAL_INSERT), table(table) {
 	}
 
 	vector<vector<unique_ptr<Expression>>> insert_values;
