@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include "duckdb/planner/binder.hpp"
 #include "duckdb/planner/bound_tableref.hpp"
 
 namespace duckdb {
@@ -18,6 +19,10 @@ public:
 	BoundCrossProductRef() : BoundTableRef(TableReferenceType::CROSS_PRODUCT) {
 	}
 
+	//! The binder used to bind the LHS of the cross product
+	unique_ptr<Binder> left_binder;
+	//! The binder used to bind the RHS of the cross product
+	unique_ptr<Binder> right_binder;
 	//! The left hand side of the cross product
 	unique_ptr<BoundTableRef> left;
 	//! The right hand side of the cross product
