@@ -21,6 +21,7 @@ class Index;
 class MorselInfo;
 class PersistentSegment;
 class TransientSegment;
+struct TableFilterSet;
 
 struct IndexScanState {
 	virtual ~IndexScanState() {
@@ -66,6 +67,7 @@ struct LocalScanState {
 	idx_t chunk_index;
 	idx_t max_index;
 	idx_t last_chunk_count;
+	TableFilterSet *table_filters;
 
 private:
 	LocalTableStorage *storage = nullptr;
@@ -78,6 +80,7 @@ public:
 	idx_t base_row;
 	unique_ptr<ColumnScanState[]> column_scans;
 	idx_t column_count;
+	TableFilterSet *table_filters = nullptr;
 	unique_ptr<AdaptiveFilter> adaptive_filter;
 	LocalScanState local_state;
 	MorselInfo *version_info;
