@@ -47,7 +47,7 @@ void Appender::BeginRow() {
 void Appender::EndRow() {
 	CheckInvalidated();
 	// check that all rows have been appended to
-	if (column != chunk.column_count()) {
+	if (column != chunk.ColumnCount()) {
 		InvalidateException("Call to EndRow before all rows have been appended to!");
 	}
 	column = 0;
@@ -68,7 +68,7 @@ void Appender::InvalidateException(string msg) {
 
 template <class T> void Appender::AppendValueInternal(T input) {
 	CheckInvalidated();
-	if (column >= chunk.column_count()) {
+	if (column >= chunk.ColumnCount()) {
 		InvalidateException("Too many appends for chunk!");
 	}
 	auto &col = chunk.data[column];
@@ -144,14 +144,14 @@ template <> void Appender::Append(double value) {
 }
 
 template <> void Appender::Append(Value value) {
-	if (column >= chunk.column_count()) {
+	if (column >= chunk.ColumnCount()) {
 		InvalidateException("Too many appends for chunk!");
 	}
 	AppendValue(move(value));
 }
 
 template <> void Appender::Append(nullptr_t value) {
-	if (column >= chunk.column_count()) {
+	if (column >= chunk.ColumnCount()) {
 		InvalidateException("Too many appends for chunk!");
 	}
 	auto &col = chunk.data[column++];
@@ -187,7 +187,7 @@ void Appender::Close() {
 	if (!invalidated_msg.empty()) {
 		return;
 	}
-	if (column == 0 || column == chunk.column_count()) {
+	if (column == 0 || column == chunk.ColumnCount()) {
 		Flush();
 	}
 	Invalidate("The appender has been closed!");
@@ -200,7 +200,7 @@ void Appender::Invalidate(string msg, bool close) {
 	if (close) {
 		con.context->RemoveAppender(this);
 	}
-	assert(!msg.empty());
+	D_ASSERT(!msg.empty());
 	invalidated_msg = msg;
 }
 } // namespace duckdb
