@@ -17,7 +17,7 @@ MaterializedQueryResult::MaterializedQueryResult(string error)
 }
 
 Value MaterializedQueryResult::GetValue(idx_t column, idx_t index) {
-	auto &data = collection.GetChunk(index).data[column];
+	auto &data = collection.GetChunkForRow(index).data[column];
 	auto offset_in_chunk = index % STANDARD_VECTOR_SIZE;
 	return data.GetValue(offset_in_chunk);
 }
@@ -26,9 +26,9 @@ string MaterializedQueryResult::ToString() {
 	string result;
 	if (success) {
 		result = HeaderToString();
-		result += "[ Rows: " + to_string(collection.count) + "]\n";
-		for (idx_t j = 0; j < collection.count; j++) {
-			for (idx_t i = 0; i < collection.column_count(); i++) {
+		result += "[ Rows: " + to_string(collection.Count()) + "]\n";
+		for (idx_t j = 0; j < collection.Count(); j++) {
+			for (idx_t i = 0; i < collection.ColumnCount(); i++) {
 				auto val = collection.GetValue(i, j);
 				result += val.is_null ? "NULL" : val.ToString();
 				result += "\t";
@@ -46,12 +46,8 @@ unique_ptr<DataChunk> MaterializedQueryResult::Fetch() {
 	if (!success) {
 		return nullptr;
 	}
-	if (collection.chunks.size() == 0) {
-		return make_unique<DataChunk>();
-	}
-	auto chunk = move(collection.chunks[0]);
-	collection.chunks.erase(collection.chunks.begin() + 0);
-	return chunk;
+
+	return collection.Fetch();
 }
 
 } // namespace duckdb
