@@ -14,7 +14,8 @@ PreparedStatementData::~PreparedStatementData() {
 void PreparedStatementData::Bind(vector<Value> values) {
 	// set parameters
 	if (values.size() != value_map.size()) {
-		throw BinderException("Parameter/argument count mismatch for prepared statement");
+		throw BinderException("Parameter/argument count mismatch for prepared statement. Expected %llu, got %llu",
+		                      value_map.size(), values.size());
 	}
 	// bind the values
 	for (idx_t i = 0; i < values.size(); i++) {
@@ -22,13 +23,17 @@ void PreparedStatementData::Bind(vector<Value> values) {
 		if (it == value_map.end()) {
 			throw BinderException("Could not find parameter with index %llu", i + 1);
 		}
-		if (values[i].type() != it->second->type()) {
+		if (it->second.empty()) {
+			throw BinderException("No value found for parameter with index %llu", i + 1);
+		}
+		if (values[i].type() != it->second[0]->type()) {
 			throw BinderException(
 			    "Type mismatch for binding parameter with index %llu, expected type %s but got type %s", i + 1,
-			    values[i].type().ToString().c_str(), it->second->type().ToString().c_str());
+			    values[i].type().ToString().c_str(), it->second[0]->type().ToString().c_str());
+		}
+		for (auto &target : it->second) {
+			*target = values[i];
 		}
-		auto &target = it->second;
-		*target = values[i];
 	}
 }
 
@@ -37,7 +42,10 @@ LogicalType PreparedStatementData::GetType(idx_t param_idx) {
 	if (it == value_map.end()) {
 		throw BinderException("Could not find parameter with index %llu", param_idx);
 	}
-	return it->second->type();
+	if (it->second.empty()) {
+		throw BinderException("No value found for parameter with index %llu", param_idx);
+	}
+	return it->second[0]->type();
 }
 
 } // namespace duckdb
