@@ -41,7 +41,6 @@ bool QueryProfiler::OperatorRequiresProfiling(PhysicalOperatorType op_type) {
 	case PhysicalOperatorType::AGGREGATE:
 	case PhysicalOperatorType::WINDOW:
 	case PhysicalOperatorType::UNNEST:
-	case PhysicalOperatorType::DISTINCT:
 	case PhysicalOperatorType::SIMPLE_AGGREGATE:
 	case PhysicalOperatorType::HASH_GROUP_BY:
 	case PhysicalOperatorType::SORT_GROUP_BY:
@@ -125,7 +124,7 @@ void QueryProfiler::EndPhase() {
 	if (!enabled || !running) {
 		return;
 	}
-	assert(phase_stack.size() > 0);
+	D_ASSERT(phase_stack.size() > 0);
 
 	// end the timer
 	phase_profiler.End();
@@ -189,7 +188,7 @@ void OperatorProfiler::EndOperator(DataChunk *chunk) {
 
 	AddTiming(execution_stack.top(), op.Elapsed(), chunk ? chunk->size() : 0);
 
-	assert(!execution_stack.empty());
+	D_ASSERT(!execution_stack.empty());
 	execution_stack.pop();
 
 	// start timing again for the previous element, if any
@@ -221,7 +220,7 @@ void QueryProfiler::Flush(OperatorProfiler &profiler) {
 
 	for (auto &node : profiler.timings) {
 		auto entry = tree_map.find(node.first);
-		assert(entry != tree_map.end());
+		D_ASSERT(entry != tree_map.end());
 
 		entry->second->info.time += node.second.time;
 		entry->second->info.elements += node.second.elements;
@@ -306,16 +305,17 @@ void QueryProfiler::ToStream(std::ostream &ss, bool print_optimizer_output) cons
 				}
 				ss << "┌─────────────────────────────────────┐\n";
 				ss << "│" +
-						DrawPadded(RenderTitleCase(entry.first) + ": " + RenderTiming(entry.second),
-									TOTAL_BOX_WIDTH - 2) +
-						"│\n";
+				          DrawPadded(RenderTitleCase(entry.first) + ": " + RenderTiming(entry.second),
+				                     TOTAL_BOX_WIDTH - 2) +
+				          "│\n";
 				ss << "│┌───────────────────────────────────┐│\n";
 				has_previous_phase = true;
 			} else {
 				string entry_name = StringUtil::Split(entry.first, " > ")[1];
 				ss << "││" +
-						DrawPadded(RenderTitleCase(entry_name) + ": " + RenderTiming(entry.second), TOTAL_BOX_WIDTH - 4) +
-						"││\n";
+				          DrawPadded(RenderTitleCase(entry_name) + ": " + RenderTiming(entry.second),
+				                     TOTAL_BOX_WIDTH - 4) +
+				          "││\n";
 			}
 		}
 		if (has_previous_phase) {
@@ -444,7 +444,7 @@ vector<QueryProfiler::PhaseTimingItem> QueryProfiler::GetOrderedPhaseTimings() c
 	std::sort(phases.begin(), phases.end());
 	for (const auto &phase : phases) {
 		auto entry = phase_timings.find(phase);
-		assert(entry != phase_timings.end());
+		D_ASSERT(entry != phase_timings.end());
 		result.emplace_back(entry->first, entry->second);
 	}
 	return result;
