@@ -38,7 +38,7 @@ void ColumnLifetimeAnalyzer::GenerateProjectionMap(vector<ColumnBinding> binding
 
 void ColumnLifetimeAnalyzer::StandardVisitOperator(LogicalOperator &op) {
 	LogicalOperatorVisitor::VisitOperatorExpressions(op);
-	if (op.type == LogicalOperatorType::DELIM_JOIN) {
+	if (op.type == LogicalOperatorType::LOGICAL_DELIM_JOIN) {
 		// visit the duplicate eliminated columns on the LHS, if any
 		auto &delim_join = (LogicalDelimJoin &)op;
 		for (auto &expr : delim_join.duplicate_eliminated_columns) {
@@ -50,7 +50,7 @@ void ColumnLifetimeAnalyzer::StandardVisitOperator(LogicalOperator &op) {
 
 void ColumnLifetimeAnalyzer::VisitOperator(LogicalOperator &op) {
 	switch (op.type) {
-	case LogicalOperatorType::AGGREGATE_AND_GROUP_BY: {
+	case LogicalOperatorType::LOGICAL_AGGREGATE_AND_GROUP_BY: {
 		// FIXME: groups that are not referenced can be removed from projection
 		// recurse into the children of the aggregate
 		ColumnLifetimeAnalyzer analyzer;
@@ -58,8 +58,8 @@ void ColumnLifetimeAnalyzer::VisitOperator(LogicalOperator &op) {
 		analyzer.VisitOperator(*op.children[0]);
 		return;
 	}
-	case LogicalOperatorType::DELIM_JOIN:
-	case LogicalOperatorType::COMPARISON_JOIN: {
+	case LogicalOperatorType::LOGICAL_DELIM_JOIN:
+	case LogicalOperatorType::LOGICAL_COMPARISON_JOIN: {
 		if (everything_referenced) {
 			break;
 		}
@@ -90,9 +90,9 @@ void ColumnLifetimeAnalyzer::VisitOperator(LogicalOperator &op) {
 		GenerateProjectionMap(op.children[1]->GetColumnBindings(), unused_bindings, comp_join.right_projection_map);
 		return;
 	}
-	case LogicalOperatorType::UNION:
-	case LogicalOperatorType::EXCEPT:
-	case LogicalOperatorType::INTERSECT:
+	case LogicalOperatorType::LOGICAL_UNION:
+	case LogicalOperatorType::LOGICAL_EXCEPT:
+	case LogicalOperatorType::LOGICAL_INTERSECT:
 		// for set operations we don't remove anything, just recursively visit the children
 		// FIXME: for UNION we can remove unreferenced columns as long as everything_referenced is false (i.e. we
 		// encounter a UNION node that is not preceded by a DISTINCT)
@@ -101,21 +101,21 @@ void ColumnLifetimeAnalyzer::VisitOperator(LogicalOperator &op) {
 			analyzer.VisitOperator(*child);
 		}
 		return;
-	case LogicalOperatorType::PROJECTION: {
+	case LogicalOperatorType::LOGICAL_PROJECTION: {
 		// then recurse into the children of this projection
 		ColumnLifetimeAnalyzer analyzer;
 		analyzer.VisitOperatorExpressions(op);
 		analyzer.VisitOperator(*op.children[0]);
 		return;
 	}
-	case LogicalOperatorType::DISTINCT: {
+	case LogicalOperatorType::LOGICAL_DISTINCT: {
 		// distinct, all projected columns are used for the DISTINCT computation
 		// mark all columns as used and continue to the children
 		// FIXME: DISTINCT with expression list does not implicitly reference everything
 		everything_referenced = true;
 		break;
 	}
-	case LogicalOperatorType::FILTER: {
+	case LogicalOperatorType::LOGICAL_FILTER: {
 		auto &filter = (LogicalFilter &)op;
 		if (everything_referenced) {
 			break;
