@@ -9,6 +9,8 @@
 #include "duckdb/planner/operator/logical_filter.hpp"
 #include "duckdb/planner/expression/bound_columnref_expression.hpp"
 #include "duckdb/planner/expression.hpp"
+#include "duckdb/planner/table_filter.hpp"
+
 namespace duckdb {
 using namespace std;
 
@@ -25,14 +27,14 @@ Expression *FilterCombiner::GetNode(Expression *expr) {
 	// expression does not exist yet: create a copy and store it
 	auto copy = expr->Copy();
 	auto pointer_copy = copy.get();
-	assert(stored_expressions.find(pointer_copy) == stored_expressions.end());
+	D_ASSERT(stored_expressions.find(pointer_copy) == stored_expressions.end());
 	stored_expressions.insert(make_pair(pointer_copy, move(copy)));
 	return pointer_copy;
 }
 
 idx_t FilterCombiner::GetEquivalenceSet(Expression *expr) {
-	assert(stored_expressions.find(expr) != stored_expressions.end());
-	assert(stored_expressions.find(expr)->second.get() == expr);
+	D_ASSERT(stored_expressions.find(expr) != stored_expressions.end());
+	D_ASSERT(stored_expressions.find(expr)->second.get() == expr);
 
 	auto entry = equivalence_set_map.find(expr);
 	if (entry == equivalence_set_map.end()) {
@@ -279,7 +281,7 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 			return FilterResult::SUCCESS;
 		}
 	}
-	assert(!expr->IsFoldable());
+	D_ASSERT(!expr->IsFoldable());
 	if (expr->GetExpressionClass() == ExpressionClass::BOUND_BETWEEN) {
 		auto &comparison = (BoundBetweenExpression &)*expr;
 		//! check if one of the sides is a scalar value
@@ -302,7 +304,7 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 			info.constant = constant_value;
 
 			// get the current bucket of constant values
-			assert(constant_values.find(equivalence_set) != constant_values.end());
+			D_ASSERT(constant_values.find(equivalence_set) != constant_values.end());
 			auto &info_list = constant_values.find(equivalence_set)->second;
 			// check the existing constant comparisons to see if we can do any pruning
 			AddConstantComparison(info_list, info);
@@ -318,7 +320,7 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 			info.constant = constant_value;
 
 			// get the current bucket of constant values
-			assert(constant_values.find(equivalence_set) != constant_values.end());
+			D_ASSERT(constant_values.find(equivalence_set) != constant_values.end());
 			// check the existing constant comparisons to see if we can do any pruning
 			return AddConstantComparison(constant_values.find(equivalence_set)->second, info);
 		}
@@ -348,17 +350,18 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 			info.constant = constant_value;
 
 			// get the current bucket of constant values
-			assert(constant_values.find(equivalence_set) != constant_values.end());
+			D_ASSERT(constant_values.find(equivalence_set) != constant_values.end());
 			auto &info_list = constant_values.find(equivalence_set)->second;
 			// check the existing constant comparisons to see if we can do any pruning
 			auto ret = AddConstantComparison(info_list, info);
 
-			auto non_scalar = left_is_scalar ? comparison.right.get(): comparison.left.get();
+			auto non_scalar = left_is_scalar ? comparison.right.get() : comparison.left.get();
 			auto transitive_filter = FindTransitiveFilter(non_scalar);
-			if(transitive_filter.get() != nullptr) {
-				//try to add transitive filters
-				if(AddTransitiveFilters((BoundComparisonExpression &)*transitive_filter.get()) == FilterResult::UNSUPPORTED) {
-					//in case of unsuccessful re-add filter into remaining ones
+			if (transitive_filter.get() != nullptr) {
+				// try to add transitive filters
+				if (AddTransitiveFilters((BoundComparisonExpression &)*transitive_filter.get()) ==
+				    FilterResult::UNSUPPORTED) {
+					// in case of unsuccessful re-add filter into remaining ones
 					remaining_filters.push_back(move(transitive_filter));
 				}
 			}
@@ -368,7 +371,7 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 			// comparison between two non-scalars
 			// only handle comparisons for now
 			if (expr->type != ExpressionType::COMPARE_EQUAL) {
-				if(IsGreaterThan(expr->type) || IsLessThan(expr->type)) {
+				if (IsGreaterThan(expr->type) || IsLessThan(expr->type)) {
 					return AddTransitiveFilters(comparison);
 				}
 				return FilterResult::UNSUPPORTED;
@@ -387,8 +390,8 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 				return FilterResult::SUCCESS;
 			}
 			// add the right bucket into the left bucket
-			assert(equivalence_map.find(left_equivalence_set) != equivalence_map.end());
-			assert(equivalence_map.find(right_equivalence_set) != equivalence_map.end());
+			D_ASSERT(equivalence_map.find(left_equivalence_set) != equivalence_map.end());
+			D_ASSERT(equivalence_map.find(right_equivalence_set) != equivalence_map.end());
 
 			auto &left_bucket = equivalence_map.find(left_equivalence_set)->second;
 			auto &right_bucket = equivalence_map.find(right_equivalence_set)->second;
@@ -399,8 +402,8 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 				left_bucket.push_back(right_bucket[i]);
 			}
 			// now add all constant values from the right bucket to the left bucket
-			assert(constant_values.find(left_equivalence_set) != constant_values.end());
-			assert(constant_values.find(right_equivalence_set) != constant_values.end());
+			D_ASSERT(constant_values.find(left_equivalence_set) != constant_values.end());
+			D_ASSERT(constant_values.find(right_equivalence_set) != constant_values.end());
 			auto &left_constant_bucket = constant_values.find(left_equivalence_set)->second;
 			auto &right_constant_bucket = constant_values.find(right_equivalence_set)->second;
 			for (idx_t i = 0; i < right_constant_bucket.size(); i++) {
@@ -417,11 +420,11 @@ FilterResult FilterCombiner::AddFilter(Expression *expr) {
 }
 
 /*
-* Create and add new transitive filters from a two non-scalar filter such as j > i, j >= i, j < i, and j <= i
-* It's missing to create another method to add transitive filters from scalar filters, e.g, i > 10
-*/
+ * Create and add new transitive filters from a two non-scalar filter such as j > i, j >= i, j < i, and j <= i
+ * It's missing to create another method to add transitive filters from scalar filters, e.g, i > 10
+ */
 FilterResult FilterCombiner::AddTransitiveFilters(BoundComparisonExpression &comparison) {
-	assert(IsGreaterThan(comparison.type) || IsLessThan(comparison.type));
+	D_ASSERT(IsGreaterThan(comparison.type) || IsLessThan(comparison.type));
 	// get the LHS and RHS nodes
 	Expression *left_node = GetNode(comparison.left.get());
 	Expression *right_node = GetNode(comparison.right.get());
@@ -443,36 +446,40 @@ FilterResult FilterCombiner::AddTransitiveFilters(BoundComparisonExpression &com
 	// read every constant filters already inserted for the right scalar variable
 	// and see if we can create new trasitive filters, e.g., there is already a filter i > 10,
 	// suppose that we have now the j >= i, then we can infer a new filter j > 10
-	for(auto right_constant: right_constants) {
+	for (auto right_constant : right_constants) {
 		ExpressionValueInformation info;
 		info.constant = right_constant.constant;
 		// there is already an equality filter, e.g., i = 10
-		if(right_constant.comparison_type == ExpressionType::COMPARE_EQUAL) {
+		if (right_constant.comparison_type == ExpressionType::COMPARE_EQUAL) {
 			// create filter j [>, >=, <, <=] 10
 			// suppose the new comparsion is j >= i and we have already a filter i = 10,
 			// then we create a new filter j >= 10
 			// and the filter j >= i can be pruned by not adding it into the remaining filters
 			info.comparison_type = comparison.type;
-		} else if( (comparison.type == ExpressionType::COMPARE_GREATERTHANOREQUALTO && IsGreaterThan(right_constant.comparison_type)) ||
-				   (comparison.type == ExpressionType::COMPARE_LESSTHANOREQUALTO && IsLessThan(right_constant.comparison_type)) ) {
+		} else if ((comparison.type == ExpressionType::COMPARE_GREATERTHANOREQUALTO &&
+		            IsGreaterThan(right_constant.comparison_type)) ||
+		           (comparison.type == ExpressionType::COMPARE_LESSTHANOREQUALTO &&
+		            IsLessThan(right_constant.comparison_type))) {
 			// filters (j >= i AND i [>, >=] 10) OR (j <= i AND i [<, <=] 10)
 			// create filter j [>, >=] 10 and add the filter j [>=, <=] i into the remaining filters
 			info.comparison_type = right_constant.comparison_type; // create filter j [>, >=, <, <=] 10
-			if(!isInserted) {
-				//Add the filter j >= i in the remaing filters
+			if (!isInserted) {
+				// Add the filter j >= i in the remaing filters
 				auto filter = make_unique<BoundComparisonExpression>(comparison.type, comparison.left->Copy(),
 				                                                     comparison.right->Copy());
 				remaining_filters.push_back(move(filter));
 				isInserted = true;
 			}
-		} else if( (comparison.type == ExpressionType::COMPARE_GREATERTHAN && IsGreaterThan(right_constant.comparison_type)) ||
-				   (comparison.type == ExpressionType::COMPARE_LESSTHAN && IsLessThan(right_constant.comparison_type)) ) {
+		} else if ((comparison.type == ExpressionType::COMPARE_GREATERTHAN &&
+		            IsGreaterThan(right_constant.comparison_type)) ||
+		           (comparison.type == ExpressionType::COMPARE_LESSTHAN &&
+		            IsLessThan(right_constant.comparison_type))) {
 			// filters (j > i AND i [>, >=] 10) OR j < i AND i [<, <=] 10
 			// create filter j [>, <] 10 and add the filter j [>, <] i into the remaining filters
 			// the comparisons j > i and j < i are more restrictive
 			info.comparison_type = comparison.type;
-			if(!isInserted) {
-				//Add the filter j [>, <] i
+			if (!isInserted) {
+				// Add the filter j [>, <] i
 				auto filter = make_unique<BoundComparisonExpression>(comparison.type, comparison.left->Copy(),
 				                                                     comparison.right->Copy());
 				remaining_filters.push_back(move(filter));
@@ -483,18 +490,19 @@ FilterResult FilterCombiner::AddTransitiveFilters(BoundComparisonExpression &com
 			continue;
 		}
 		// Add the new filer into the left set
-		if(AddConstantComparison(left_constants, info) == FilterResult::UNSATISFIABLE) {
+		if (AddConstantComparison(left_constants, info) == FilterResult::UNSATISFIABLE) {
 			return FilterResult::UNSATISFIABLE;
 		}
 		isSuccessful = true;
 	}
-	if(isSuccessful) {
-		//now check for remaining trasitive filters from the left column
+	if (isSuccessful) {
+		// now check for remaining trasitive filters from the left column
 		auto transitive_filter = FindTransitiveFilter(comparison.left.get());
-		if(transitive_filter.get() != nullptr) {
-			//try to add transitive filters
-			if(AddTransitiveFilters((BoundComparisonExpression &)*transitive_filter.get()) == FilterResult::UNSUPPORTED) {
-				//in case of unsuccessful re-add filter into remaining ones
+		if (transitive_filter.get() != nullptr) {
+			// try to add transitive filters
+			if (AddTransitiveFilters((BoundComparisonExpression &)*transitive_filter.get()) ==
+			    FilterResult::UNSUPPORTED) {
+				// in case of unsuccessful re-add filter into remaining ones
 				remaining_filters.push_back(move(transitive_filter));
 			}
 		}
@@ -505,17 +513,17 @@ FilterResult FilterCombiner::AddTransitiveFilters(BoundComparisonExpression &com
 }
 
 /*
-* Find a transitive filter already inserted into the remaining filters
-* Check for a match between the right column of bound comparisons and the expression,
-* then removes the bound comparison from the remaining filters and returns it
-*/
+ * Find a transitive filter already inserted into the remaining filters
+ * Check for a match between the right column of bound comparisons and the expression,
+ * then removes the bound comparison from the remaining filters and returns it
+ */
 unique_ptr<Expression> FilterCombiner::FindTransitiveFilter(Expression *expr) {
 	// We only check for bound column ref
-	if(expr->type == ExpressionType::BOUND_COLUMN_REF) {
+	if (expr->type == ExpressionType::BOUND_COLUMN_REF) {
 		for (idx_t i = 0; i < remaining_filters.size(); i++) {
-			if(remaining_filters[i]->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON) {
+			if (remaining_filters[i]->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON) {
 				auto comparison = (BoundComparisonExpression *)remaining_filters[i].get();
-				if(expr->Equals(comparison->right.get()) && comparison->type != ExpressionType::COMPARE_NOTEQUAL) {
+				if (expr->Equals(comparison->right.get()) && comparison->type != ExpressionType::COMPARE_NOTEQUAL) {
 					auto filter = move(remaining_filters[i]);
 					remaining_filters.erase(remaining_filters.begin() + i);
 					return filter;
@@ -559,7 +567,7 @@ ValueComparisonResult CompareValueInformation(ExpressionValueInformation &left,
 			prune_right_side = left.constant != right.constant;
 			break;
 		default:
-			assert(right.comparison_type == ExpressionType::COMPARE_EQUAL);
+			D_ASSERT(right.comparison_type == ExpressionType::COMPARE_EQUAL);
 			prune_right_side = left.constant == right.constant;
 			break;
 		}
@@ -590,7 +598,7 @@ ValueComparisonResult CompareValueInformation(ExpressionValueInformation &left,
 			prune_left_side = left.constant < right.constant;
 			break;
 		default:
-			assert(right.comparison_type == ExpressionType::COMPARE_NOTEQUAL);
+			D_ASSERT(right.comparison_type == ExpressionType::COMPARE_NOTEQUAL);
 			prune_left_side = left.constant == right.constant;
 			break;
 		}
@@ -644,7 +652,7 @@ ValueComparisonResult CompareValueInformation(ExpressionValueInformation &left,
 			}
 		}
 	} else if (IsLessThan(left.comparison_type)) {
-		assert(IsGreaterThan(right.comparison_type));
+		D_ASSERT(IsGreaterThan(right.comparison_type));
 		// left is [<] and right is [>], in this case we can either
 		// (1) prune nothing or
 		// (2) return UNSATISFIABLE
@@ -656,7 +664,7 @@ ValueComparisonResult CompareValueInformation(ExpressionValueInformation &left,
 		}
 	} else {
 		// left is [>] and right is [<] or [!=]
-		assert(IsLessThan(right.comparison_type) && IsGreaterThan(left.comparison_type));
+		D_ASSERT(IsLessThan(right.comparison_type) && IsGreaterThan(left.comparison_type));
 		return InvertValueComparisonResult(CompareValueInformation(right, left));
 	}
 }
