@@ -25,10 +25,10 @@ template <class T> static bool Disjoint(unordered_set<T> &a, unordered_set<T> &b
 bool JoinOrderOptimizer::ExtractBindings(Expression &expression, unordered_set<idx_t> &bindings) {
 	if (expression.type == ExpressionType::BOUND_COLUMN_REF) {
 		auto &colref = (BoundColumnRefExpression &)expression;
-		assert(colref.depth == 0);
-		assert(colref.binding.table_index != INVALID_INDEX);
+		D_ASSERT(colref.depth == 0);
+		D_ASSERT(colref.binding.table_index != INVALID_INDEX);
 		// map the base table index to the relation index used by the JoinOrderOptimizer
-		assert(relation_mapping.find(colref.binding.table_index) != relation_mapping.end());
+		D_ASSERT(relation_mapping.find(colref.binding.table_index) != relation_mapping.end());
 		bindings.insert(relation_mapping[colref.binding.table_index]);
 	}
 	if (expression.type == ExpressionType::BOUND_REF) {
@@ -36,7 +36,7 @@ bool JoinOrderOptimizer::ExtractBindings(Expression &expression, unordered_set<i
 		bindings.clear();
 		return false;
 	}
-	assert(expression.type != ExpressionType::SUBQUERY);
+	D_ASSERT(expression.type != ExpressionType::SUBQUERY);
 	bool can_reorder = true;
 	ExpressionIterator::EnumerateChildren(expression, [&](Expression &expr) {
 		if (!ExtractBindings(expr, bindings)) {
@@ -50,14 +50,14 @@ bool JoinOrderOptimizer::ExtractBindings(Expression &expression, unordered_set<i
 static unique_ptr<LogicalOperator> PushFilter(unique_ptr<LogicalOperator> node, unique_ptr<Expression> expr) {
 	// push an expression into a filter
 	// first check if we have any filter to push it into
-	if (node->type != LogicalOperatorType::FILTER) {
+	if (node->type != LogicalOperatorType::LOGICAL_FILTER) {
 		// we don't, we need to create one
 		auto filter = make_unique<LogicalFilter>();
 		filter->children.push_back(move(node));
 		node = move(filter);
 	}
 	// push the filter into the LogicalFilter
-	assert(node->type == LogicalOperatorType::FILTER);
+	D_ASSERT(node->type == LogicalOperatorType::LOGICAL_FILTER);
 	auto filter = (LogicalFilter *)node.get();
 	filter->expressions.push_back(move(expr));
 	return node;
@@ -66,36 +66,52 @@ static unique_ptr<LogicalOperator> PushFilter(unique_ptr<LogicalOperator> node,
 bool JoinOrderOptimizer::ExtractJoinRelations(LogicalOperator &input_op, vector<LogicalOperator *> &filter_operators,
                                               LogicalOperator *parent) {
 	LogicalOperator *op = &input_op;
-	while (op->children.size() == 1 &&
-	       (op->type != LogicalOperatorType::PROJECTION && op->type != LogicalOperatorType::EXPRESSION_GET)) {
-		if (op->type == LogicalOperatorType::FILTER) {
+	while (op->children.size() == 1 && (op->type != LogicalOperatorType::LOGICAL_PROJECTION &&
+	                                    op->type != LogicalOperatorType::LOGICAL_EXPRESSION_GET)) {
+		if (op->type == LogicalOperatorType::LOGICAL_FILTER) {
 			// extract join conditions from filter
 			filter_operators.push_back(op);
 		}
-		if (op->type == LogicalOperatorType::AGGREGATE_AND_GROUP_BY || op->type == LogicalOperatorType::WINDOW) {
+		if (op->type == LogicalOperatorType::LOGICAL_AGGREGATE_AND_GROUP_BY ||
+		    op->type == LogicalOperatorType::LOGICAL_WINDOW) {
 			// don't push filters through projection or aggregate and group by
-			JoinOrderOptimizer optimizer;
+			JoinOrderOptimizer optimizer(context);
 			op->children[0] = optimizer.Optimize(move(op->children[0]));
 			return false;
 		}
 		op = op->children[0].get();
 	}
 	bool non_reorderable_operation = false;
-	if (op->type == LogicalOperatorType::UNION || op->type == LogicalOperatorType::EXCEPT ||
-	    op->type == LogicalOperatorType::INTERSECT || op->type == LogicalOperatorType::DELIM_JOIN ||
-	    op->type == LogicalOperatorType::ANY_JOIN) {
+	if (op->type == LogicalOperatorType::LOGICAL_UNION || op->type == LogicalOperatorType::LOGICAL_EXCEPT ||
+	    op->type == LogicalOperatorType::LOGICAL_INTERSECT || op->type == LogicalOperatorType::LOGICAL_DELIM_JOIN ||
+	    op->type == LogicalOperatorType::LOGICAL_ANY_JOIN) {
 		// set operation, optimize separately in children
 		non_reorderable_operation = true;
 	}
 
-	if (op->type == LogicalOperatorType::COMPARISON_JOIN) {
-		LogicalJoin *join = (LogicalJoin *)op;
-		if (join->join_type == JoinType::INNER) {
+	if (op->type == LogicalOperatorType::LOGICAL_COMPARISON_JOIN) {
+		auto &join = (LogicalComparisonJoin &)*op;
+		if (join.join_type == JoinType::INNER) {
 			// extract join conditions from inner join
 			filter_operators.push_back(op);
 		} else {
-			// non-inner join, not reordarable yet
+			// non-inner join, not reorderable yet
 			non_reorderable_operation = true;
+			if (join.join_type == JoinType::LEFT && join.right_projection_map.size() == 0) {
+				// for left joins; if the RHS cardinality is significantly larger than the LHS (2x)
+				// we convert to doing a RIGHT OUTER JOIN
+				// FIXME: for now we don't swap if the right_projection_map is not empty
+				// this can be fixed once we implement the left_projection_map properly...
+				auto lhs_cardinality = join.children[0]->EstimateCardinality(context);
+				auto rhs_cardinality = join.children[1]->EstimateCardinality(context);
+				if (rhs_cardinality > lhs_cardinality * 2) {
+					join.join_type = JoinType::RIGHT;
+					std::swap(join.children[0], join.children[1]);
+					for (auto &cond : join.conditions) {
+						std::swap(cond.left, cond.right);
+					}
+				}
+			}
 		}
 	}
 	if (non_reorderable_operation) {
@@ -106,7 +122,7 @@ bool JoinOrderOptimizer::ExtractJoinRelations(LogicalOperator &input_op, vector<
 		// new NULL values in the right side, so pushing this condition through the join leads to incorrect results
 		// for this reason, we just start a new JoinOptimizer pass in each of the children of the join
 		for (idx_t i = 0; i < op->children.size(); i++) {
-			JoinOrderOptimizer optimizer;
+			JoinOrderOptimizer optimizer(context);
 			op->children[i] = optimizer.Optimize(move(op->children[i]));
 		}
 		// after this we want to treat this node as one  "end node" (like e.g. a base relation)
@@ -124,36 +140,37 @@ bool JoinOrderOptimizer::ExtractJoinRelations(LogicalOperator &input_op, vector<
 		relations.push_back(move(relation));
 		return true;
 	}
-	if (op->type == LogicalOperatorType::COMPARISON_JOIN || op->type == LogicalOperatorType::CROSS_PRODUCT) {
+	if (op->type == LogicalOperatorType::LOGICAL_COMPARISON_JOIN ||
+	    op->type == LogicalOperatorType::LOGICAL_CROSS_PRODUCT) {
 		// inner join or cross product
 		bool can_reorder_left = ExtractJoinRelations(*op->children[0], filter_operators, op);
 		bool can_reorder_right = ExtractJoinRelations(*op->children[1], filter_operators, op);
 		return can_reorder_left && can_reorder_right;
-	} else if (op->type == LogicalOperatorType::GET) {
+	} else if (op->type == LogicalOperatorType::LOGICAL_GET) {
 		// base table scan, add to set of relations
 		auto get = (LogicalGet *)op;
 		auto relation = make_unique<SingleJoinRelation>(&input_op, parent);
 		relation_mapping[get->table_index] = relations.size();
 		relations.push_back(move(relation));
 		return true;
-	} else if (op->type == LogicalOperatorType::EXPRESSION_GET) {
+	} else if (op->type == LogicalOperatorType::LOGICAL_EXPRESSION_GET) {
 		// base table scan, add to set of relations
 		auto get = (LogicalExpressionGet *)op;
 		auto relation = make_unique<SingleJoinRelation>(&input_op, parent);
 		relation_mapping[get->table_index] = relations.size();
 		relations.push_back(move(relation));
 		return true;
-	} else if (op->type == LogicalOperatorType::DUMMY_SCAN) {
+	} else if (op->type == LogicalOperatorType::LOGICAL_DUMMY_SCAN) {
 		// table function call, add to set of relations
 		auto dummy_scan = (LogicalDummyScan *)op;
 		auto relation = make_unique<SingleJoinRelation>(&input_op, parent);
 		relation_mapping[dummy_scan->table_index] = relations.size();
 		relations.push_back(move(relation));
 		return true;
-	} else if (op->type == LogicalOperatorType::PROJECTION) {
+	} else if (op->type == LogicalOperatorType::LOGICAL_PROJECTION) {
 		auto proj = (LogicalProjection *)op;
 		// we run the join order optimizer witin the subquery as well
-		JoinOrderOptimizer optimizer;
+		JoinOrderOptimizer optimizer(context);
 		op->children[0] = optimizer.Optimize(move(op->children[0]));
 		// projection, add to the set of relations
 		auto relation = make_unique<SingleJoinRelation>(&input_op, parent);
@@ -396,14 +413,14 @@ void JoinOrderOptimizer::SolveJoinOrderApproximately() {
 					}
 				}
 			}
-			assert(smallest_plans[0] && smallest_plans[1]);
-			assert(smallest_index[0] != smallest_index[1]);
+			D_ASSERT(smallest_plans[0] && smallest_plans[1]);
+			D_ASSERT(smallest_index[0] != smallest_index[1]);
 			auto left = smallest_plans[0]->set, right = smallest_plans[1]->set;
 			// create a cross product edge (i.e. edge with empty filter) between these two sets in the query graph
 			query_graph.CreateEdge(left, right, nullptr);
 			// now emit the pair and continue with the algorithm
 			auto connection = query_graph.GetConnection(left, right);
-			assert(connection);
+			D_ASSERT(connection);
 
 			best_connection = EmitPair(left, right, connection);
 			best_left = smallest_index[0];
@@ -418,7 +435,7 @@ void JoinOrderOptimizer::SolveJoinOrderApproximately() {
 
 		// important to erase the biggest element first
 		// if we erase the smallest element first the index of the biggest element changes
-		assert(best_right > best_left);
+		D_ASSERT(best_right > best_left);
 		T.erase(T.begin() + best_right);
 		T.erase(T.begin() + best_left);
 		T.push_back(best_connection->set);
@@ -485,15 +502,15 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 			// set the join conditions from the join node
 			for (auto &f : node->info->filters) {
 				// extract the filter from the operator it originally belonged to
-				assert(filters[f->filter_index]);
+				D_ASSERT(filters[f->filter_index]);
 				auto condition = move(filters[f->filter_index]);
 				// now create the actual join condition
-				assert((JoinRelationSet::IsSubset(left.first, f->left_set) &&
-				        JoinRelationSet::IsSubset(right.first, f->right_set)) ||
-				       (JoinRelationSet::IsSubset(left.first, f->right_set) &&
-				        JoinRelationSet::IsSubset(right.first, f->left_set)));
+				D_ASSERT((JoinRelationSet::IsSubset(left.first, f->left_set) &&
+				          JoinRelationSet::IsSubset(right.first, f->right_set)) ||
+				         (JoinRelationSet::IsSubset(left.first, f->right_set) &&
+				          JoinRelationSet::IsSubset(right.first, f->left_set)));
 				JoinCondition cond;
-				assert(condition->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON);
+				D_ASSERT(condition->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON);
 				auto &comparison = (BoundComparisonExpression &)*condition;
 				// we need to figure out which side is which by looking at the relations available to us
 				bool invert = JoinRelationSet::IsSubset(left.first, f->left_set) ? false : true;
@@ -506,7 +523,7 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 				}
 				join->conditions.push_back(move(cond));
 			}
-			assert(join->conditions.size() > 0);
+			D_ASSERT(join->conditions.size() > 0);
 			result_operator = move(join);
 		}
 		left_node = left.first;
@@ -514,8 +531,8 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 		result_relation = set_manager.Union(left_node, right_node);
 	} else {
 		// base node, get the entry from the list of extracted relations
-		assert(node->set->count == 1);
-		assert(extracted_relations[node->set->relations[0]]);
+		D_ASSERT(node->set->count == 1);
+		D_ASSERT(extracted_relations[node->set->relations[0]]);
 		result_relation = node->set;
 		result_operator = move(extracted_relations[node->set->relations[0]]);
 	}
@@ -557,7 +574,7 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 				}
 				// create the join condition
 				JoinCondition cond;
-				assert(filter->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON);
+				D_ASSERT(filter->GetExpressionClass() == ExpressionClass::BOUND_COMPARISON);
 				auto &comparison = (BoundComparisonExpression &)*filter;
 				// we need to figure out which side is which by looking at the relations available to us
 				cond.left = !invert ? move(comparison.left) : move(comparison.right);
@@ -569,10 +586,10 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 				}
 				// now find the join to push it into
 				auto node = result_operator.get();
-				if (node->type == LogicalOperatorType::FILTER) {
+				if (node->type == LogicalOperatorType::LOGICAL_FILTER) {
 					node = node->children[0].get();
 				}
-				if (node->type == LogicalOperatorType::CROSS_PRODUCT) {
+				if (node->type == LogicalOperatorType::LOGICAL_CROSS_PRODUCT) {
 					// turn into comparison join
 					auto comp_join = make_unique<LogicalComparisonJoin>(JoinType::INNER);
 					comp_join->children.push_back(move(node->children[0]));
@@ -581,11 +598,11 @@ JoinOrderOptimizer::GenerateJoins(vector<unique_ptr<LogicalOperator>> &extracted
 					if (node == result_operator.get()) {
 						result_operator = move(comp_join);
 					} else {
-						assert(result_operator->type == LogicalOperatorType::FILTER);
+						D_ASSERT(result_operator->type == LogicalOperatorType::LOGICAL_FILTER);
 						result_operator->children[0] = move(comp_join);
 					}
 				} else {
-					assert(node->type == LogicalOperatorType::COMPARISON_JOIN);
+					D_ASSERT(node->type == LogicalOperatorType::LOGICAL_COMPARISON_JOIN);
 					auto &comp_join = (LogicalComparisonJoin &)*node;
 					comp_join.conditions.push_back(move(cond));
 				}
@@ -620,12 +637,13 @@ unique_ptr<LogicalOperator> JoinOrderOptimizer::RewritePlan(unique_ptr<LogicalOp
 		// first node is the join, return it immediately
 		return move(join_tree.second);
 	}
-	assert(plan->children.size() == 1);
+	D_ASSERT(plan->children.size() == 1);
 	// have to move up through the relations
 	auto op = plan.get();
 	auto parent = plan.get();
-	while (op->type != LogicalOperatorType::CROSS_PRODUCT && op->type != LogicalOperatorType::COMPARISON_JOIN) {
-		assert(op->children.size() == 1);
+	while (op->type != LogicalOperatorType::LOGICAL_CROSS_PRODUCT &&
+	       op->type != LogicalOperatorType::LOGICAL_COMPARISON_JOIN) {
+		D_ASSERT(op->children.size() == 1);
 		parent = op;
 		op = op->children[0].get();
 	}
@@ -639,7 +657,8 @@ unique_ptr<LogicalOperator> JoinOrderOptimizer::RewritePlan(unique_ptr<LogicalOp
 // https://db.in.tum.de/teaching/ws1415/queryopt/chapter3.pdf?lang=de
 // FIXME: incorporate cardinality estimation into the plans, possibly by pushing samples?
 unique_ptr<LogicalOperator> JoinOrderOptimizer::Optimize(unique_ptr<LogicalOperator> plan) {
-	assert(filters.size() == 0 && relations.size() == 0); // assert that the JoinOrderOptimizer has not been used before
+	D_ASSERT(filters.size() == 0 &&
+	         relations.size() == 0); // assert that the JoinOrderOptimizer has not been used before
 	LogicalOperator *op = plan.get();
 	// now we optimize the current plan
 	// we skip past until we find the first projection, we do this because the HAVING clause inserts a Filter AFTER the
@@ -659,10 +678,10 @@ unique_ptr<LogicalOperator> JoinOrderOptimizer::Optimize(unique_ptr<LogicalOpera
 	// filters in the process
 	expression_set_t filter_set;
 	for (auto &op : filter_operators) {
-		if (op->type == LogicalOperatorType::COMPARISON_JOIN) {
+		if (op->type == LogicalOperatorType::LOGICAL_COMPARISON_JOIN) {
 			auto &join = (LogicalComparisonJoin &)*op;
-			assert(join.join_type == JoinType::INNER);
-			assert(join.expressions.size() == 0);
+			D_ASSERT(join.join_type == JoinType::INNER);
+			D_ASSERT(join.expressions.size() == 0);
 			for (auto &cond : join.conditions) {
 				auto comparison =
 				    make_unique<BoundComparisonExpression>(cond.comparison, move(cond.left), move(cond.right));
@@ -737,7 +756,7 @@ unique_ptr<LogicalOperator> JoinOrderOptimizer::Optimize(unique_ptr<LogicalOpera
 	for (idx_t i = 0; i < relations.size(); i++) {
 		auto &rel = *relations[i];
 		auto node = set_manager.GetJoinRelation(i);
-		plans[node] = make_unique<JoinNode>(node, rel.op->EstimateCardinality());
+		plans[node] = make_unique<JoinNode>(node, rel.op->EstimateCardinality(context));
 	}
 	// now we perform the actual dynamic programming to compute the final result
 	SolveJoinOrder();
@@ -758,7 +777,7 @@ unique_ptr<LogicalOperator> JoinOrderOptimizer::Optimize(unique_ptr<LogicalOpera
 		SolveJoinOrder();
 		// now we can obtain the final plan!
 		final_plan = plans.find(total_relation);
-		assert(final_plan != plans.end());
+		D_ASSERT(final_plan != plans.end());
 	}
 	// now perform the actual reordering
 	return RewritePlan(move(plan), final_plan->second.get());
