@@ -3,6 +3,7 @@
 #include "duckdb/execution/expression_executor.hpp"
 #include "duckdb/main/client_context.hpp"
 #include "duckdb/optimizer/column_lifetime_optimizer.hpp"
+#include "duckdb/optimizer/common_aggregate_optimizer.hpp"
 #include "duckdb/optimizer/cse_optimizer.hpp"
 #include "duckdb/optimizer/expression_heuristics.hpp"
 #include "duckdb/optimizer/filter_pushdown.hpp"
@@ -12,6 +13,7 @@
 #include "duckdb/optimizer/remove_unused_columns.hpp"
 #include "duckdb/optimizer/rule/list.hpp"
 #include "duckdb/optimizer/topn_optimizer.hpp"
+#include "duckdb/optimizer/statistics_propagator.hpp"
 #include "duckdb/planner/binder.hpp"
 
 namespace duckdb {
@@ -32,7 +34,7 @@ Optimizer::Optimizer(Binder &binder, ClientContext &context) : context(context),
 #ifdef DEBUG
 	for (auto &rule : rewriter.rules) {
 		// root not defined in rule
-		assert(rule->root);
+		D_ASSERT(rule->root);
 	}
 #endif
 }
@@ -41,7 +43,7 @@ unique_ptr<LogicalOperator> Optimizer::Optimize(unique_ptr<LogicalOperator> plan
 	// first we perform expression rewrites using the ExpressionRewriter
 	// this does not change the logical plan structure, but only simplifies the expression trees
 	context.profiler.StartPhase("expression_rewriter");
-	rewriter.Apply(*plan);
+	rewriter.VisitOperator(*plan);
 	context.profiler.EndPhase();
 
 	// perform filter pushdown
@@ -63,21 +65,32 @@ unique_ptr<LogicalOperator> Optimizer::Optimize(unique_ptr<LogicalOperator> plan
 	// then we perform the join ordering optimization
 	// this also rewrites cross products + filters into joins and performs filter pushdowns
 	context.profiler.StartPhase("join_order");
-	JoinOrderOptimizer optimizer;
+	JoinOrderOptimizer optimizer(context);
 	plan = optimizer.Optimize(move(plan));
 	context.profiler.EndPhase();
 
-	// then we extract common subexpressions inside the different operators
-	// context.profiler.StartPhase("common_subexpressions");
-	// CommonSubExpressionOptimizer cse_optimizer;
-	// cse_optimizer.VisitOperator(*plan);
-	// context.profiler.EndPhase();
-
 	context.profiler.StartPhase("unused_columns");
 	RemoveUnusedColumns unused(binder, context, true);
 	unused.VisitOperator(*plan);
 	context.profiler.EndPhase();
 
+	// perform statistics propagation
+	context.profiler.StartPhase("statistics_propagation");
+	StatisticsPropagator propagator(context);
+	propagator.PropagateStatistics(plan);
+	context.profiler.EndPhase();
+
+	// then we extract common subexpressions inside the different operators
+	context.profiler.StartPhase("common_subexpressions");
+	CommonSubExpressionOptimizer cse_optimizer(binder);
+	cse_optimizer.VisitOperator(*plan);
+	context.profiler.EndPhase();
+
+	context.profiler.StartPhase("common_aggregate");
+	CommonAggregateOptimizer common_aggregate;
+	common_aggregate.VisitOperator(*plan);
+	context.profiler.EndPhase();
+
 	context.profiler.StartPhase("column_lifetime");
 	ColumnLifetimeAnalyzer column_lifetime(true);
 	column_lifetime.VisitOperator(*plan);
