@@ -87,8 +87,8 @@ void Executor::BuildPipelines(PhysicalOperator *op, Pipeline *parent) {
 		case PhysicalOperatorType::UPDATE:
 		case PhysicalOperatorType::CREATE:
 		case PhysicalOperatorType::HASH_GROUP_BY:
-		case PhysicalOperatorType::DISTINCT:
 		case PhysicalOperatorType::SIMPLE_AGGREGATE:
+		case PhysicalOperatorType::PERFECT_HASH_GROUP_BY:
 		case PhysicalOperatorType::WINDOW:
 		case PhysicalOperatorType::ORDER_BY:
 		case PhysicalOperatorType::TOP_N:
@@ -120,7 +120,7 @@ void Executor::BuildPipelines(PhysicalOperator *op, Pipeline *parent) {
 			break;
 		}
 		default:
-			throw NotImplementedException("Unimplemented sink type!");
+			throw InternalException("Unimplemented sink type!");
 		}
 		// recurse into the pipeline child
 		BuildPipelines(pipeline->child, pipeline.get());
@@ -146,10 +146,10 @@ void Executor::BuildPipelines(PhysicalOperator *op, Pipeline *parent) {
 		case PhysicalOperatorType::DELIM_SCAN: {
 			// check if this chunk scan scans a duplicate eliminated join collection
 			auto entry = delim_join_dependencies.find(op);
-			assert(entry != delim_join_dependencies.end());
+			D_ASSERT(entry != delim_join_dependencies.end());
 			// this chunk scan introduces a dependency to the current pipeline
 			// namely a dependency on the duplicate elimination pipeline to finish
-			assert(parent);
+			D_ASSERT(parent);
 			parent->AddDependency(entry->second);
 			break;
 		}
@@ -175,7 +175,8 @@ void Executor::BuildPipelines(PhysicalOperator *op, Pipeline *parent) {
 				auto &deps = cte_node.pipelines[i]->GetDependencies();
 				for (idx_t j = i + 1; j < cte_node.pipelines.size(); j++) {
 					if (deps.find(cte_node.pipelines[j].get()) != deps.end()) {
-						// pipeline "i" depends on pipeline "j" but pipeline "i" is scheduled to be executed before pipeline "j"
+						// pipeline "i" depends on pipeline "j" but pipeline "i" is scheduled to be executed before
+						// pipeline "j"
 						std::swap(cte_node.pipelines[i], cte_node.pipelines[j]);
 						i--;
 						continue;
@@ -210,7 +211,7 @@ void Executor::BuildPipelines(PhysicalOperator *op, Pipeline *parent) {
 }
 
 vector<LogicalType> Executor::GetTypes() {
-	assert(physical_plan);
+	D_ASSERT(physical_plan);
 	return physical_plan->GetTypes();
 }
 
@@ -228,7 +229,7 @@ void Executor::Flush(ThreadContext &tcontext) {
 }
 
 unique_ptr<DataChunk> Executor::FetchChunk() {
-	assert(physical_plan);
+	D_ASSERT(physical_plan);
 
 	ThreadContext thread(context);
 	TaskContext task;
