@@ -9,6 +9,10 @@ void BaseExpression::Print() {
 	Printer::Print(ToString());
 }
 
+string BaseExpression::GetName() const {
+	return !alias.empty() ? alias : ToString();
+}
+
 bool BaseExpression::Equals(const BaseExpression *other) const {
 	if (!other) {
 		return false;
