@@ -30,6 +30,7 @@ unique_ptr<QueryNode> RecursiveCTENode::Copy() {
 	result->union_all = union_all;
 	result->left = left->Copy();
 	result->right = right->Copy();
+	result->aliases = aliases;
 	this->CopyProperties(*result);
 	return move(result);
 }
@@ -40,6 +41,7 @@ void RecursiveCTENode::Serialize(Serializer &serializer) {
 	serializer.WriteString(union_all ? "T" : "F");
 	left->Serialize(serializer);
 	right->Serialize(serializer);
+	serializer.WriteStringVector(aliases);
 }
 
 unique_ptr<QueryNode> RecursiveCTENode::Deserialize(Deserializer &source) {
@@ -48,6 +50,7 @@ unique_ptr<QueryNode> RecursiveCTENode::Deserialize(Deserializer &source) {
 	result->union_all = source.Read<string>() == "T" ? true : false;
 	result->left = QueryNode::Deserialize(source);
 	result->right = QueryNode::Deserialize(source);
+	source.ReadStringVector(result->aliases);
 	return move(result);
 }
 
