@@ -10,7 +10,7 @@ bool BaseTableRef::Equals(const TableRef *other_) const {
 		return false;
 	}
 	auto other = (BaseTableRef *)other_;
-	return other->schema_name == schema_name && other->table_name == table_name;
+	return other->schema_name == schema_name && other->table_name == table_name && column_name_alias == other->column_name_alias;
 }
 
 void BaseTableRef::Serialize(Serializer &serializer) {
@@ -18,6 +18,7 @@ void BaseTableRef::Serialize(Serializer &serializer) {
 
 	serializer.WriteString(schema_name);
 	serializer.WriteString(table_name);
+	serializer.WriteStringVector(column_name_alias);
 }
 
 unique_ptr<TableRef> BaseTableRef::Deserialize(Deserializer &source) {
@@ -25,6 +26,7 @@ unique_ptr<TableRef> BaseTableRef::Deserialize(Deserializer &source) {
 
 	result->schema_name = source.Read<string>();
 	result->table_name = source.Read<string>();
+	source.ReadStringVector(result->column_name_alias);
 
 	return move(result);
 }
@@ -35,6 +37,7 @@ unique_ptr<TableRef> BaseTableRef::Copy() {
 	copy->schema_name = schema_name;
 	copy->table_name = table_name;
 	copy->alias = alias;
+	copy->column_name_alias = column_name_alias;
 
 	return move(copy);
 }
