@@ -18,14 +18,18 @@ unique_ptr<ParsedExpression> Transformer::TransformColumnRef(PGColumnRef *root)
 		string column_name, table_name;
 		if (fields->length == 1) {
 			column_name = string(reinterpret_cast<PGValue *>(fields->head->data.ptr_value)->val.str);
-			return make_unique<ColumnRefExpression>(column_name, table_name);
+			auto colref = make_unique<ColumnRefExpression>(column_name, table_name);
+			colref->query_location = root->location;
+			return move(colref);
 		} else {
 			table_name = string(reinterpret_cast<PGValue *>(fields->head->data.ptr_value)->val.str);
 			auto col_node = reinterpret_cast<PGNode *>(fields->head->next->data.ptr_value);
 			switch (col_node->type) {
 			case T_PGString: {
 				column_name = string(reinterpret_cast<PGValue *>(col_node)->val.str);
-				return make_unique<ColumnRefExpression>(column_name, table_name);
+				auto colref = make_unique<ColumnRefExpression>(column_name, table_name);
+				colref->query_location = root->location;
+				return move(colref);
 			}
 			case T_PGAStar: {
 				return make_unique<TableStarExpression>(table_name);
