@@ -7,7 +7,7 @@ using namespace duckdb_libpgquery;
 
 unique_ptr<ExplainStatement> Transformer::TransformExplain(PGNode *node) {
 	PGExplainStmt *stmt = reinterpret_cast<PGExplainStmt *>(node);
-	assert(stmt);
+	D_ASSERT(stmt);
 	return make_unique<ExplainStatement>(TransformStatement(stmt->query));
 }
 
