@@ -10,11 +10,13 @@ using namespace duckdb_libpgquery;
 
 bool Transformer::TransformParseTree(PGList *tree, vector<unique_ptr<SQLStatement>> &statements) {
 	for (auto entry = tree->head; entry != nullptr; entry = entry->next) {
+		SetParamCount(0);
 		auto stmt = TransformStatement((PGNode *)entry->data.ptr_value);
 		if (!stmt) {
 			statements.clear();
 			return false;
 		}
+		stmt->n_param = ParamCount();
 		statements.push_back(move(stmt));
 	}
 	return true;
@@ -41,6 +43,8 @@ unique_ptr<SQLStatement> Transformer::TransformStatement(PGNode *stmt) {
 		return TransformCreateView(stmt);
 	case T_PGCreateSeqStmt:
 		return TransformCreateSequence(stmt);
+	case T_PGCreateFunctionStmt:
+		return TransformCreateFunction(stmt);
 	case T_PGDropStmt:
 		return TransformDrop(stmt);
 	case T_PGInsertStmt:
