@@ -45,9 +45,13 @@ vector<string> BindContext::GetSimilarBindings(const string &column_name) {
 	return StringUtil::TopNStrings(scores);
 }
 
+void BindContext::HideBinding(const string &binding_name, const string &column_name) {
+	hidden_columns.insert(QualifiedColumnName(binding_name, column_name));
+}
+
 bool BindContext::BindingIsHidden(const string &binding_name, const string &column_name) {
-	string total_binding = binding_name + "." + column_name;
-	return hidden_columns.find(total_binding) != hidden_columns.end();
+	QualifiedColumnName qcolumn(binding_name, column_name);
+	return hidden_columns.find(qcolumn) != hidden_columns.end();
 }
 
 unordered_set<string> BindContext::GetMatchingBindings(const string &column_name) {
@@ -98,6 +102,16 @@ BindResult BindContext::BindColumn(ColumnRefExpression &colref, idx_t depth) {
 	return binding->Bind(colref, depth);
 }
 
+void BindContext::GenerateAllColumnExpressions(vector<unique_ptr<ParsedExpression>> &new_select_list, Binding *binding) {
+	for (auto &column_name : binding->names) {
+		D_ASSERT(!column_name.empty());
+		if (BindingIsHidden(binding->alias, column_name)) {
+			continue;
+		}
+		new_select_list.push_back(make_unique<ColumnRefExpression>(column_name, binding->alias));
+	}
+}
+
 void BindContext::GenerateAllColumnExpressions(vector<unique_ptr<ParsedExpression>> &new_select_list,
                                                string relation_name) {
 	if (bindings_list.size() == 0) {
@@ -107,7 +121,7 @@ void BindContext::GenerateAllColumnExpressions(vector<unique_ptr<ParsedExpressio
 		// we have to bind the tables and subqueries in order of table_index
 		for (auto &entry : bindings_list) {
 			auto binding = entry.second;
-			binding->GenerateAllColumnExpressions(*this, new_select_list);
+			GenerateAllColumnExpressions(new_select_list, binding);
 		}
 	} else { // SELECT tbl.* case
 		string error;
@@ -115,7 +129,7 @@ void BindContext::GenerateAllColumnExpressions(vector<unique_ptr<ParsedExpressio
 		if (!binding) {
 			throw BinderException(error);
 		}
-		binding->GenerateAllColumnExpressions(*this, new_select_list);
+		GenerateAllColumnExpressions(new_select_list, binding);
 	}
 }
 
@@ -173,4 +187,19 @@ void BindContext::AddCTEBinding(idx_t index, const string &alias, vector<string>
 	cte_references[alias] = std::make_shared<idx_t>(0);
 }
 
+void BindContext::AddContext(BindContext other) {
+	for(auto &binding : other.bindings) {
+		if (bindings.find(binding.first) != bindings.end()) {
+			throw BinderException("Duplicate alias \"%s\" in query!", binding.first);
+		}
+		bindings[binding.first] = move(binding.second);
+	}
+	for(auto &binding : other.bindings_list) {
+		bindings_list.push_back(move(binding));
+	}
+	for(auto &hidden_column : other.hidden_columns) {
+		hidden_columns.insert(hidden_column);
+	}
+}
+
 } // namespace duckdb
