@@ -22,7 +22,7 @@ static void GatherAliases(BoundQueryNode &node, unordered_map<string, idx_t> &al
 		GatherAliases(*setop.right, aliases, expressions);
 	} else {
 		// query node
-		assert(node.type == QueryNodeType::SELECT_NODE);
+		D_ASSERT(node.type == QueryNodeType::SELECT_NODE);
 		auto &select = (BoundSelectNode &)node;
 		// fill the alias lists
 		for (idx_t i = 0; i < select.names.size(); i++) {
@@ -65,8 +65,8 @@ unique_ptr<BoundQueryNode> Binder::BindNode(SetOperationNode &statement) {
 
 	// first recursively visit the set operations
 	// both the left and right sides have an independent BindContext and Binder
-	assert(statement.left);
-	assert(statement.right);
+	D_ASSERT(statement.left);
+	D_ASSERT(statement.right);
 
 	result->setop_index = GenerateTableIndex();
 
