@@ -19,7 +19,7 @@ namespace duckdb {
 static unique_ptr<Expression> PlanUncorrelatedSubquery(Binder &binder, BoundSubqueryExpression &expr,
                                                        unique_ptr<LogicalOperator> &root,
                                                        unique_ptr<LogicalOperator> plan) {
-	assert(!expr.IsCorrelated());
+	D_ASSERT(!expr.IsCorrelated());
 	switch (expr.subquery_type) {
 	case SubqueryType::EXISTS: {
 		// uncorrelated EXISTS
@@ -69,7 +69,7 @@ static unique_ptr<Expression> PlanUncorrelatedSubquery(Binder &binder, BoundSubq
 		// uncorrelated scalar, we want to return the first entry
 		// figure out the table index of the bound table of the entry which we want to return
 		auto bindings = plan->GetColumnBindings();
-		assert(bindings.size() == 1);
+		D_ASSERT(bindings.size() == 1);
 		idx_t table_idx = bindings[0].table_index;
 
 		// in the uncorrelated case we are only interested in the first result of the query
@@ -95,7 +95,7 @@ static unique_ptr<Expression> PlanUncorrelatedSubquery(Binder &binder, BoundSubq
 		// in the uncorrelated case, we add the value to the main query through a cross product
 		// FIXME: should use something else besides cross product as we always add only one scalar constant and cross
 		// product is not optimized for this.
-		assert(root);
+		D_ASSERT(root);
 		auto cross_product = make_unique<LogicalCrossProduct>();
 		cross_product->AddChild(move(root));
 		cross_product->AddChild(move(plan));
@@ -106,7 +106,7 @@ static unique_ptr<Expression> PlanUncorrelatedSubquery(Binder &binder, BoundSubq
 		return make_unique<BoundColumnRefExpression>(expr.GetName(), expr.return_type, ColumnBinding(aggr_index, 0));
 	}
 	default: {
-		assert(expr.subquery_type == SubqueryType::ANY);
+		D_ASSERT(expr.subquery_type == SubqueryType::ANY);
 		// we generate a MARK join that results in either (TRUE, FALSE or NULL)
 		// subquery has NULL values -> result is (TRUE or NULL)
 		// subquery has no NULL values -> result is (TRUE, FALSE or NULL [if input is NULL])
@@ -162,7 +162,7 @@ static unique_ptr<Expression> PlanCorrelatedSubquery(Binder &binder, BoundSubque
                                                      unique_ptr<LogicalOperator> &root,
                                                      unique_ptr<LogicalOperator> plan) {
 	auto &correlated_columns = expr.binder->correlated_columns;
-	assert(expr.IsCorrelated());
+	D_ASSERT(expr.IsCorrelated());
 	// correlated subquery
 	// for a more in-depth explanation of this code, read the paper "Unnesting Arbitrary Subqueries"
 	// we handle three types of correlated subqueries: Scalar, EXISTS and ANY
@@ -230,7 +230,7 @@ static unique_ptr<Expression> PlanCorrelatedSubquery(Binder &binder, BoundSubque
 		return make_unique<BoundColumnRefExpression>(expr.GetName(), expr.return_type, ColumnBinding(mark_index, 0));
 	}
 	default: {
-		assert(expr.subquery_type == SubqueryType::ANY);
+		D_ASSERT(expr.subquery_type == SubqueryType::ANY);
 		// correlated ANY query
 		// this query is similar to the correlated SCALAR query
 		// however, in this case we push a correlated MARK join
@@ -294,13 +294,13 @@ private:
 };
 
 unique_ptr<Expression> Binder::PlanSubquery(BoundSubqueryExpression &expr, unique_ptr<LogicalOperator> &root) {
-	assert(root);
+	D_ASSERT(root);
 	// first we translate the QueryNode of the subquery into a logical plan
 	// note that we do not plan nested subqueries yet
 	Binder sub_binder(context);
 	sub_binder.plan_subquery = false;
 	auto subquery_root = sub_binder.CreatePlan(*expr.subquery);
-	assert(subquery_root);
+	D_ASSERT(subquery_root);
 
 	// now we actually flatten the subquery
 	auto plan = move(subquery_root);
@@ -322,10 +322,7 @@ void Binder::PlanSubqueries(unique_ptr<Expression> *expr_ptr, unique_ptr<Logical
 	auto &expr = **expr_ptr;
 
 	// first visit the children of the node, if any
-	ExpressionIterator::EnumerateChildren(expr, [&](unique_ptr<Expression> expr) -> unique_ptr<Expression> {
-		PlanSubqueries(&expr, root);
-		return expr;
-	});
+	ExpressionIterator::EnumerateChildren(expr, [&](unique_ptr<Expression> &expr) { PlanSubqueries(&expr, root); });
 
 	// check if this is a subquery node
 	if (expr.expression_class == ExpressionClass::BOUND_SUBQUERY) {
