@@ -7,7 +7,11 @@ using namespace std;
 
 unique_ptr<BoundTableRef> Binder::Bind(SubqueryRef &ref) {
 	auto binder = make_unique<Binder>(context, this);
-	auto subquery = binder->BindNode(*ref.subquery);
+	binder->alias = ref.alias;
+	for (auto &cte_it : ref.subquery->cte_map) {
+		binder->AddCTE(cte_it.first, cte_it.second.get());
+	}
+	auto subquery = binder->BindNode(*ref.subquery->node);
 	idx_t bind_index = subquery->GetRootIndex();
 	auto result = make_unique<BoundSubqueryRef>(move(binder), move(subquery));
 
