@@ -6,19 +6,20 @@
 namespace duckdb {
 using namespace std;
 
-BoundConstantExpression::BoundConstantExpression(Value value)
-    : Expression(ExpressionType::VALUE_CONSTANT, ExpressionClass::BOUND_CONSTANT, value.type()), value(value) {
+BoundConstantExpression::BoundConstantExpression(Value value_p)
+    : Expression(ExpressionType::VALUE_CONSTANT, ExpressionClass::BOUND_CONSTANT, value_p.type()),
+      value(move(value_p)) {
 }
 
 string BoundConstantExpression::ToString() const {
 	return value.ToString();
 }
 
-bool BoundConstantExpression::Equals(const BaseExpression *other_) const {
-	if (!Expression::Equals(other_)) {
+bool BoundConstantExpression::Equals(const BaseExpression *other_p) const {
+	if (!Expression::Equals(other_p)) {
 		return false;
 	}
-	auto other = (BoundConstantExpression *)other_;
+	auto other = (BoundConstantExpression *)other_p;
 	return value == other->value;
 }
 
