@@ -13,7 +13,8 @@ HavingBinder::HavingBinder(Binder &binder, ClientContext &context, BoundSelectNo
 	target_type = LogicalType(LogicalTypeId::BOOLEAN);
 }
 
-BindResult HavingBinder::BindExpression(ParsedExpression &expr, idx_t depth, bool root_expression) {
+BindResult HavingBinder::BindExpression(unique_ptr<ParsedExpression> *expr_ptr, idx_t depth, bool root_expression) {
+	auto &expr = **expr_ptr;
 	// check if the expression binds to one of the groups
 	auto group_index = TryBindGroup(expr, depth);
 	if (group_index != INVALID_INDEX) {
@@ -26,7 +27,7 @@ BindResult HavingBinder::BindExpression(ParsedExpression &expr, idx_t depth, boo
 		return BindResult(StringUtil::Format(
 		    "column %s must appear in the GROUP BY clause or be used in an aggregate function", expr.ToString()));
 	default:
-		return ExpressionBinder::BindExpression(expr, depth);
+		return ExpressionBinder::BindExpression(expr_ptr, depth);
 	}
 }
 
