@@ -8,7 +8,8 @@ RelationBinder::RelationBinder(Binder &binder, ClientContext &context, string op
     : ExpressionBinder(binder, context), op(move(op)) {
 }
 
-BindResult RelationBinder::BindExpression(ParsedExpression &expr, idx_t depth, bool root_expression) {
+BindResult RelationBinder::BindExpression(unique_ptr<ParsedExpression> *expr_ptr, idx_t depth, bool root_expression) {
+	auto &expr = **expr_ptr;
 	switch (expr.expression_class) {
 	case ExpressionClass::AGGREGATE:
 		return BindResult("aggregate functions are not allowed in " + op);
@@ -19,7 +20,7 @@ BindResult RelationBinder::BindExpression(ParsedExpression &expr, idx_t depth, b
 	case ExpressionClass::WINDOW:
 		return BindResult("window functions are not allowed in " + op);
 	default:
-		return ExpressionBinder::BindExpression(expr, depth);
+		return ExpressionBinder::BindExpression(expr_ptr, depth);
 	}
 }
 
