@@ -4,7 +4,7 @@ namespace duckdb {
 using namespace std;
 
 LogicalProjection::LogicalProjection(idx_t table_index, vector<unique_ptr<Expression>> select_list)
-    : LogicalOperator(LogicalOperatorType::PROJECTION, move(select_list)), table_index(table_index) {
+    : LogicalOperator(LogicalOperatorType::LOGICAL_PROJECTION, move(select_list)), table_index(table_index) {
 }
 
 vector<ColumnBinding> LogicalProjection::GetColumnBindings() {
