@@ -50,15 +50,19 @@ void Planner::CreatePlan(SQLStatement &statement) {
 		auto value = make_unique<Value>(expr->return_type);
 		expr->value = value.get();
 		// check if the parameter number has been used before
-		if (value_map.find(expr->parameter_nr) != value_map.end()) {
-			throw BinderException("Duplicate parameter index. Use $1, $2 etc. to differentiate.");
+		if (value_map.find(expr->parameter_nr) == value_map.end()) {
+			// not used before, create vector
+			value_map[expr->parameter_nr] = vector<unique_ptr<Value>>();
+		} else if (value_map[expr->parameter_nr].back()->type() != value->type()) {
+			// used before, but types are inconsistent
+			throw BinderException("Inconsistent types found for parameter with index %llu", expr->parameter_nr);
 		}
-		value_map[expr->parameter_nr] = move(value);
+		value_map[expr->parameter_nr].push_back(move(value));
 	}
 }
 
 void Planner::CreatePlan(unique_ptr<SQLStatement> statement) {
-	assert(statement);
+	D_ASSERT(statement);
 	switch (statement->type) {
 	case StatementType::SELECT_STATEMENT:
 	case StatementType::INSERT_STATEMENT:
@@ -146,12 +150,12 @@ void Planner::CreatePlan(unique_ptr<SQLStatement> statement) {
 // 				auto inner_hash = copies[j]->Hash();
 // 				if (outer_hash != inner_hash) {
 // 					// if hashes are not equivalent the expressions should not be equivalent
-// 					assert(!Expression::Equals(copies[i].get(), copies[j].get()));
+// 					D_ASSERT(!Expression::Equals(copies[i].get(), copies[j].get()));
 // 				}
 // 			}
 // 		}
 // 	} else {
-// 		assert(node.type == QueryNodeType::SET_OPERATION_NODE);
+// 		D_ASSERT(node.type == QueryNodeType::SET_OPERATION_NODE);
 // 		auto &setop_node = (BoundSetOperationNode &)node;
 // 		VerifyNode(*setop_node.left);
 // 		VerifyNode(*setop_node.right);
@@ -166,8 +170,8 @@ void Planner::CreatePlan(unique_ptr<SQLStatement> statement) {
 // 	// verify that the copy of expressions works
 // 	auto copy = expr.Copy();
 // 	// copy should have identical hash and identical equality function
-// 	assert(copy->Hash() == expr.Hash());
-// 	assert(Expression::Equals(copy.get(), &expr));
+// 	D_ASSERT(copy->Hash() == expr.Hash());
+// 	D_ASSERT(Expression::Equals(copy.get(), &expr));
 // 	copies.push_back(move(copy));
 // }
 
