@@ -24,7 +24,7 @@ FlattenDependentJoins::FlattenDependentJoins(Binder &binder, const vector<Correl
 }
 
 bool FlattenDependentJoins::DetectCorrelatedExpressions(LogicalOperator *op) {
-	assert(op);
+	D_ASSERT(op);
 	// check if this entry has correlated expressions
 	HasCorrelatedExpressions visitor(correlated_columns);
 	visitor.VisitOperator(*op);
@@ -56,7 +56,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoin(unique_
 unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal(unique_ptr<LogicalOperator> plan) {
 	// first check if the logical operator has correlated expressions
 	auto entry = has_correlated_expressions.find(plan.get());
-	assert(entry != has_correlated_expressions.end());
+	D_ASSERT(entry != has_correlated_expressions.end());
 	if (!entry->second) {
 		// we reached a node without correlated expressions
 		// we can eliminate the dependent join now and create a simple cross product
@@ -70,7 +70,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		return move(cross_product);
 	}
 	switch (plan->type) {
-	case LogicalOperatorType::FILTER: {
+	case LogicalOperatorType::LOGICAL_FILTER: {
 		// filter
 		// first we flatten the dependent join in the child of the filter
 		plan->children[0] = PushDownDependentJoinInternal(move(plan->children[0]));
@@ -79,7 +79,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		rewriter.VisitOperator(*plan);
 		return plan;
 	}
-	case LogicalOperatorType::PROJECTION: {
+	case LogicalOperatorType::LOGICAL_PROJECTION: {
 		// projection
 		// first we flatten the dependent join in the child of the projection
 		plan->children[0] = PushDownDependentJoinInternal(move(plan->children[0]));
@@ -99,7 +99,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		this->data_offset = 0;
 		return plan;
 	}
-	case LogicalOperatorType::AGGREGATE_AND_GROUP_BY: {
+	case LogicalOperatorType::LOGICAL_AGGREGATE_AND_GROUP_BY: {
 		auto &aggr = (LogicalAggregate &)*plan;
 		// aggregate and group by
 		// first we flatten the dependent join in the child of the projection
@@ -134,7 +134,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 			// for any COUNT aggregate we replace references to the column with: CASE WHEN COUNT(*) IS NULL THEN 0
 			// ELSE COUNT(*) END
 			for (idx_t i = 0; i < aggr.expressions.size(); i++) {
-				assert(aggr.expressions[i]->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
+				D_ASSERT(aggr.expressions[i]->GetExpressionClass() == ExpressionClass::BOUND_AGGREGATE);
 				auto bound = (BoundAggregateExpression *)&*aggr.expressions[i];
 				vector<LogicalType> arguments;
 				if (bound->function == CountFun::GetFunction() || bound->function == CountStarFun::GetFunction()) {
@@ -156,7 +156,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 			return plan;
 		}
 	}
-	case LogicalOperatorType::CROSS_PRODUCT: {
+	case LogicalOperatorType::LOGICAL_CROSS_PRODUCT: {
 		// cross product
 		// push into both sides of the plan
 		bool left_has_correlation = has_correlated_expressions.find(plan->children[0].get())->second;
@@ -192,9 +192,9 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		join->children.push_back(move(plan->children[1]));
 		return move(join);
 	}
-	case LogicalOperatorType::COMPARISON_JOIN: {
+	case LogicalOperatorType::LOGICAL_COMPARISON_JOIN: {
 		auto &join = (LogicalComparisonJoin &)*plan;
-		assert(plan->children.size() == 2);
+		D_ASSERT(plan->children.size() == 2);
 		// check the correlated expressions in the children of the join
 		bool left_has_correlation = has_correlated_expressions.find(plan->children[0].get())->second;
 		bool right_has_correlation = has_correlated_expressions.find(plan->children[1].get())->second;
@@ -260,7 +260,7 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		rewriter.VisitOperator(*plan);
 		return plan;
 	}
-	case LogicalOperatorType::LIMIT: {
+	case LogicalOperatorType::LOGICAL_LIMIT: {
 		auto &limit = (LogicalLimit &)*plan;
 		if (limit.offset > 0) {
 			throw ParserException("OFFSET not supported in correlated subquery");
@@ -274,13 +274,13 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 			return move(plan->children[0]);
 		}
 	}
-	case LogicalOperatorType::WINDOW: {
+	case LogicalOperatorType::LOGICAL_WINDOW: {
 		auto &window = (LogicalWindow &)*plan;
 		// push into children
 		plan->children[0] = PushDownDependentJoinInternal(move(plan->children[0]));
 		// add the correlated columns to the PARTITION BY clauses in the Window
 		for (auto &expr : window.expressions) {
-			assert(expr->GetExpressionClass() == ExpressionClass::BOUND_WINDOW);
+			D_ASSERT(expr->GetExpressionClass() == ExpressionClass::BOUND_WINDOW);
 			auto &w = (BoundWindowExpression &)*expr;
 			for (idx_t i = 0; i < correlated_columns.size(); i++) {
 				w.partitions.push_back(make_unique<BoundColumnRefExpression>(
@@ -290,9 +290,9 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		}
 		return plan;
 	}
-	case LogicalOperatorType::EXCEPT:
-	case LogicalOperatorType::INTERSECT:
-	case LogicalOperatorType::UNION: {
+	case LogicalOperatorType::LOGICAL_EXCEPT:
+	case LogicalOperatorType::LOGICAL_INTERSECT:
+	case LogicalOperatorType::LOGICAL_UNION: {
 		auto &setop = (LogicalSetOperation &)*plan;
 		// set operator, push into both children
 		plan->children[0] = PushDownDependentJoin(move(plan->children[0]));
@@ -303,10 +303,10 @@ unique_ptr<LogicalOperator> FlattenDependentJoins::PushDownDependentJoinInternal
 		setop.column_count += correlated_columns.size();
 		return plan;
 	}
-	case LogicalOperatorType::DISTINCT:
+	case LogicalOperatorType::LOGICAL_DISTINCT:
 		plan->children[0] = PushDownDependentJoin(move(plan->children[0]));
 		return plan;
-	case LogicalOperatorType::ORDER_BY:
+	case LogicalOperatorType::LOGICAL_ORDER_BY:
 		throw ParserException("ORDER BY not supported in correlated subquery");
 	default:
 		throw NotImplementedException("Logical operator type \"%s\" for dependent join",
