@@ -6,8 +6,8 @@ using namespace std;
 
 ManagedBuffer::ManagedBuffer(BufferManager &manager, idx_t size, bool can_destroy, block_id_t id)
     : FileBuffer(FileBufferType::MANAGED_BUFFER, size), manager(manager), can_destroy(can_destroy), id(id) {
-	assert(id >= MAXIMUM_BLOCK);
-	assert(size >= Storage::BLOCK_ALLOC_SIZE);
+	D_ASSERT(id >= MAXIMUM_BLOCK);
+	D_ASSERT(size >= Storage::BLOCK_ALLOC_SIZE);
 }
 
 } // namespace duckdb
