@@ -11,6 +11,8 @@
 #include "duckdb/storage/table/transient_segment.hpp"
 #include "duckdb/storage/storage_manager.hpp"
 #include "duckdb/main/client_context.hpp"
+#include "duckdb/planner/table_filter.hpp"
+#include "duckdb/storage/table/persistent_table_data.hpp"
 
 #include "duckdb/storage/table/morsel_info.hpp"
 
@@ -19,22 +21,23 @@ using namespace std;
 using namespace chrono;
 
 DataTable::DataTable(StorageManager &storage, string schema, string table, vector<LogicalType> types_,
-                     unique_ptr<vector<unique_ptr<PersistentSegment>>[]> data)
+                     unique_ptr<PersistentTableData> data)
     : info(make_shared<DataTableInfo>(schema, table)), types(types_), storage(storage),
       versions(make_shared<SegmentTree>()), total_rows(0), is_root(true) {
 	// set up the segment trees for the column segments
 	for (idx_t i = 0; i < types.size(); i++) {
-		auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info);
-		column_data->type = types[i];
-		column_data->column_idx = i;
+		auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info, types[i], i);
 		columns.push_back(move(column_data));
 	}
 
 	// initialize the table with the existing data from disk, if any
-	if (data && data[0].size() > 0) {
+	if (data && data->table_data[0].size() > 0) {
+		for (idx_t i = 0; i < types.size(); i++) {
+			columns[i]->statistics = move(data->column_stats[i]);
+		}
 		// first append all the segments to the set of column segments
 		for (idx_t i = 0; i < types.size(); i++) {
-			columns[i]->Initialize(data[i]);
+			columns[i]->Initialize(data->table_data[i]);
 			if (columns[i]->persistent_rows != columns[0]->persistent_rows) {
 				throw Exception("Column length mismatch in table load!");
 			}
@@ -63,9 +66,7 @@ DataTable::DataTable(ClientContext &context, DataTable &parent, ColumnDefinition
 	idx_t new_column_idx = columns.size();
 
 	types.push_back(new_column_type);
-	auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info);
-	column_data->type = new_column_type;
-	column_data->column_idx = new_column_idx;
+	auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info, new_column_type, new_column_idx);
 	columns.push_back(move(column_data));
 
 	// fill the column with its DEFAULT value, or NULL if none is specified
@@ -114,7 +115,7 @@ DataTable::DataTable(ClientContext &context, DataTable &parent, idx_t removed_co
 		}
 	}
 	// erase the column from this DataTable
-	assert(removed_column < types.size());
+	D_ASSERT(removed_column < types.size());
 	types.erase(types.begin() + removed_column);
 	columns.erase(columns.begin() + removed_column);
 
@@ -143,9 +144,7 @@ DataTable::DataTable(ClientContext &context, DataTable &parent, idx_t changed_id
 	types[changed_idx] = target_type;
 
 	// construct a new column data for this type
-	auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info);
-	column_data->type = target_type;
-	column_data->column_idx = changed_idx;
+	auto column_data = make_shared<ColumnData>(*storage.buffer_manager, *info, target_type, changed_idx);
 
 	ColumnAppendState append_state;
 	column_data->InitializeAppend(append_state);
@@ -193,7 +192,7 @@ DataTable::DataTable(ClientContext &context, DataTable &parent, idx_t changed_id
 // Scan
 //===--------------------------------------------------------------------===//
 void DataTable::InitializeScan(TableScanState &state, const vector<column_t> &column_ids,
-                               unordered_map<idx_t, vector<TableFilter>> *table_filters) {
+                               TableFilterSet *table_filters) {
 	// initialize a column scan state for each column
 	state.column_scans = unique_ptr<ColumnScanState[]>(new ColumnScanState[column_ids.size()]);
 	for (idx_t i = 0; i < column_ids.size(); i++) {
@@ -210,22 +209,23 @@ void DataTable::InitializeScan(TableScanState &state, const vector<column_t> &co
 	state.base_row = 0;
 	state.max_row = total_rows;
 	state.version_info = (MorselInfo *)versions->GetRootSegment();
-	if (table_filters && table_filters->size() > 0) {
-		state.adaptive_filter = make_unique<AdaptiveFilter>(*table_filters);
+	state.table_filters = table_filters;
+	if (table_filters) {
+		D_ASSERT(table_filters->filters.size() > 0);
+		state.adaptive_filter = make_unique<AdaptiveFilter>(table_filters);
 	}
 }
 
 void DataTable::InitializeScan(Transaction &transaction, TableScanState &state, const vector<column_t> &column_ids,
-                               unordered_map<idx_t, vector<TableFilter>> *table_filters) {
+                               TableFilterSet *table_filters) {
 	InitializeScan(state, column_ids, table_filters);
-	transaction.storage.InitializeScan(this, state.local_state);
+	transaction.storage.InitializeScan(this, state.local_state, table_filters);
 }
 
 void DataTable::InitializeScanWithOffset(TableScanState &state, const vector<column_t> &column_ids,
-                                         unordered_map<idx_t, vector<TableFilter>> *table_filters, idx_t start_row,
-                                         idx_t end_row) {
-	assert(start_row % STANDARD_VECTOR_SIZE == 0);
-	assert(end_row > start_row);
+                                         TableFilterSet *table_filters, idx_t start_row, idx_t end_row) {
+	D_ASSERT(start_row % STANDARD_VECTOR_SIZE == 0);
+	D_ASSERT(end_row > start_row);
 	idx_t vector_offset = start_row / STANDARD_VECTOR_SIZE;
 	// initialize a column scan state for each column
 	state.column_scans = unique_ptr<ColumnScanState[]>(new ColumnScanState[column_ids.size()]);
@@ -244,8 +244,9 @@ void DataTable::InitializeScanWithOffset(TableScanState &state, const vector<col
 	state.base_row = start_row;
 	state.max_row = end_row;
 	state.version_info = (MorselInfo *)versions->GetSegment(state.current_row);
-	if (table_filters && table_filters->size() > 0 && !state.adaptive_filter) {
-		state.adaptive_filter = make_unique<AdaptiveFilter>(*table_filters);
+	state.table_filters = table_filters;
+	if (table_filters && table_filters->filters.size() > 0) {
+		state.adaptive_filter = make_unique<AdaptiveFilter>(table_filters);
 	}
 }
 
@@ -265,8 +266,7 @@ void DataTable::InitializeParallelScan(ParallelTableScanState &state) {
 }
 
 bool DataTable::NextParallelScan(ClientContext &context, ParallelTableScanState &state, TableScanState &scan_state,
-                                 const vector<column_t> &column_ids,
-                                 unordered_map<idx_t, vector<TableFilter>> *table_filters) {
+                                 const vector<column_t> &column_ids) {
 	idx_t PARALLEL_SCAN_VECTOR_COUNT = 100;
 	if (context.force_parallelism) {
 		PARALLEL_SCAN_VECTOR_COUNT = 1;
@@ -277,7 +277,7 @@ bool DataTable::NextParallelScan(ClientContext &context, ParallelTableScanState
 		idx_t next = MinValue(state.current_row + PARALLEL_SCAN_TUPLE_COUNT, total_rows);
 
 		// scan a morsel from the persistent rows
-		InitializeScanWithOffset(scan_state, column_ids, table_filters, state.current_row, next);
+		InitializeScanWithOffset(scan_state, column_ids, scan_state.table_filters, state.current_row, next);
 
 		state.current_row = next;
 		return true;
@@ -287,7 +287,7 @@ bool DataTable::NextParallelScan(ClientContext &context, ParallelTableScanState
 		scan_state.current_row = 0;
 		scan_state.base_row = 0;
 		scan_state.max_row = 0;
-		transaction.storage.InitializeScan(this, scan_state.local_state);
+		transaction.storage.InitializeScan(this, scan_state.local_state, scan_state.table_filters);
 		state.transaction_local_data = true;
 		return true;
 	} else {
@@ -296,10 +296,9 @@ bool DataTable::NextParallelScan(ClientContext &context, ParallelTableScanState
 	}
 }
 
-void DataTable::Scan(Transaction &transaction, DataChunk &result, TableScanState &state, vector<column_t> &column_ids,
-                     unordered_map<idx_t, vector<TableFilter>> &table_filters) {
+void DataTable::Scan(Transaction &transaction, DataChunk &result, TableScanState &state, vector<column_t> &column_ids) {
 	// scan the persistent segments
-	while (ScanBaseTable(transaction, result, state, column_ids, state.current_row, state.max_row, table_filters)) {
+	while (ScanBaseTable(transaction, result, state, column_ids, state.current_row, state.max_row)) {
 		if (result.size() > 0) {
 			return;
 		}
@@ -307,50 +306,14 @@ void DataTable::Scan(Transaction &transaction, DataChunk &result, TableScanState
 	}
 
 	// scan the transaction-local segments
-	transaction.storage.Scan(state.local_state, column_ids, result, &table_filters);
+	transaction.storage.Scan(state.local_state, column_ids, result);
 }
 
-template <class T> bool checkZonemap(TableScanState &state, TableFilter &table_filter, T constant) {
-	T *min = (T *)state.column_scans[table_filter.column_index].current->stats.minimum.get();
-	T *max = (T *)state.column_scans[table_filter.column_index].current->stats.maximum.get();
-	switch (table_filter.comparison_type) {
-	case ExpressionType::COMPARE_EQUAL:
-		return constant >= *min && constant <= *max;
-	case ExpressionType::COMPARE_GREATERTHANOREQUALTO:
-		return constant <= *max;
-	case ExpressionType::COMPARE_GREATERTHAN:
-		return constant < *max;
-	case ExpressionType::COMPARE_LESSTHANOREQUALTO:
-		return constant >= *min;
-	case ExpressionType::COMPARE_LESSTHAN:
-		return constant > *min;
-	default:
-		throw NotImplementedException("Operation not implemented");
+bool DataTable::CheckZonemap(TableScanState &state, TableFilterSet *table_filters, idx_t &current_row) {
+	if (!table_filters) {
+		return true;
 	}
-}
-
-bool checkZonemapString(TableScanState &state, TableFilter &table_filter, const char *constant) {
-	char *min = (char *)state.column_scans[table_filter.column_index].current->stats.minimum.get();
-	char *max = (char *)state.column_scans[table_filter.column_index].current->stats.maximum.get();
-	int min_comp = strcmp(min, constant);
-	int max_comp = strcmp(max, constant);
-	switch (table_filter.comparison_type) {
-	case ExpressionType::COMPARE_EQUAL:
-		return min_comp <= 0 && max_comp >= 0;
-	case ExpressionType::COMPARE_GREATERTHANOREQUALTO:
-	case ExpressionType::COMPARE_GREATERTHAN:
-		return max_comp >= 0;
-	case ExpressionType::COMPARE_LESSTHAN:
-	case ExpressionType::COMPARE_LESSTHANOREQUALTO:
-		return min_comp <= 0;
-	default:
-		throw NotImplementedException("Operation not implemented");
-	}
-}
-
-bool DataTable::CheckZonemap(TableScanState &state, unordered_map<idx_t, vector<TableFilter>> &table_filters,
-                             idx_t &current_row) {
-	for (auto &table_filter : table_filters) {
+	for (auto &table_filter : table_filters->filters) {
 		for (auto &predicate_constant : table_filter.second) {
 			bool readSegment = true;
 
@@ -359,57 +322,8 @@ bool DataTable::CheckZonemap(TableScanState &state, unordered_map<idx_t, vector<
 				if (!state.column_scans[predicate_constant.column_index].current) {
 					return true;
 				}
-				switch (state.column_scans[predicate_constant.column_index].current->type) {
-				case PhysicalType::INT8: {
-					int8_t constant = predicate_constant.constant.value_.tinyint;
-					readSegment = checkZonemap<int8_t>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::INT16: {
-					int16_t constant = predicate_constant.constant.value_.smallint;
-					readSegment = checkZonemap<int16_t>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::INT32: {
-					int32_t constant = predicate_constant.constant.value_.integer;
-					readSegment = checkZonemap<int32_t>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::INT64: {
-					int64_t constant = predicate_constant.constant.value_.bigint;
-					readSegment = checkZonemap<int64_t>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::INT128: {
-					auto constant = predicate_constant.constant.value_.hugeint;
-					readSegment = checkZonemap<hugeint_t>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::FLOAT: {
-					float constant = predicate_constant.constant.value_.float_;
-					readSegment = checkZonemap<float>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::DOUBLE: {
-					double constant = predicate_constant.constant.value_.double_;
-					readSegment = checkZonemap<double>(state, predicate_constant, constant);
-					break;
-				}
-				case PhysicalType::VARCHAR: {
-					//! we can only compare the first 7 bytes
-					size_t value_size = predicate_constant.constant.str_value.size() > 7
-					                        ? 7
-					                        : predicate_constant.constant.str_value.size();
-					string constant;
-					for (size_t i = 0; i < value_size; i++) {
-						constant += predicate_constant.constant.str_value[i];
-					}
-					readSegment = checkZonemapString(state, predicate_constant, constant.c_str());
-					break;
-				}
-				default:
-					throw NotImplementedException("Unimplemented type for zonemaps");
-				}
+				readSegment =
+				    state.column_scans[predicate_constant.column_index].current->stats.CheckZonemap(predicate_constant);
 			}
 			if (!readSegment) {
 				//! We can skip this partition
@@ -430,8 +344,7 @@ bool DataTable::CheckZonemap(TableScanState &state, unordered_map<idx_t, vector<
 }
 
 bool DataTable::ScanBaseTable(Transaction &transaction, DataChunk &result, TableScanState &state,
-                              const vector<column_t> &column_ids, idx_t &current_row, idx_t max_row,
-                              unordered_map<idx_t, vector<TableFilter>> &table_filters) {
+                              const vector<column_t> &column_ids, idx_t &current_row, idx_t max_row) {
 	if (current_row >= max_row) {
 		// exceeded the amount of rows to scan
 		return false;
@@ -439,7 +352,7 @@ bool DataTable::ScanBaseTable(Transaction &transaction, DataChunk &result, Table
 	idx_t max_count = MinValue<idx_t>(STANDARD_VECTOR_SIZE, max_row - current_row);
 	idx_t vector_offset = (current_row - state.base_row) / STANDARD_VECTOR_SIZE;
 	//! first check the zonemap if we have to scan this partition
-	if (!CheckZonemap(state, table_filters, current_row)) {
+	if (!CheckZonemap(state, state.table_filters, current_row)) {
 		return true;
 	}
 	// second, scan the version chunk manager to figure out which tuples to load for this transaction
@@ -457,13 +370,13 @@ bool DataTable::ScanBaseTable(Transaction &transaction, DataChunk &result, Table
 		return true;
 	}
 	idx_t approved_tuple_count = count;
-	if (count == max_count && table_filters.empty()) {
+	if (count == max_count && !state.table_filters) {
 		//! If we don't have any deleted tuples or filters we can just run a regular scan
 		for (idx_t i = 0; i < column_ids.size(); i++) {
 			auto column = column_ids[i];
 			if (column == COLUMN_IDENTIFIER_ROW_ID) {
 				// scan row id
-				assert(result.data[i].type.InternalType() == ROW_TYPE);
+				D_ASSERT(result.data[i].type.InternalType() == ROW_TYPE);
 				result.data[i].Sequence(current_row, 1);
 			} else {
 				columns[column]->Scan(transaction, state.column_scans[i], result.data[i]);
@@ -480,21 +393,23 @@ bool DataTable::ScanBaseTable(Transaction &transaction, DataChunk &result, Table
 		//! First, we scan the columns with filters, fetch their data and generate a selection vector.
 		//! get runtime statistics
 		auto start_time = high_resolution_clock::now();
-		for (idx_t i = 0; i < table_filters.size(); i++) {
-			auto tf_idx = state.adaptive_filter->permutation[i];
-			auto col_idx = column_ids[tf_idx];
-			columns[col_idx]->Select(transaction, state.column_scans[tf_idx], result.data[tf_idx], sel,
-			                         approved_tuple_count, table_filters[tf_idx]);
-		}
-		for (auto &table_filter : table_filters) {
-			result.data[table_filter.first].Slice(sel, approved_tuple_count);
+		if (state.table_filters) {
+			for (idx_t i = 0; i < state.table_filters->filters.size(); i++) {
+				auto tf_idx = state.adaptive_filter->permutation[i];
+				auto col_idx = column_ids[tf_idx];
+				columns[col_idx]->Select(transaction, state.column_scans[tf_idx], result.data[tf_idx], sel,
+				                         approved_tuple_count, state.table_filters->filters[tf_idx]);
+			}
+			for (auto &table_filter : state.table_filters->filters) {
+				result.data[table_filter.first].Slice(sel, approved_tuple_count);
+			}
 		}
 		//! Now we use the selection vector to fetch data for the other columns.
 		for (idx_t i = 0; i < column_ids.size(); i++) {
-			if (table_filters.find(i) == table_filters.end()) {
+			if (!state.table_filters || state.table_filters->filters.find(i) == state.table_filters->filters.end()) {
 				auto column = column_ids[i];
 				if (column == COLUMN_IDENTIFIER_ROW_ID) {
-					assert(result.data[i].type.InternalType() == PhysicalType::INT64);
+					D_ASSERT(result.data[i].type.InternalType() == PhysicalType::INT64);
 					result.data[i].vector_type = VectorType::FLAT_VECTOR;
 					auto result_data = (int64_t *)FlatVector::GetData(result.data[i]);
 					for (size_t sel_idx = 0; sel_idx < approved_tuple_count; sel_idx++) {
@@ -507,7 +422,7 @@ bool DataTable::ScanBaseTable(Transaction &transaction, DataChunk &result, Table
 			}
 		}
 		auto end_time = high_resolution_clock::now();
-		if (state.adaptive_filter && table_filters.size() > 1) {
+		if (state.adaptive_filter && state.table_filters->filters.size() > 1) {
 			state.adaptive_filter->AdaptRuntimeStatistics(
 			    duration_cast<duration<double>>(end_time - start_time).count());
 		}
@@ -536,7 +451,7 @@ void DataTable::Fetch(Transaction &transaction, DataChunk &result, vector<column
 		auto column = column_ids[col_idx];
 		if (column == COLUMN_IDENTIFIER_ROW_ID) {
 			// row id column: fill in the row ids
-			assert(result.data[col_idx].type.InternalType() == PhysicalType::INT64);
+			D_ASSERT(result.data[col_idx].type.InternalType() == PhysicalType::INT64);
 			result.data[col_idx].vector_type = VectorType::FLAT_VECTOR;
 			auto data = FlatVector::GetData<row_t>(result.data[col_idx]);
 			for (idx_t i = 0; i < count; i++) {
@@ -553,7 +468,7 @@ void DataTable::Fetch(Transaction &transaction, DataChunk &result, vector<column
 }
 
 idx_t DataTable::FetchRows(Transaction &transaction, Vector &row_identifiers, idx_t fetch_count, row_t result_rows[]) {
-	assert(row_identifiers.type.InternalType() == ROW_TYPE);
+	D_ASSERT(row_identifiers.type.InternalType() == ROW_TYPE);
 
 	// now iterate over the row ids and figure out which rows to use
 	idx_t count = 0;
@@ -634,7 +549,7 @@ void DataTable::Append(TableCatalogEntry &table, ClientContext &context, DataChu
 	if (chunk.size() == 0) {
 		return;
 	}
-	if (chunk.column_count() != table.columns.size()) {
+	if (chunk.ColumnCount() != table.columns.size()) {
 		throw CatalogException("Mismatch in column count for append");
 	}
 	if (!is_root) {
@@ -673,7 +588,7 @@ void DataTable::InitializeAppend(Transaction &transaction, TableAppendState &sta
 	// start writing to the morsels
 	lock_guard<mutex> morsel_lock(versions->node_lock);
 	auto last_morsel = (MorselInfo *)versions->GetLastSegment();
-	assert(last_morsel->start <= (idx_t)state.row_start);
+	D_ASSERT(last_morsel->start <= (idx_t)state.row_start);
 	idx_t current_position = state.row_start - last_morsel->start;
 	idx_t remaining = append_count;
 	while (true) {
@@ -700,8 +615,8 @@ void DataTable::InitializeAppend(Transaction &transaction, TableAppendState &sta
 }
 
 void DataTable::Append(Transaction &transaction, DataChunk &chunk, TableAppendState &state) {
-	assert(is_root);
-	assert(chunk.column_count() == types.size());
+	D_ASSERT(is_root);
+	D_ASSERT(chunk.ColumnCount() == types.size());
 	chunk.Verify();
 
 	// append the physical data to each of the entries
@@ -793,7 +708,7 @@ void DataTable::RevertAppendInternal(idx_t start_row, idx_t count) {
 	// adjust the cardinality
 	info->cardinality = start_row;
 	total_rows = start_row;
-	assert(is_root);
+	D_ASSERT(is_root);
 	// revert changes in the base columns
 	for (idx_t i = 0; i < types.size(); i++) {
 		columns[i]->RevertAppend(start_row);
@@ -840,7 +755,7 @@ void DataTable::RevertAppend(idx_t start_row, idx_t count) {
 // Indexes
 //===--------------------------------------------------------------------===//
 bool DataTable::AppendToIndexes(TableAppendState &state, DataChunk &chunk, row_t row_start) {
-	assert(is_root);
+	D_ASSERT(is_root);
 	if (info->indexes.size() == 0) {
 		return true;
 	}
@@ -868,7 +783,7 @@ bool DataTable::AppendToIndexes(TableAppendState &state, DataChunk &chunk, row_t
 }
 
 void DataTable::RemoveFromIndexes(TableAppendState &state, DataChunk &chunk, row_t row_start) {
-	assert(is_root);
+	D_ASSERT(is_root);
 	if (info->indexes.size() == 0) {
 		return;
 	}
@@ -881,14 +796,14 @@ void DataTable::RemoveFromIndexes(TableAppendState &state, DataChunk &chunk, row
 }
 
 void DataTable::RemoveFromIndexes(TableAppendState &state, DataChunk &chunk, Vector &row_identifiers) {
-	assert(is_root);
+	D_ASSERT(is_root);
 	for (idx_t i = 0; i < info->indexes.size(); i++) {
 		info->indexes[i]->Delete(state.index_locks[i], chunk, row_identifiers);
 	}
 }
 
 void DataTable::RemoveFromIndexes(Vector &row_identifiers, idx_t count) {
-	assert(is_root);
+	D_ASSERT(is_root);
 	auto row_ids = FlatVector::GetData<row_t>(row_identifiers);
 	// create a selection vector from the row_ids
 	SelectionVector sel(STANDARD_VECTOR_SIZE);
@@ -914,7 +829,7 @@ void DataTable::RemoveFromIndexes(Vector &row_identifiers, idx_t count) {
 // Delete
 //===--------------------------------------------------------------------===//
 void DataTable::Delete(TableCatalogEntry &table, ClientContext &context, Vector &row_identifiers, idx_t count) {
-	assert(row_identifiers.type.InternalType() == ROW_TYPE);
+	D_ASSERT(row_identifiers.type.InternalType() == ROW_TYPE);
 	if (count == 0) {
 		return;
 	}
@@ -1006,14 +921,14 @@ void DataTable::VerifyUpdateConstraints(TableCatalogEntry &table, DataChunk &chu
 	// instead update should have been rewritten to delete + update on higher layer
 #ifdef DEBUG
 	for (idx_t i = 0; i < info->indexes.size(); i++) {
-		assert(!info->indexes[i]->IndexIsUpdated(column_ids));
+		D_ASSERT(!info->indexes[i]->IndexIsUpdated(column_ids));
 	}
 #endif
 }
 
 void DataTable::Update(TableCatalogEntry &table, ClientContext &context, Vector &row_ids, vector<column_t> &column_ids,
                        DataChunk &updates) {
-	assert(row_ids.type.InternalType() == ROW_TYPE);
+	D_ASSERT(row_ids.type.InternalType() == ROW_TYPE);
 
 	updates.Verify();
 	if (updates.size() == 0) {
@@ -1037,7 +952,7 @@ void DataTable::Update(TableCatalogEntry &table, ClientContext &context, Vector
 
 	for (idx_t i = 0; i < column_ids.size(); i++) {
 		auto column = column_ids[i];
-		assert(column != COLUMN_IDENTIFIER_ROW_ID);
+		D_ASSERT(column != COLUMN_IDENTIFIER_ROW_ID);
 
 		columns[column]->Update(transaction, updates.data[i], row_ids, updates.size());
 	}
@@ -1075,7 +990,7 @@ bool DataTable::ScanCreateIndex(CreateIndexScanState &state, const vector<column
 		auto column = column_ids[i];
 		if (column == COLUMN_IDENTIFIER_ROW_ID) {
 			// scan row id
-			assert(result.data[i].type.InternalType() == ROW_TYPE);
+			D_ASSERT(result.data[i].type.InternalType() == ROW_TYPE);
 			result.data[i].Sequence(current_row, 1);
 		} else {
 			// scan actual base column
@@ -1127,11 +1042,19 @@ void DataTable::AddIndex(unique_ptr<Index> index, vector<unique_ptr<Expression>>
 		executor.Execute(intermediate, result);
 
 		// insert into the index
-		if (!index->Insert(lock, result, intermediate.data[intermediate.column_count() - 1])) {
+		if (!index->Insert(lock, result, intermediate.data[intermediate.ColumnCount() - 1])) {
 			throw ConstraintException("Cant create unique index, table contains duplicate data on indexed column(s)");
 		}
 	}
 	info->indexes.push_back(move(index));
 }
 
+unique_ptr<BaseStatistics> DataTable::GetStatistics(ClientContext &context, column_t column_id) {
+	if (column_id == COLUMN_IDENTIFIER_ROW_ID) {
+		return nullptr;
+	}
+	// FIXME: potentially merge with transaction local shtuff
+	return columns[column_id]->statistics->Copy();
+}
+
 } // namespace duckdb
