@@ -1,9 +1,12 @@
 #include "duckdb/storage/write_ahead_log.hpp"
-#include "duckdb/main/database.hpp"
+
+#include "duckdb/catalog/catalog_entry/macro_catalog_entry.hpp"
 #include "duckdb/catalog/catalog_entry/schema_catalog_entry.hpp"
 #include "duckdb/catalog/catalog_entry/table_catalog_entry.hpp"
 #include "duckdb/catalog/catalog_entry/view_catalog_entry.hpp"
+#include "duckdb/main/database.hpp"
 #include "duckdb/parser/parsed_data/alter_table_info.hpp"
+
 #include <cstring>
 
 namespace duckdb {
@@ -76,6 +79,20 @@ void WriteAheadLog::WriteSequenceValue(SequenceCatalogEntry *entry, SequenceValu
 	writer->Write<int64_t>(val.counter);
 }
 
+//===--------------------------------------------------------------------===//
+// MACRO'S
+//===--------------------------------------------------------------------===//
+void WriteAheadLog::WriteCreateMacro(MacroCatalogEntry *entry) {
+	writer->Write<WALType>(WALType::CREATE_MACRO);
+	entry->Serialize(*writer);
+}
+
+void WriteAheadLog::WriteDropMacro(MacroCatalogEntry *entry) {
+	writer->Write<WALType>(WALType::DROP_MACRO);
+	writer->WriteString(entry->schema->name);
+	writer->WriteString(entry->name);
+}
+
 //===--------------------------------------------------------------------===//
 // VIEWS
 //===--------------------------------------------------------------------===//
@@ -108,7 +125,7 @@ void WriteAheadLog::WriteSetTable(string &schema, string &table) {
 }
 
 void WriteAheadLog::WriteInsert(DataChunk &chunk) {
-	assert(chunk.size() > 0);
+	D_ASSERT(chunk.size() > 0);
 	chunk.Verify();
 
 	writer->Write<WALType>(WALType::INSERT_TUPLE);
@@ -116,8 +133,8 @@ void WriteAheadLog::WriteInsert(DataChunk &chunk) {
 }
 
 void WriteAheadLog::WriteDelete(DataChunk &chunk) {
-	assert(chunk.size() > 0);
-	assert(chunk.column_count() == 1 && chunk.data[0].type == LOGICAL_ROW_TYPE);
+	D_ASSERT(chunk.size() > 0);
+	D_ASSERT(chunk.ColumnCount() == 1 && chunk.data[0].type == LOGICAL_ROW_TYPE);
 	chunk.Verify();
 
 	writer->Write<WALType>(WALType::DELETE_TUPLE);
@@ -125,7 +142,7 @@ void WriteAheadLog::WriteDelete(DataChunk &chunk) {
 }
 
 void WriteAheadLog::WriteUpdate(DataChunk &chunk, column_t col_idx) {
-	assert(chunk.size() > 0);
+	D_ASSERT(chunk.size() > 0);
 	chunk.Verify();
 
 	writer->Write<WALType>(WALType::UPDATE_TUPLE);
