@@ -31,7 +31,7 @@ void CommitState::WriteCatalogEntry(CatalogEntry *entry, data_ptr_t dataptr) {
 	if (entry->temporary || entry->parent->temporary) {
 		return;
 	}
-	assert(log);
+	D_ASSERT(log);
 	// look at the type of the parent entry
 	auto parent = entry->parent;
 	switch (parent->type) {
@@ -74,6 +74,9 @@ void CommitState::WriteCatalogEntry(CatalogEntry *entry, data_ptr_t dataptr) {
 	case CatalogType::SEQUENCE_ENTRY:
 		log->WriteCreateSequence((SequenceCatalogEntry *)parent);
 		break;
+	case CatalogType::MACRO_ENTRY:
+		log->WriteCreateMacro((MacroCatalogEntry *)parent);
+		break;
 	case CatalogType::DELETED_ENTRY:
 		if (entry->type == CatalogType::TABLE_ENTRY) {
 			log->WriteDropTable((TableCatalogEntry *)entry);
@@ -83,8 +86,10 @@ void CommitState::WriteCatalogEntry(CatalogEntry *entry, data_ptr_t dataptr) {
 			log->WriteDropView((ViewCatalogEntry *)entry);
 		} else if (entry->type == CatalogType::SEQUENCE_ENTRY) {
 			log->WriteDropSequence((SequenceCatalogEntry *)entry);
+		} else if (entry->type == CatalogType::MACRO_ENTRY) {
+			log->WriteDropMacro((MacroCatalogEntry *)entry);
 		} else if (entry->type == CatalogType::PREPARED_STATEMENT) {
-			// do nothing, we log the query to drop this
+			// do nothing, prepared statements aren't persisted to disk
 		} else {
 			throw NotImplementedException("Don't know how to drop this type!");
 		}
@@ -98,8 +103,7 @@ void CommitState::WriteCatalogEntry(CatalogEntry *entry, data_ptr_t dataptr) {
 	case CatalogType::COPY_FUNCTION_ENTRY:
 	case CatalogType::PRAGMA_FUNCTION_ENTRY:
 	case CatalogType::COLLATION_ENTRY:
-
-		// do nothing, we log the query to recreate this
+		// do nothing, these entries are not persisted to disk
 		break;
 	default:
 		throw NotImplementedException("UndoBuffer - don't know how to write this entry to the WAL");
@@ -107,7 +111,7 @@ void CommitState::WriteCatalogEntry(CatalogEntry *entry, data_ptr_t dataptr) {
 }
 
 void CommitState::WriteDelete(DeleteInfo *info) {
-	assert(log);
+	D_ASSERT(log);
 	// switch to the current table, if necessary
 	SwitchTable(info->table->info.get(), UndoFlags::DELETE_TUPLE);
 
@@ -125,7 +129,7 @@ void CommitState::WriteDelete(DeleteInfo *info) {
 }
 
 void CommitState::WriteUpdate(UpdateInfo *info) {
-	assert(log);
+	D_ASSERT(log);
 	// switch to the current table, if necessary
 	SwitchTable(&info->column_data->table_info, UndoFlags::UPDATE_TUPLE);
 
@@ -155,7 +159,7 @@ template <bool HAS_LOG> void CommitState::CommitEntry(UndoFlags type, data_ptr_t
 	case UndoFlags::CATALOG_ENTRY: {
 		// set the commit timestamp of the catalog entry to the given id
 		auto catalog_entry = Load<CatalogEntry *>(data);
-		assert(catalog_entry->parent);
+		D_ASSERT(catalog_entry->parent);
 		catalog_entry->set->UpdateTimestamp(catalog_entry->parent, commit_id);
 		if (catalog_entry->name != catalog_entry->parent->name) {
 			catalog_entry->set->UpdateTimestamp(catalog_entry, commit_id);
@@ -179,7 +183,6 @@ template <bool HAS_LOG> void CommitState::CommitEntry(UndoFlags type, data_ptr_t
 	case UndoFlags::DELETE_TUPLE: {
 		// deletion:
 		auto info = (DeleteInfo *)data;
-		info->table->info->cardinality -= info->count;
 		if (HAS_LOG && !info->table->info->IsTemporary()) {
 			WriteDelete(info);
 		}
@@ -207,7 +210,7 @@ void CommitState::RevertCommit(UndoFlags type, data_ptr_t data) {
 	case UndoFlags::CATALOG_ENTRY: {
 		// set the commit timestamp of the catalog entry to the given id
 		auto catalog_entry = Load<CatalogEntry *>(data);
-		assert(catalog_entry->parent);
+		D_ASSERT(catalog_entry->parent);
 		catalog_entry->set->UpdateTimestamp(catalog_entry->parent, transaction_id);
 		if (catalog_entry->name != catalog_entry->parent->name) {
 			catalog_entry->set->UpdateTimestamp(catalog_entry, transaction_id);
