@@ -18,7 +18,7 @@ void RollbackState::RollbackEntry(UndoFlags type, data_ptr_t data) {
 	case UndoFlags::CATALOG_ENTRY: {
 		// undo this catalog entry
 		auto catalog_entry = Load<CatalogEntry *>(data);
-		assert(catalog_entry->set);
+		D_ASSERT(catalog_entry->set);
 		catalog_entry->set->Undo(catalog_entry);
 		break;
 	}
@@ -40,7 +40,7 @@ void RollbackState::RollbackEntry(UndoFlags type, data_ptr_t data) {
 		break;
 	}
 	default:
-		assert(type == UndoFlags::EMPTY_ENTRY);
+		D_ASSERT(type == UndoFlags::EMPTY_ENTRY);
 		break;
 	}
 }
